@@ -9,8 +9,7 @@
 \mainpage
 
 
-TikiWiki CMS/Groupware is Free and Open Source Software (FOSS). It is a community-driven project.
-It exists and improves by the participation of people just like YOU.
+TikiWiki CMS/Groupware is Free and Open Source Software (FOSS). It is a community-driven project which exists and improves thanks to the participation of people just like YOU.
 
 
 IMPORTANT LINKS
@@ -57,9 +56,6 @@ Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for detail
 */
 
 // I call index.php because tiki may not be setup when people attempt to call this.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== FALSE) {
-	header ("location: index.php");
-	die;
-}
+header ("location: index.php");
+die;
 
-?>
\ No newline at end of file
