@@ -1,6 +1,6 @@
 <?php
 
-// $Id: /cvsroot/tikiwiki/tiki/categorize_list.php,v 1.30.2.5 2007-12-19 22:50:15 sylvieg Exp $
+// $Id: categorize_list.php 22383 2009-10-16 14:01:42Z jonnybradley $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -14,9 +14,10 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 require_once('tiki-setup.php');  
 global $prefs, $userlib;
+$catobjperms = Perms::get( array( 'type' => $cat_type, 'object' => $cat_objid ) );
 
 $smarty->assign('mandatory_category', '-1');
-if ($prefs['feature_categories'] == 'y') {
+if ($prefs['feature_categories'] == 'y' && isset($cat_type) && isset($cat_objid)) {
 	global $categlib, $user; include_once ('lib/categories/categlib.php');
 	$smarty->assign('cat_categorize', 'n');
 
@@ -24,7 +25,15 @@ if ($prefs['feature_categories'] == 'y') {
 		$smarty->assign('cat_categorize', 'y');
 	}
 
-	$cats = $categlib->get_object_categories($cat_type, $cat_objid);
+	if( ! isset( $cat_object_exists ) ) {
+		$cat_object_exists = (bool) $cat_objid;
+	}
+
+	if( $cat_object_exists ) {
+		$cats = $categlib->get_object_categories($cat_type, $cat_objid);
+	} else {
+		$cats = $categlib->get_default_categories();
+	}
 	
 	if ($prefs['feature_wikiapproval'] == 'y' && $prefs['wikiapproval_sync_categories'] == 'y' && !$cats
 	 && $cat_type == 'wiki page' && substr($cat_objid, 0, strlen($prefs['wikiapproval_prefix'])) == $prefs['wikiapproval_prefix']
@@ -44,32 +53,28 @@ if ($prefs['feature_categories'] == 'y') {
 			$all_categories = $categlib->list_categs();
 		}
 		$smarty->assign('mandatory_category', $prefs[$pref]);
-	} else
+	} else {
 		$all_categories = $categlib->list_categs();
-	$categories = array();
-	for ($i = 0; $i < count($all_categories); $i++) {
-		if($tikilib->user_has_perm_on_object($user,$all_categories[$i]['categId'],'category','tiki_p_edit_categorized') || $tikilib->user_has_perm_on_object($user,$all_categories[$i]['categId'],'category','tiki_p_admin_categories')) {
-			$categories[] = $all_categories[$i];
-			// remove category for approved pages from category list if this is a staging page
-			if ($prefs["feature_wikiapproval"] == 'y' && $cat_type == 'wiki page' && substr($cat_objid, 0, strlen($prefs['wikiapproval_prefix'])) == $prefs['wikiapproval_prefix']
-			 && $prefs['wikiapproval_approved_category'] > 0 && $prefs['wikiapproval_approved_category'] == $all_categories[$i]['categId']) {			
-				array_pop($categories);
-			}	
-		}
 	}
 
-if (isset ($categories)) {
+	if( ! empty( $all_categories ) ) {
+		$categories = Perms::filter( array( 'type' => 'category' ), 'object', $all_categories, array( 'object' => 'categId' ), 'view_category' );
+	} else {
+		$categories = array();
+	}
+
 	$num_categories = count($categories);
-}
-else {
-	$num_categories = 0;
-};
+ 	$can = $catobjperms->modify_object_categories;
 
 	for ($i = 0; $i < $num_categories; $i++) {
+		$catperms = Perms::get( array( 'type' => 'category', 'object' => $categories[$i]['categId'] ) );
+
 		if (!empty($cats) && in_array($categories[$i]["categId"], $cats)) {
 			$categories[$i]["incat"] = 'y';
+			$categories[$i]['canchange'] = ! $cat_object_exists || ( $can && $catperms->remove_object );
 		} else {
 			$categories[$i]["incat"] = 'n';
+			$categories[$i]['canchange'] = $can && $catperms->add_object;
 		}
 		if (isset($_REQUEST["cat_categories"]) && isset($_REQUEST["cat_categorize"]) && $_REQUEST["cat_categorize"] == 'on') {
 			if (in_array($categories[$i]["categId"], $_REQUEST["cat_categories"])) {
@@ -83,6 +88,29 @@ else {
 		}
 	}
 
+	include_once ('lib/tree/categ_picker_tree.php');
+	$tree_nodes = array();
+	$roots = $categlib->findRoots( $categories );
+	foreach ($categories as $c) {
+		if (isset($c['name']) || $c['parentId'] != 0) {
+			$smarty->assign( 'category_data', $c );
+			$tree_nodes[] = array(
+				'id' => $c['categId'],
+				'parent' => $c['parentId'],
+				'data' => $smarty->fetch( 'category_tree_entry.tpl' ),
+			);
+			if (in_array( $c['parentId'], $roots )) {
+				$tree_nodes[count($tree_nodes) - 1]['data'] = '<strong>'.$tree_nodes[count($tree_nodes) - 1]['data'].'</strong>';
+			}
+		}
+	}
+	$tm = new CatPickerTreeMaker("categorize");
+	$res = '';
+	foreach( $roots as $root ) {
+		$res .= $tm->make_tree($root, $tree_nodes);
+	}
+	$smarty->assign('cat_tree', $res);
+	
 	if (!empty($cats))
 		$smarty->assign('catsdump', implode(',',$cats));
 	$smarty->assign_by_ref('categories', $categories);
@@ -95,5 +123,3 @@ else {
 	}
 	$smarty->assign('cat_categorize', $cat_categorize);
 }
-
-?>
