@@ -19,7 +19,7 @@ require_once ('tiki-setup.php');
 include_once ('lib/banners/bannerlib.php');
 
 if (!isset($bannerlib)) {
-	$bannerlib = new BannerLib($dbTiki);
+	$bannerlib = new BannerLib;
 }
 
 // CHECK FEATURE BANNERS HERE
@@ -63,7 +63,4 @@ case 'useText':
 
 	break;
 }
-
 print ($raw);
-
-?>
