@@ -41,6 +41,7 @@ $langmapping = array(
     'ru' => array(  'Русский',      tra("Russian")      ),
     'sb' => array(  'Pijin Solomon', tra("Pijin Solomon")    ),
     'sk' => array(   'Slovenský',  tra("Slovak")       ),
+    'sl' => array(   'Slovenščina', tra('Slovene')       ),
     'sr' => array(   'Српски',  tra("Serbian")       ),
     'sr-latn' => array(   'Srpski',  tra("Serbian Latin")       ),
     'sv' => array(  'Svenska',      tra("Swedish")      ),
@@ -48,4 +49,3 @@ $langmapping = array(
     'tw' => array(  '正體中文',          tra("Traditional Chinese")          ),
     'uk' => array( 'Українська',     tra("Ukrainian")    )
 );
-?>
