@@ -6,25 +6,37 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   exit;
 }
 
-define('weekInSeconds', 604800);
+if (!defined('weekInSeconds')) define('weekInSeconds', 604800);
 
 class CalendarLib extends TikiLib {
-
-	function CalendarLib($db) {
-		$this->TikiLib($db);
+	function convertSortMode($sort_mode) {
+		$tmp = explode("_",$sort_mode);
+		if (count($tmp) == 2) {
+			if ($tmp[0] == "categoryName" || $tmp[0] == "locationName")
+				return "name " . $tmp[1];
+		}
+		return parent::convertSortMode($sort_mode);
 	}
- 
+
 	function list_calendars($offset = 0, $maxRecords = -1, $sort_mode = 'name_asc', $find = '') {
 		$mid = '';
 		$res = array();
 		$bindvars = array();
 		if ($find) {
-			$mid = "where `name` like ?";
+			$mid = "where tcal.`name` like ?";
 			$bindvars[] = '%'.$find.'%';
 		}
-		$query = "select * from `tiki_calendars` $mid order by ".$this->convert_sortmode($sort_mode);
+	
+		global $categlib; require_once( 'lib/categories/categlib.php' );
+		
+		$join = '';
+		if( $jail = $categlib->get_jail() ) {
+			$categlib->getSqlJoin($jail, 'calendar', 'tcal.`calendarId`', $join, $mid, $bindvars);
+		}	
+
+		$query = "select * from `tiki_calendars` as tcal $join where 1=1 $mid order by tcal.".$this->convertSortMode($sort_mode);
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
-		$query_cant = "select count(*) from `tiki_calendars` $mid";
+		$query_cant = "select count(*) from `tiki_calendars` as tcal $join where 1=1 $mid";
 		$cant = $this->getOne($query_cant,$bindvars);
 
 		$res = array();
@@ -154,7 +166,6 @@ class CalendarLib extends TikiLib {
 
 	/* tsart ans tstop are in user time - the data base is in server time */
 	function list_raw_items($calIds, $user, $tstart, $tstop, $offset, $maxRecords, $sort_mode='start_asc', $find='', $customs=array()) {
-		global $user;
 
 		if (sizeOf($calIds) == 0) {
 		    return array();
@@ -179,7 +190,19 @@ class CalendarLib extends TikiLib {
 		$bindvars[] = $user;
 
 		$query = "select i.`calitemId` as `calitemId` ";
-		$query .= "from `tiki_calendar_items` as i left join `tiki_calendars` as c on i.`calendarId`=c.`calendarId` where ($cond)  order by i.".$this->convert_sortmode("$sort_mode");
+		$queryCompl = "";
+		$joinCompl = "";
+		$tblRef = "i.";
+		if (substr($sort_mode,0,12) == "categoryName") {
+			$queryCompl = "`tiki_calendar_categories` as compl right join ";
+			$joinCompl = " on i.categoryId = compl.calcatid ";
+			$tblRef = "compl.";
+		} elseif (substr($sort_mode,0,12) == "locationName") {
+			$queryCompl = "`tiki_calendar_locations` as compl right join ";
+			$joinCompl = " on i.locationId = compl.callocid ";
+			$tblRef = "compl.";
+		}
+		$query .= "from " . $queryCompl . "`tiki_calendar_items` as i ".$joinCompl." left join `tiki_calendars` as c on i.`calendarId`=c.`calendarId` where ($cond)  order by ". $tblRef . $this->convertSortMode("$sort_mode");
 		$result = $this->query($query, $bindvars, $maxRecords, $offset);
 		$ret = array();
 		while ($res = $result->fetchRow()) {
@@ -189,7 +212,7 @@ class CalendarLib extends TikiLib {
 	}
 
 	function list_items($calIds, $user, $tstart, $tstop, $offset, $maxRecords, $sort_mode='start_asc', $find='', $customs=array()) {
-		global $user, $tiki_p_change_events, $prefs;
+		global $tiki_p_change_events, $prefs;
 		$ret = array();
 		$list = $this->list_raw_items($calIds, $user, $tstart, $tstop, $offset, $maxRecords, $sort_mode, $find, $customs);
 		foreach ($list as $res) {
@@ -231,7 +254,8 @@ class CalendarLib extends TikiLib {
 					"head" => $head,
 					"parsedDescription" => $this->parse_data($res["description"]),
 					"description" => str_replace("\n|\r", "", $res["description"]),
-					"calendarId" => $res['calendarId']
+					"calendarId" => $res['calendarId'],
+					"status" => $res['status']
 				);
 			}
 		}
@@ -239,7 +263,7 @@ class CalendarLib extends TikiLib {
 	}
 
 	function list_items_by_day($calIds, $user, $tstart, $tstop, $offset, $maxRecords, $sort_mode='start_asc', $find='', $customs=array()) {
-		global $user, $prefs;
+		global $prefs;
 		$ret = array();
 		$list = $this->list_raw_items($calIds, $user, $tstart, $tstop, $offset, $maxRecords, $sort_mode, $find, $customs);
 		foreach ($list as $res) {
@@ -252,7 +276,9 @@ class CalendarLib extends TikiLib {
 			$tend = TikiLib::date_format("%H%M", $res["end"]);
 			for ( $i = $dstart; $i <= $dend; $i = TikiLib::make_time(0, 0, 0, $mloop, ++$dloop, $yloop) ) {
 				/* $head is in user time */
-				if ($dstart == $dend) {
+				if ($res['allday'] == '1') {
+					$head = tra('All Day');
+				} elseif ($dstart == $dend) {
 					$head = TikiLib::date_format($prefs['short_time_format'], $res["start"]). " - " . TikiLib::date_format($prefs['short_time_format'], $res["end"]);
 				} elseif ($i == $dstart) {
 					$head = TikiLib::date_format($prefs['short_time_format'], $res["start"]). " ...";
@@ -263,7 +289,7 @@ class CalendarLib extends TikiLib {
 				}
 
 				/* $i is timestamp unix of the beginning of a day */
-				$j = is_array($ret[$i]) ? count($ret[$i]) : 0;
+				$j = (isset($ret[$i]) && is_array($ret[$i])) ? count($ret[$i]) : 0;
 
 				$ret[$i][$j] = $res;
 				$ret[$i][$j]['head'] = $head;
@@ -276,7 +302,7 @@ class CalendarLib extends TikiLib {
 				/*	'time' => $tstart, /* user time */
 				/*	'end' => $tend, /* user time */
 
-				$ret[$i][$j]['group_description'] = $res['name'].', '.$head;
+				$ret[$i][$j]['group_description'] = $res['name'].'<span class="calgrouptime">, '.$head.'</span>';
 			}
 		}
 		return $ret;
@@ -287,7 +313,7 @@ class CalendarLib extends TikiLib {
 
 		$query = "select i.`calitemId` as `calitemId`, i.`calendarId` as `calendarId`, i.`user` as `user`, i.`start` as `start`, i.`end` as `end`, t.`name` as `calname`, ";
 		$query.= "i.`locationId` as `locationId`, l.`name` as `locationName`, i.`categoryId` as `categoryId`, c.`name` as `categoryName`, i.`priority` as `priority`, i.`nlId` as `nlId`, ";
-		$query.= "i.`status` as `status`, i.`url` as `url`, i.`lang` as `lang`, i.`name` as `name`, i.`description` as `description`, i.`created` as `created`, i.`lastmodif` as `lastModif`, ";
+		$query.= "i.`status` as `status`, i.`url` as `url`, i.`lang` as `lang`, i.`name` as `name`, i.`description` as `description`, i.`created` as `created`, i.`lastmodif` as `lastModif`, i.`allday` as `allday`, i.`recurrenceId` as `recurrenceId`, ";
 		$query.= "t.`customlocations` as `customlocations`, t.`customcategories` as `customcategories`, t.`customlanguages` as `customlanguages`, t.`custompriorities` as `custompriorities`, ";
 		$query.= "t.`customsubscription` as `customsubscription`, ";
 		$query.= "t.`customparticipants` as `customparticipants` ";
@@ -325,7 +351,7 @@ class CalendarLib extends TikiLib {
 	}
 
 	function set_item($user, $calitemId, $data, $customs=array()) {
-		global $user, $prefs;
+		global $prefs;
 		if (!isset($data['calendarId'])) {
 			return false;
 		}
@@ -412,10 +438,13 @@ class CalendarLib extends TikiLib {
 			$data['nlId'] = 0;
 		}
 
+		if (!isset($data['recurrenceId']) || !($data['recurrenceId'] > 0))
+			$data['recurrenceId'] = null;
+
 		$data['user']=$user;
 
 		$realcolumns=array('calitemId', 'calendarId', 'start', 'end', 'locationId', 'categoryId', 'nlId','priority',
-				   'status', 'url', 'lang', 'name', 'description', 'user', 'created', 'lastmodif');
+				   'status', 'url', 'lang', 'name', 'description', 'user', 'created', 'lastmodif', 'allday','recurrenceId','changed');
 		foreach($customs as $custom) $realcolumns[]=$custom;
 
 		if ($calitemId) {
@@ -448,7 +477,7 @@ class CalendarLib extends TikiLib {
 			    if (!in_array($k, $realcolumns)) continue;
 			    $l[]="`$k`";
 			    $z[]='?';
-			    $r[]=$v;
+			    $r[]=($k=='priority')?(string)$v:$v;
 			}
 
 			$query = 'INSERT INTO `tiki_calendar_items` ('.implode(',', $l).') VALUES ('.implode(',', $z).')';
@@ -543,7 +572,7 @@ class CalendarLib extends TikiLib {
 			$bindvars = array();
 		}
 				
-		$query = "select `start`, `name`, `calitemId`, `calendarId`, `user`, `lastModif` from `tiki_calendar_items` ".$cond."order by ".$this->convert_sortmode('lastModif_desc');
+		$query = "select `start`, `name`, `calitemId`, `calendarId`, `user`, `lastModif` from `tiki_calendar_items` ".$cond."order by ".$this->convertSortMode('lastModif_desc');
 	
 		$result = $this->query($query,$bindvars,$maxrows,0);
 		
@@ -557,36 +586,53 @@ class CalendarLib extends TikiLib {
 	}
 	
 	function importCSV($fname, $calendarId) {
-		global $user;
-		$fhandle = fopen($fname, "r");
-		$fields = fgetcsv($fhandle, 1000);
+		global $user, $smarty;
+		$fields = false;
+		if ($fhandle = fopen($fname, 'r')) {
+			$fields = fgetcsv($fhandle, 1000);
+		}
 		if ($fields === false) {
 			$smarty->assign('msg', tra("The file is not a CSV file or has not a correct syntax"));
 			$smarty->display("error.tpl");
 			die;
 		}
-
-		while (!feof($fhandle)) {
-			$data = fgetcsv($fhandle, 1000);
+		$nb = 0;
+		while (($data = fgetcsv($fhandle, 1000)) !== FALSE) {
 			$d = array("calendarId"=>$calendarId, "calitemId"=>"0", "name"=>"", "description" =>"", "locationId"=>"", 
-					"organizers"=>"", "participants"=>"","status"=>"0","priority"=>"5","categoryId"=>"0","newloc"=>"0","newcat"=>"","nlId"=>"","lang"=>"");
+					   "organizers"=>"", "participants"=>"","status"=>"0","priority"=>"5","categoryId"=>"0","newloc"=>"0","newcat"=>"","nlId"=>"","lang"=>"", 'start'=>'', 'end'=>'');
 			foreach ($fields as $field) {
-				$d[strtolower($field)] = $data[array_search($field, $fields)];
+				$d[$field] = $data[array_search($field, $fields)];
 			}
 			if (isset($d["subject"]) && empty($d["name"]))
 				$d["name"] = $d["subject"];
-			if (isset($d["start date"]) && isset($d["start time"]))
-				$d["start"] = strtotime($d["start time"], strtotime($d["start date"]));
-			if (isset($d["end date"]) && isset($d["end time"]))
-				$d["end"] = strtotime($d["end time"], strtotime($d["end date"]));
+			if (isset($d['start date'])) {
+				if (isset($d['start time'])) {
+					$d['start'] = strtotime($d['start time'], strtotime($d['start date']));
+				} else {
+					$d['start'] = strtotime($d['start date']);
+				}
+			}
+			if (isset($d['end date'])) {
+				echo 'fff';
+				if (isset($d['end time'])) {
+					$d['end'] = strtotime($d['end time'], strtotime($d['end date']));
+				} else {
+					$d['end'] = strtotime($d['end date']);
+				}
+			}
 // TODO do a replace if name, calendarId, start, end exists
-			$this->set_item($user, 0, $d);
+			if (!empty($d['start']) && !empty($d['end'])) {		
+				$this->set_item($user, 0, $d);
+				++$nb;
+			}
 		}
 		fclose ($fhandle);
-		return true;
+		return $nb;
 	}
 
-	function upcoming_events($maxrows = -1, $calendarId = 0, $maxDays = -1, $order = 'start_asc') {
+	// Returns an array of a maximum of $maxrows upcoming (but possibly past) events in the given $order. If $calendarId is set, events not in the specified calendars are filtered. $calendarId can be a calendar identifier or an array of calendar identifiers. If $maxDaysEnd is a natural, events ending after $maxDaysEnd days are filtered. If $maxDaysStart is a natural, events starting after $maxDaysStart days are filtered. Events ending more than $priorDays in the past are filtered.
+	// Each event is represented by a string-indexed array with indices start, end, name, description, calitemId, calendarId, user, lastModif, url, allday in the same format as tiki_calendar_items fields, as well as location for the event's locations, parsed for the parsed description and category for the event's calendar category.
+	function upcoming_events($maxrows = -1, $calendarId = 0, $maxDaysEnd = -1, $order = 'start_asc', $priorDays = 0, $maxDaysStart = -1) {
 		$cond = '';
 		$bindvars = array();
 		if(is_array($calendarId) && count($calendarId) > 0) {
@@ -595,24 +641,32 @@ class CalendarLib extends TikiLib {
 				$cond = $cond." or i.`calendarId` = ? ";
 			}
 			$cond = $cond.")";
-			$bindvars += $calendarId;
+			$bindvars = array_merge( $bindvars, $calendarId );
 		} elseif (!is_array($calendarId) and $calendarId > 0) {
 			$cond = $cond." and i.`calendarId` = ? ";
-			$bindvars += array($calendarId);
+			$bindvars[] = $calendarId;
 		}
-		$cond .= " and `end` >= (unix_timestamp(now()))";
-		if($maxDays > 0)
+		$cond .= " and `end` >= (unix_timestamp(now()) - ?*3600*34)";
+		$bindvars[] = $priorDays;
+
+		if($maxDaysEnd > 0)
 		{
-			$maxSeconds = ($maxDays * 24 * 60 * 60);
+			$maxSeconds = ($maxDaysEnd * 24 * 60 * 60);
 			$cond .= " and `end` <= (unix_timestamp(now())) +".$maxSeconds;
 		}
+		if ($maxDaysStart > 0)
+		{
+			$maxSeconds = ($maxDaysStart * 24 * 60 * 60);
+			$cond .= " and `start` <= (unix_timestamp(now())) +".$maxSeconds;
+		}
 		$ljoin = "left join `tiki_calendar_locations` as l on i.`locationId`=l.`callocId` left join `tiki_calendar_categories` as c on i.`categoryId`=c.`calcatId`";
-		$query = "select i.`start`, i.`end`, i.`name`, i.`description`, i.`calitemId`, i.`calendarId`, i.`user`, i.`lastModif`, i.`url`, l.`name` as location, c.`name` as category from `tiki_calendar_items` i $ljoin where 1=1 ".$cond." order by ".$this->convert_sortmode($order);
+		$query = "select i.`start`, i.`end`, i.`name`, i.`description`, i.`calitemId`, i.`calendarId`, i.`user`, i.`lastModif`, i.`url`, l.`name` as location, i.`allday`, c.`name` as category from `tiki_calendar_items` i $ljoin where 1=1 ".$cond." order by ".$this->convertSortMode($order);
 		$result = $this->query($query,$bindvars,$maxrows,0);
 			
 		$ret = array();
 			
 		while ($res = $result->fetchRow()) {
+			$res['parsed'] = $this->parse_data($res['description']);
 			$ret[] = $res;
 		}
 	
@@ -647,6 +701,7 @@ class CalendarLib extends TikiLib {
 		if ( $display_tz == '' ) $display_tz = 'UTC';
 		$curtikidate->setTZbyID($display_tz);
 		$curtikidate->setLocalTime($dloop,$mloop,$yloop,0,0,0,0);
+		$listevents = array();
 	
 		// note that number of weeks starts at ZERO (i.e., zero = 1 week to display).
 		for ($i = 0; $i <= $numberofweeks; $i++) {
@@ -675,7 +730,7 @@ class CalendarLib extends TikiLib {
 	
 					foreach ( $listtikievents["$dday"] as $lte ) {
 						$lte['desc_name'] = $lte['name'];
-						if ( $calendarGroupByItem != 'n' ) {
+						if ( $group_by_item != 'n' ) {
 							if ( $group_by != 'day' ) $key = $lte['id'].'|'.$lte['type'];
 							if ( ! isset($leday[$key]) ) {
 								$leday[$key] = $lte;
@@ -691,7 +746,7 @@ class CalendarLib extends TikiLib {
 								$leday_item =& $leday[$key];
 								$leday_item['user'] .= ', '.$lte['user'];
 	
-								if ( ! is_integer($leday_item['action']) ) {
+								if ( !isset($leday_item['action']) || !is_integer($leday_item['action']) ) {
 									$leday_item['action'] = 1;
 								}
 								$leday_item['action']++;
@@ -716,9 +771,8 @@ class CalendarLib extends TikiLib {
 							$lte['desc_name'] .= tra($lte['action']);
 						}
 					}
-	
 					foreach ( $leday as $key => $lte ) {
-
+			
 						if ( $group_by == 'day' ) {
 							$desc = '';
 							foreach ( $lte['description'] as $desc_where => $desc_items ) {
@@ -726,12 +780,16 @@ class CalendarLib extends TikiLib {
 								foreach ( $desc_items as $desc_item ) {
 									if ( $desc != '' ) $desc .= '<br />';
 									$desc .= '- '.$desc_item;
-									if ( $desc_where != '' ) $desc .= ' <i>['.$desc_where.']</i>';
+									if (!empty($lte['show_location']) && $lte['show_location'] == 'y' && $desc_where != '' ) {
+										$desc .= ' <i>['.$desc_where.']</i>';
+									}
 								}
 							}
 							$lte['description'] = $desc;
 						}
-	
+
+						$smarty->assign('calendar_type', ( $myurl == 'tiki-action_calendar.php' ? 'tiki_actions' : 'calendar' ) );
+						$smarty->assign_by_ref('item_url', $lte["url"]);
 						$smarty->assign_by_ref('cellhead', $lte["head"]);
 						$smarty->assign_by_ref('cellprio', $lte["prio"]);
 						$smarty->assign_by_ref('cellcalname', $lte["calname"]);
@@ -758,7 +816,7 @@ class CalendarLib extends TikiLib {
 			}
 		}
 
-		if ( $_SESSION['CalendarViewList'] == 'list' ) {
+		if ( isset($_SESSION['CalendarViewList']) && $_SESSION['CalendarViewList'] == 'list' ) {
 			if ( is_array($listtikievents) ) {
 				foreach ( $listtikievents as $le ) {
 					if ( is_array($le) ) {
@@ -776,11 +834,9 @@ class CalendarLib extends TikiLib {
 			'weeks' => $weeks,
 			'weekdays' => $weekdays,
 			'daysnames' => $daysnames,
+			'daysnames_abr' => $daysnames_abr,
 			'trunc' => $trunc
 		);
 	}
 }
-global $dbTiki;
-$calendarlib = new CalendarLib($dbTiki);
-
-?>
+$calendarlib = new CalendarLib;
