@@ -8,10 +8,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 class DirLib extends TikiLib {
-	function DirLib($db) {
-		$this->TikiLib($db);
-	}
-
 	// Path functions
 	function dir_get_category_path_admin($categId) {
 		global $prefs;
@@ -39,10 +35,10 @@ class DirLib extends TikiLib {
 		global $prefs;
 		$path = '';
 		$info = $this->dir_get_category($categId);
-		$path = '<a class="dirlink" href="tiki-directory_browse.php?parent=' . $info["categId"] . '">' . $info["name"] . '</a>';
+		$path = '<a class="dirlink" href="tiki-directory_browse.php?parent=' . $info["categId"] . '">' . htmlspecialchars($info["name"]) . '</a>';
 		while ($info["parent"] != 0) {
 			$info = $this->dir_get_category($info["parent"]);
-			$path = '<a class="dirlink" href="tiki-directory_browse.php?parent=' . $info["categId"] . '">' . $info["name"] . '</a> ' . $prefs['site_crumb_seper'] . ' ' . $path;
+			$path = '<a class="dirlink" href="tiki-directory_browse.php?parent=' . $info["categId"] . '">' . htmlspecialchars($info["name"]) . '</a> ' . $prefs['site_crumb_seper'] . ' ' . $path;
 		}
 
 		return $path;
@@ -106,7 +102,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_categories` where `parent`=? $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_categories` where `parent`=? $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_categories` where `parent`=? $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -114,34 +110,9 @@ class DirLib extends TikiLib {
 
 		while ($res = $result->fetchRow()) {
 			$res["sites"] = $this->getOne("select count(*) from `tiki_category_sites` where `categId`=?",array((int)$res["categId"]));
-			//$res["path"]=$this->dir_get_path_text($res["categId"]);
 
-		    $add = TRUE;
-		    global $prefs, $userlib, $user, $tiki_p_admin;
-
-		    if ($tiki_p_admin != 'y' && $prefs['feature_categories'] == 'y') {
-		    	global $categlib;
-				if (!is_object($categlib)) {
-					include_once('lib/categories/categlib.php');
-				}
-		    	unset($tiki_p_view_categorized); // unset this var in case it was set previously
-		    	$perms_array = $categlib->get_object_categories_perms($user, 'directory', $res['categId']);
-		    	if ($perms_array) {
-		    		$is_categorized = TRUE;
-			    	foreach ($perms_array as $perm => $value) {
-			    		$$perm = $value;
-			    	}
-		    	} else {
-		    		$is_categorized = FALSE;
-		    	}
-
-		    	if ($is_categorized && isset($tiki_p_view_categorized) && $tiki_p_view_categorized != 'y') {
-		    		$add = FALSE;
-		    	}
-		    }
-		    if ($add) {
-				$ret[] = $res;
-		    }
+			// TODO : Any permission to check? Used to verify view_categorized when categorized, what is the real permission?
+			$ret[] = $res;
 		}
 
 		$retval = array();
@@ -161,7 +132,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_categories` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_categories` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_categories` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -193,7 +164,7 @@ class DirLib extends TikiLib {
 			$mid .= " and `isValid`=? ";
 			$bindvars[] = $isValid;
 		}
-		$query = "select * from `tiki_directory_sites` tds, `tiki_category_sites` tcs where tds.`siteId`=tcs.`siteId` and tcs.`categId`=? $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_sites` tds, `tiki_category_sites` tcs where tds.`siteId`=tcs.`siteId` and tcs.`categId`=? $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_sites` tds, `tiki_category_sites` tcs where tds.`siteId`=tcs.`siteId` and tcs.`categId`=? $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -220,7 +191,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_sites` where `isValid`=? $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_sites` where `isValid`=? $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_sites` where `isValid`=? $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -258,7 +229,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_sites` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_sites` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_sites` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -284,7 +255,7 @@ class DirLib extends TikiLib {
 			$bindvars[] = $findesc;
 		}
 
-		$query = "select * from `tiki_directory_sites` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_sites` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_sites` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -310,7 +281,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_categories` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_categories` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_categories` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -320,7 +291,7 @@ class DirLib extends TikiLib {
 			$res["path"] = $this->dir_get_path_text($res["categId"]);
 			$res["belongs"] = 'n';
 			if ($siteId) {
-				$belongs = $this->db->getOne( "select count(*) from `tiki_category_sites` where `siteId`=? and `categId`=?",array((int)$siteId,(int)$res["categId"]));
+				$belongs = $this->getOne( "select count(*) from `tiki_category_sites` where `siteId`=? and `categId`=?",array((int)$siteId,(int)$res["categId"]));
 				if ($belongs) {
 					$res["belongs"] = 'y';
 				}
@@ -341,7 +312,7 @@ class DirLib extends TikiLib {
 		} else {
 			$mid = "";
 		}
-		$query = "select * from `tiki_directory_categories` where `categId`<>? $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_directory_categories` where `categId`<>? $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_directory_categories` where `categId`<>? $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -373,12 +344,12 @@ class DirLib extends TikiLib {
 		$ret = array();
 
 		while ($res = $result->fetchRow()) {
-			$res["sites"] = $this->db->getOne("select count(*) from `tiki_category_sites` where `categId`=" . $res["categId"]);
+			$res["sites"] = $this->getOne("select count(*) from `tiki_category_sites` where `categId`=" . $res["categId"]);
 			$res["path"] = $this->dir_get_path_text($res["categId"]);
 			$res["belongs"] = 'n';
 
 			if ($siteId) {
-				$belongs = $this->db->getOne( "select count(*) from `tiki_category_sites` where `siteId`=? and `categId`=?",array((int)$siteId,(int)$res["categId"]));
+				$belongs = $this->getOne( "select count(*) from `tiki_category_sites` where `siteId`=? and `categId`=?",array((int)$siteId,(int)$res["categId"]));
 				if ($belongs) {
 					$res["belongs"] = 'y';
 				}
@@ -397,10 +368,10 @@ class DirLib extends TikiLib {
 	function dir_replace_site($siteId, $name, $description, $url, $country, $isValid) {
 		global $prefs;
 
-		make_clean($name);
-		make_clean($description);
-		make_clean($url);
-		make_clean($country);
+		$name = TikiFilter::get('striptags')->filter( $name );
+		$description = TikiFilter::get('striptags')->filter( $description );
+		$url = TikiFilter::get('url')->filter( $url );
+		$country = TikiFilter::get('word')->filter( $country );
 
 		if ($siteId) {
 			$query = "update `tiki_directory_sites` set `name`=?, `description`=?, `url`=?, `country`=?, `isValid`=?, `lastModif`=?  where `siteId`=?";
@@ -408,7 +379,7 @@ class DirLib extends TikiLib {
 		} else {
 			$query = "insert into `tiki_directory_sites`(`name`,`description`,`url`,`country`,`isValid`,`hits`,`created`,`lastModif`) values(?,?,?,?,?,?,?,?)";
 			$this->query($query,array($name,$description,$url,$country,$isValid,0,(int)$this->now,(int)$this->now));
-			$siteId = $this->db->getOne("select max(siteId) from `tiki_directory_sites` where `created`=? and `name`=?",array((int)$this->now,$name));
+			$siteId = $this->getOne("select max(siteId) from `tiki_directory_sites` where `created`=? and `name`=?",array((int)$this->now,$name));
 
 			if ($prefs['cachepages'] == 'y') {
 				$this->cache_url($url);
@@ -499,7 +470,7 @@ class DirLib extends TikiLib {
 				$siteId = $res2["siteId"];
 				$query3 = "delete from `tiki_category_sites` where `siteId`=? and `categId`=?";
 				$result3 = $this->query($query3,array((int)$siteId,(int)$categId));
-				$cant = $this->db->getOne("select count(*) from `tiki_category_sites` where `siteId`=?",array((int)$siteId));
+				$cant = $this->getOne("select count(*) from `tiki_category_sites` where `siteId`=?",array((int)$siteId));
 				if (!$cant) {
 					$this->dir_remove_site($siteId);
 				}
@@ -544,7 +515,7 @@ class DirLib extends TikiLib {
 	}
 
 	function dir_url_exists($url) {
-		$cant = $this->db->getOne("select count(*) from `tiki_directory_sites` where `url`=?",array($url));
+		$cant = $this->getOne("select count(*) from `tiki_directory_sites` where `url`=?",array($url));
 		return $cant;
 	}
 
@@ -575,7 +546,7 @@ class DirLib extends TikiLib {
 			$word = $words[$i];
 			if (!empty($word)) {
 				// Check if the term is in the stats then add it or increment it
-				if ($this->db->getOne("select count(*) from `tiki_directory_search` where `term`=?",array($word))) {
+				if ($this->getOne("select count(*) from `tiki_directory_search` where `term`=?",array($word))) {
 					$query = "update `tiki_directory_search` set `hits`=`hits`+1 where `term`=?";
 					$this->query($query,array($word));
 				} else {
@@ -591,8 +562,8 @@ class DirLib extends TikiLib {
 		}
 
 		$words = implode($how, $words);
-		$query = "select * from `tiki_directory_sites` where `isValid`=? and $words  order by ".$this->convert_sortmode($sort_mode);
-		$cant = $this->db->getOne("select count(*) from tiki_directory_sites where `isValid`=? and $words", $bindvars);
+		$query = "select * from `tiki_directory_sites` where `isValid`=? and $words  order by ".$this->convertSortMode($sort_mode);
+		$cant = $this->getOne("select count(*) from tiki_directory_sites where `isValid`=? and $words", $bindvars);
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$ret = array();
 		while ($res = $result->fetchRow()) {
@@ -614,7 +585,7 @@ class DirLib extends TikiLib {
 			$words[$i] = trim($words[$i]);
 			$word = $words[$i];
 			// Check if the term is in the stats then add it or increment it
-			if ($this->db->getOne("select count(*) from `tiki_directory_search` where `term`=?",array($word))) {
+			if ($this->getOne("select count(*) from `tiki_directory_search` where `term`=?",array($word))) {
 				$query = "update `tiki_directory_search` set `hits`=`hits`+1 where `term`=?";
 				$this->query($query,array($word));
 			} else {
@@ -631,8 +602,8 @@ class DirLib extends TikiLib {
 		$words = implode($how, $words);
 		$query = "select distinct tds.`name`, tds.`siteId`, tds.`description`, tds.`url`, tds.`country`, tds.`hits`, ";
 		$query.= " tds.`created`, tds.`lastModif` from `tiki_directory_sites` tds, `tiki_category_sites` tcs, `tiki_directory_categories` tdc ";
-		$query.= " where tds.`siteId`=tcs.`siteId` and tcs.`categId`=tdc.`categId` and `isValid`=? and tdc.`categId`=? and $words order by ".$this->convert_sortmode($sort_mode);
-		$cant = $this->db->getOne("select count(*) from `tiki_directory_sites` tds,`tiki_category_sites` tcs,`tiki_directory_categories` tdc 
+		$query.= " where tds.`siteId`=tcs.`siteId` and tcs.`categId`=tdc.`categId` and `isValid`=? and tdc.`categId`=? and $words order by ".$this->convertSortMode($sort_mode);
+		$cant = $this->getOne("select count(*) from `tiki_directory_sites` tds,`tiki_category_sites` tcs,`tiki_directory_categories` tdc 
 			where tds.`siteId`=tcs.`siteId` and tcs.`categId`=tdc.`categId` and `isValid`=? and tdc.`categId`=? and $words",$bindvars);
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$ret = array();
@@ -647,12 +618,9 @@ class DirLib extends TikiLib {
 	}
 
 }
-global $dbTiki;
-$dirlib = new DirLib($dbTiki);
+$dirlib = new DirLib;
 
 function compare_paths($p1, $p2) {
 		// must be case insentive to have the same than dir_mist_sites
 	return strcasecmp($p1["path"], $p2["path"]);
 }
-
-?>
