@@ -85,8 +85,8 @@ class FreetagLib extends ObjectLib {
      * Constructor for the freetag class. 
      *
      */ 
-	function FreetagLib($db) {
-		$this->ObjectLib($db);
+	function __construct() {
+		parent::__construct();
 
 		// update private vars with tiki preferences
 		global $prefs;
@@ -144,7 +144,7 @@ class FreetagLib extends ObjectLib {
 	$query = "SELECT DISTINCT o.* ";
 	$query_cant = "SELECT COUNT(*) ";
 	
-	$query_end = "FROM `tiki_objects` o, `tiki_freetagged_objects` fto, `tiki_freetags` t WHERE fto.`tagId`=t.`tagId` AND o.`objectId` = fto.`objectId` AND `tag` = ? $mid ORDER BY o.". $this->convert_sortmode($sort_mode);
+	$query_end = "FROM `tiki_objects` o, `tiki_freetagged_objects` fto, `tiki_freetags` t WHERE fto.`tagId`=t.`tagId` AND o.`objectId` = fto.`objectId` AND `tag` = ? $mid ORDER BY o.". $this->convertSortMode($sort_mode);
 
 	
 	
@@ -187,7 +187,9 @@ class FreetagLib extends ObjectLib {
      * 
      */
     
-function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0, $maxRecords = -1, $sort_mode = 'name_asc', $find = '', $broaden = 'n') {
+function get_objects_with_tag_combo($tagArray, $type='', $thisUser = '', $offset = 0, $maxRecords = -1, $sort_mode = 'name_asc', $find = '', $broaden = 'n') {
+	global $categlib; include_once('lib/categories/categlib.php');
+	global $tiki_p_admin, $user, $smarty;
 	if (!isset($tagArray) || !is_array($tagArray)) {
 	    return false;
 	}
@@ -201,9 +203,9 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 	
 	$numTags = count($tagArray);
 		
-	if (isset($user) && !empty($user)) {
+	if (isset($thisUser) && !empty($thisUser)) {
 	    $mid = "AND `user` = ?";
-	    $bindvals[] = $user;
+	    $bindvals[] = $thisUser;
 	} else {
 	    $mid = '';
 	}
@@ -218,9 +220,9 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 		$bindvals_t = $bindvals;		
 		$mid_t = '';
 
-		if (isset($user) && !empty($user)) {
+		if (isset($thisUser) && !empty($thisUser)) {
 	    	$mid_t = "AND `user` = ?";
-	    	$bindvals_t[] = $user;	
+	    	$bindvals_t[] = $thisUser;	
 		}	
 	
 		if (isset($type) && !empty($type)) {
@@ -268,9 +270,9 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 	
 	$mid = '';
 
-	if (isset($user) && !empty($user)) {
+	if (isset($thisUser) && !empty($thisUser)) {
 	    $mid = "AND `user` = ?";
-	    $bindvals[] = $user;	
+	    $bindvals[] = $thisUser;	
 	}	
 	
 	if (isset($type) && !empty($type)) {
@@ -296,21 +298,46 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 	$query_cant = "SELECT COUNT(DISTINCT o.`objectId`) ";
 	
 	$query_end = "FROM `tiki_objects` o, `tiki_freetagged_objects` fto, `tiki_freetags` t 
-	WHERE fto.`tagId`=t.`tagId` AND o.`objectId` = fto.`objectId` AND $tag_sql $mid ORDER BY ". $this->convert_sortmode($sort_mode);
+	WHERE fto.`tagId`=t.`tagId` AND o.`objectId` = fto.`objectId` AND $tag_sql $mid ORDER BY ". $this->convertSortMode($sort_mode);
 	// note the original line was originally here to fix ambiguous 'created' column for default sort. Not a neat fix the o. prefix is ugly.	So changed default order instead.
 	
 	$query      .= $query_end;
 	$query_cant .= $query_end;	
 	
 	$result = $this->query($query, $bindvals, $maxRecords, $offset);
-	
-	$ret = array();
-	while ($row = $result->fetchRow()) {
-	    $ret[] = $row;
-	}
-	
 	$cant = $this->getOne($query_cant, $bindvals);
 	
+	$ret = array();
+	$permMap = $categlib->map_object_type_to_permission();
+	while ($row = $result->fetchRow()) {
+		$ok = false;
+		if ($tiki_p_admin == 'y') { 
+			$ok = true;
+		} elseif ($row['type'] == 'blog post') {
+			global $bloglib; include_once('lib/blogs/bloglib.php');
+			$post_info = $bloglib->get_post($row['itemId']);
+			if ($this->user_has_perm_on_object($user, $post_info['blogId'], 'blog', 'tiki_p_read_blog')) {
+				$ok = true;
+			}
+		} elseif ($this->user_has_perm_on_object($user, $row['itemId'], $row['type'], $permMap[$row['type']])) {
+			$ok = true;
+		}
+		if ($ok) {
+			if ($prefs['feature_sefurl'] == 'y') {
+				include_once('tiki-sefurl.php');
+				if ($row['type'] == 'blog post' && !empty($post_info)) {
+					$row['href'] = filter_out_sefurl($row['href'], $smarty, 'blogpost', $post_info['title']);
+				} else {
+					$type = ($row['type'] == 'wiki page')?'wiki':($row['type'] == 'blog post'? 'blogpost': $row['type']);
+					$row['href'] = filter_out_sefurl($row['href'], $smarty, $type);
+				}
+			}
+			$ret[] = $row;
+		} else {
+			-- $cant;
+		}
+	}
+
 	return array('data' => $ret,
 		     'cant' => $cant);
     }
@@ -392,7 +419,7 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
      *	 - 'user' => The unique ID of the person who tagged the object with this tag.
      */ 
 	function get_tags_on_object($itemId, $type, $offset = 0, $maxRecords = -1, $user = NULL) {
-		if (!isset($itemId) || !isset($type) || empty($itemId) || empty($type)) {
+		if (!isset($itemId) || !isset($type) || empty($itemId) || empty($type) || is_array($itemId) || !is_string($type)) {
 			return false;
 		}
 
@@ -810,6 +837,10 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 	} else {
 	    $query = trim($tag_string);
 	}
+
+	$query = preg_replace('/[<>&;#%!*"]/','',$query);
+	$query = strip_tags(htmlspecialchars($query, ENT_COMPAT));
+
 	$words = preg_split('/(")/', $query,-1,PREG_SPLIT_NO_EMPTY|PREG_SPLIT_DELIM_CAPTURE);
 	$delim = 0;
 	$newwords = array();
@@ -895,7 +926,11 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 	$count = array();
 
 	while ($row = $result->fetchRow()) {
-	    $size[] = $row['size'] = ceil($this->max_cloud_text_size * $row['count'] / $top);
+	    $row['size'] =  ceil(1 +(1+ $row['count'] / $top)*log(1+$row['count']));
+		if ($row['size'] > $this->max_cloud_text_size) {
+			$row['size'] = $this->max_cloud_text_size;
+		}
+		$size[] = $row['size'];
 	    $tag[] = $row['tag'];
 	    $count[] = $row['count'];
 
@@ -923,7 +958,7 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
      */
 
     function get_tag_suggestion($exclude = '', $max = 10, $lang = null) {
-	$query = "select t.* from `tiki_freetags` t, `tiki_freetagged_objects` o where t.`tagId`=o.`tagId` and (`lang` = ? or `lang` is null) order by " . $this->convert_sortmode('random');
+	$query = "select t.* from `tiki_freetags` t, `tiki_freetagged_objects` o where t.`tagId`=o.`tagId` and (`lang` = ? or `lang` is null) order by " . $this->convertSortMode('random');
 	$result = $this->query($query, array( $lang ));
 
 	$tags = array();
@@ -1121,9 +1156,8 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 					cnt >= ?
 				ORDER BY
 					cnt DESC, RAND()
-				LIMIT ?
 				";
-			
+			break;
 		// }}}
 
 		case 'weighted': // {{{
@@ -1146,16 +1180,14 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 					having_cnt >= ?
 				ORDER BY					
 					sort_cnt DESC, RAND()
-				LIMIT ?
 				";	
 			// Sort based on the global popularity of all tags in common
 		// }}}
 		}
 		
 		$bindvals[] = $minCommon;
-		$bindvals[] = $maxResults;
 		
-		$result = $this->query( $query, $bindvals );
+		$result = $this->query( $query, $bindvals, $maxResults );
 		$tags = array();
 		while( $row = $result->fetchRow() )
 			$tags[] = $row;
@@ -1172,11 +1204,12 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
     
 	function cleanup_tags() {
 		$this->query( "
-			DELETE FROM tiki_freetagged_objects WHERE tagId NOT IN(SELECT tagId FROM tiki_freetags)" );
+			DELETE FROM `tiki_freetagged_objects` WHERE `tagId` NOT IN(SELECT `tagId` FROM `tiki_freetags`)" );
+		$this->query('delete tfo from `tiki_freetagged_objects` tfo left join `tiki_objects` tob on (tob.`objectId`=tfo.`objectId`) where tob.`objectId` is null');
 		$this->query( "
-			DELETE FROM tiki_freetags 
-			WHERE tagId NOT IN(SELECT tagId FROM tiki_freetagged_objects)
-				AND tagId NOT IN(SELECT objId FROM tiki_translated_objects WHERE type = 'freetag')" );
+			DELETE FROM `tiki_freetags` 
+			WHERE `tagId` NOT IN(SELECT `tagId` FROM `tiki_freetagged_objects`)
+				AND `tagId` NOT IN(SELECT `objId` FROM `tiki_translated_objects` WHERE type = 'freetag')" );
 	    return true;
 	 }
 
@@ -1318,7 +1351,4 @@ function get_objects_with_tag_combo($tagArray, $type='', $user = '', $offset = 0
 		$this->cleanup_tags();
 	}
 }
-
-global $dbTiki;
-$freetaglib = new FreetagLib($dbTiki);
-?>
+$freetaglib = new FreetagLib;
