@@ -9,9 +9,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 class LogsLib extends TikiLib {
 
-	function LogsLib($db) {
-		$this->TikiLib($db);
-	}
 
 	function add_log($type,$message,$who='',$ip='',$client='',$time='') {
 		global $user;
@@ -23,7 +20,7 @@ class LogsLib extends TikiLib {
 			}
 		}
 		if (!$ip) {
-			$ip = $_SERVER['REMOTE_ADDR'];
+			$ip = $this->get_ip_address();
 		}
 		if (!$client) {
 			if (!$_SERVER['HTTP_USER_AGENT']) {
@@ -45,7 +42,8 @@ class LogsLib extends TikiLib {
 		$mid = '';
 		if ($find) {
 			$findesc = '%'.$find.'%';
-			$amid[] = "`logmessage` like ? or `loguser` like ?";
+			$amid[] = "`logmessage` like ? or `loguser` like ? or 'logip' like ?";
+			$bindvars[] = $findesc;
 			$bindvars[] = $findesc;
 			$bindvars[] = $findesc;
 		}
@@ -76,7 +74,7 @@ class LogsLib extends TikiLib {
 			$mid = " where ".implode(" and ",$amid)." ";
 		}
 		$query = "select `logId`,`loguser`,`logtype`,`logmessage`,`logtime`,`logip`,`logclient` ";
-		$query.= " from `tiki_logs` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query.= " from `tiki_logs` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_logs` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -112,7 +110,7 @@ class LogsLib extends TikiLib {
 		if ($who == '')
 			$who = $user;
 		if ($ip == '')
-			$ip = $_SERVER['REMOTE_ADDR'];;
+			$ip = $this->get_ip_address();
 		if ($client == '')
 			$client = $_SERVER['HTTP_USER_AGENT'];
 		if ($logCateg) {
@@ -161,7 +159,7 @@ class LogsLib extends TikiLib {
 				}
 			}
 		}
-		return  $actions[0];
+		return  isset($actions[0])? $actions[0]: 0;
 	}
 	function action_must_be_logged($action, $objectType) {
 		global $prefs;
@@ -289,7 +287,7 @@ class LogsLib extends TikiLib {
 		} else {
 			$query = "select a.* from `tiki_actionlog` a ,`tiki_actionlog_conf` c where $mid";
 		}
-		$query .= " order by ".$this->convert_sortmode($sort_mode);
+		$query .= " order by ".$this->convertSortMode($sort_mode);
 		$result = $this->query($query, $bindvars, $maxRecords, $offset);
 		$ret = array();
 		while ($res = $result->fetchRow()) {
@@ -607,12 +605,21 @@ class LogsLib extends TikiLib {
 	}
 	return $csv;
 	}
-	function get_action_params($actionId, $name) {
-		$query = "select `value` from `tiki_actionlog_params` where `actionId`=? and `name`=?";
-		$result = $this->query($query, array($actionId, $name));
-		$ret = array();
-		while ($res = $result->fetchRow()) {
-			$ret[] = $res['value'];
+	function get_action_params($actionId, $name='') {
+		if (empty($name)) {
+			$query = "select * from `tiki_actionlog_params` where `actionId`=?";
+			$result = $this->query($query, array($actionId));
+			$ret = array();
+			while ($res = $result->fetchRow()) {
+				$ret[] = $res;
+			}
+		} else {
+			$query = "select `value` from `tiki_actionlog_params` where `actionId`=? and `name`=?";
+			$result = $this->query($query, array($actionId, $name));
+			$ret = array();
+			while ($res = $result->fetchRow()) {
+				$ret[] = $res['value'];
+			}
 		}
 		return $ret;
 	}
@@ -631,6 +638,10 @@ class LogsLib extends TikiLib {
 		$query = "update `tiki_actionlog`set `object`=? where `object`=? and (`objectType`=? or `objectType`= ?)";
 		$this->query($query, array($newName, $oldName, $objectType, 'comment'));
 	}
+	function update_category($actionId, $categId) {
+		$query = "update `tiki_actionlog` set `categId`=? where `actionId`=?";
+		$this->query($query, array($categId, $actionId));
+	}
 	function get_info_action($actionId) {
 		$query = "select * from `tiki_actionlog`where `actionId`= ?";
 		$result = $this->query($query, array($actionId));
@@ -845,7 +856,7 @@ class LogsLib extends TikiLib {
 
 	// get the contributors of the last update of a wiki page
 	function get_wiki_contributors($page_info) {
-		$query = 'select distinct(uu.`login`) from `tiki_actionlog_params` tap, `users_users` uu , `tiki_actionlog` ta where tap.`actionId`= ta.`actionId` and tap.`name`=? and uu.`userId`=tap.`value` and ta.`object`=? and ta.`objectType`=? and ta.`lastModif`=? order by `login` asc';
+		$query = 'select distinct(uu.`login`), uu.`userId` from `tiki_actionlog_params` tap, `users_users` uu , `tiki_actionlog` ta where tap.`actionId`= ta.`actionId` and tap.`name`=? and uu.`userId`=tap.`value` and ta.`object`=? and ta.`objectType`=? and ta.`lastModif`=? order by `login` asc';
 		$result = $this->query($query, array('contributor', $page_info['pageName'], 'wiki page', $page_info['lastModif'])); 
 		$ret = array();
 		while ($res = $result->fetchRow()) {
@@ -887,14 +898,18 @@ class LogsLib extends TikiLib {
 		}
 		return $contributorActions;
 	}
-	function list_logsql($sort_mode='created_desc', $offset=0, $maxRecords=-1) {
+	function list_logsql($sort_mode='created_desc', $offset=0, $maxRecords=-1, $find='') {
 		global $prefs;
-		if ($prefs['log_sql'] != 'y')
-			return null;
-		$query = 'select * from `adodb_logsql` order by '.$this->convert_sortmode($sort_mode);
-		$result = $this->query($query, array(), $maxRecords, $offset);
-		$query_cant = 'select count(*) from `adodb_logsql`';
-		$cant = $this->getOne($query_cant,$bindvars);
+		$bindvars = array();
+		if (!empty($find)) {
+			$findesc = '%'.$find.'%';
+			$amid = '`sql1` like ? or `params` like ? or `tracer` like ?';
+			$bindvars[] = $findesc;$bindvars[] = $findesc;$bindvars[] = $findesc;
+		}
+		$query = 'select * from `adodb_logsql`'.($find?" where $amid":'').' order by '.$this->convertSortMode($sort_mode);
+		$result = $this->query($query, $bindvars, $maxRecords, $offset);
+		$query_cant = 'select count(*) from `adodb_logsql`'.($find?" where $amid":'');
+		$cant = $this->getOne($query_cant, $bindvars);
 		$ret = array();
 		while ($res = $result->fetchRow()) {
 			$ret[] = $res;
@@ -905,7 +920,7 @@ class LogsLib extends TikiLib {
 		return $retval;
 	}
 	function clean_logsql() {
-		$query = 'delete * from  `adodb_logsql`';
+		$query = 'delete from  `adodb_logsql`';
 		$this->query($query, array());
 	}
 	function graph_to_jpgraph(&$jpgraph, $series, $accumulated = false, $color='whitesmoke', $colorLegend='white') {
@@ -930,7 +945,7 @@ class LogsLib extends TikiLib {
 	function insert_image($galleryId, $graph, $ext, $title, $period) {
 		global $prefs, $user;
 		global $imagegallib; include_once('lib/imagegals/imagegallib.php');
-		$filename = $prefs['tmpDir'].md5(rand().time()).'.'.$ext;
+		$filename = $prefs['tmpDir'].'/'.md5(rand().time()).'.'.$ext;
 		$graph->Stroke($filename);
 		$info = getimagesize($filename);
 		$size = filesize($filename);
@@ -941,7 +956,7 @@ class LogsLib extends TikiLib {
 	}
 
 	function get_more_info($actions, $categNames) {
-		global $tikilib;
+		global $tikilib, $prefs;
 	for ($i = 0; $i < sizeof($actions); ++$i) {
 		if ($actions[$i]['categId'])
 			$actions[$i]['categName'] = $categNames[$actions[$i]['categId']];
@@ -1001,7 +1016,7 @@ class LogsLib extends TikiLib {
 				$actions[$i]['link'] = 'tiki-list_file_gallery.php?galleryId='.$actions[$i]['object'];
 			if (!isset($fileGalleryNames)) {
 				include_once('lib/filegals/filegallib.php');
-				$objects = $filegallib->list_file_galleries(0, -1, 'name_asc', 'admin', '');
+				$objects = $filegallib->list_file_galleries(0, -1, 'name_asc', 'admin', '', $prefs['fgal_root_id']);
 				foreach ($objects['data'] as $object) {
 					$fileGalleryNames[$object['galleryId']] = $object['name'];
 				}
@@ -1054,8 +1069,11 @@ class LogsLib extends TikiLib {
 	}
 	return $actions;
 	} // end of get_more_info($actions)
+	function remove_action($actionId) {
+		$query = 'delete from `tiki_actionlog` where `actionId`=?';
+		$this->query($query, array($actionId));
+		$query = 'delete from `tiki_actionlog_params` where `actionId`=?';
+		$this->query($query, array($actionId));
+	}
 }
-global $dbTiki;
-$logslib = new LogsLib($dbTiki);
-
-?>
+$logslib = new LogsLib;
