@@ -7,9 +7,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 class MailinLib extends TikiLib {
-	function MailinLib($db) {
-		$this->TikiLib($db);
-	}
 
 	function list_mailin_accounts($offset, $maxRecords, $sort_mode, $find) {
 
@@ -22,7 +19,7 @@ class MailinLib extends TikiLib {
 			$bindvars = array();
 		}
 
-		$query = "select * from `tiki_mailin_accounts` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_mailin_accounts` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_mailin_accounts` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -49,7 +46,7 @@ class MailinLib extends TikiLib {
 			$bindvars = array("y");
 		}
 
-		$query = "select * from `tiki_mailin_accounts` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_mailin_accounts` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_mailin_accounts` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -96,7 +93,4 @@ class MailinLib extends TikiLib {
 		return $res;
 	}
 }
-global $dbTiki;
-$mailinlib = new MailinLib($dbTiki);
-
-?>
+$mailinlib = new MailinLib;
