@@ -6,13 +6,33 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   exit;
 }
 
+include_once('lib/mime/mimetypes.php');
+
 // returns mimetypes of files
-function tiki_get_mime($filename) {
+function tiki_get_mime($filename, $fallback = '') {
+	global $mimetypes;
+	
 	if (function_exists("mime_content_type")) {
 		//notice: this is the better way. 
 		//Compile php with --enable-mime-magic
 		//to be able to use this.
 		return mime_content_type($filename);
+		
+	}
+	
+	if (isset($mimetypes)) {
+		
+		$ext = pathinfo($filename);
+		$ext = isset($ext['extension']) ? $ext['extension'] : '';
+		$mimetype = isset($mimetypes[$ext]) ? $mimetypes[$ext] : '';
+		
+		if (!empty($mimetype)) {
+			return $mimetype;
+		}
+	}
+	
+	if ( $fallback != '' ) {
+		return $fallback;
 	} else {
 		//The "Microsoft Way" - just kidding
 		$defaultmime = "application/octet-stream";
@@ -42,5 +62,3 @@ function tiki_get_mime_sub($filename) {
 
 	return $filesplit["1"];
 }
-
-?>
