@@ -335,6 +335,7 @@ class TikiModInfo extends TikiModAvailable {
 		} else {
 			$this->md5 = md5_file($filename);
 		}
+		chmod($filename, 0644); // needed on some servers
 		
 		chdir($oldir);
 		return $err;
@@ -403,10 +404,12 @@ class ModsLib {
 
 	var $feedback_listeners;
 	var $types;
+	var $versions;
 
-	function ModsLib() { 
+	function __construct() { 
 		$this->types = array();
 		$this->feedback_listeners = array();
+		$this->versions = array('Unspecified' => -1,'1.x' => 1.0,'1.9.x' => 1.9,'2.x' => 2.0,'3.x' => 3.0, '4.x' => 4.0);
 	}
 
 	function feedback_info($feedback) {
@@ -591,7 +594,7 @@ class ModsLib {
 					foreach($str as $k => $v) $str[$k]=stripslashes($v);
 					$mod=new TikiModAvailable($str[0], $str[1]);
 					$this->types[$mod->type] = true;
-					if ((empty($type) or ($mod->type == $type)) and (empty($find) or (strpos($mode->name,$find) !== false))) {
+					if ((empty($type) or ($mod->type == $type)) and (empty($find) or (strpos($mod->name,$find) !== false))) {
 						$mod->revision=$str[2];
 						$mod->description=$str[3];
 						$mod->licence=$str[4];
@@ -639,7 +642,7 @@ class ModsLib {
 	function revision_compare($a, $b) {
 		$ra=explode('.', $a);
 		$rb=explode('.', $b);
-		for ($i=0; $i<max(count($ra), count($rb)); $i++) {
+		for ($i=0, $max_counts = max(count($ra), count($rb)); $i<$max_counts; $i++) {
 			$suba=isset($ra[$i]) ? (int)$ra[$i] : 0;
 			$subb=isset($rb[$i]) ? (int)$rb[$i] : 0;
 			if ($suba > $subb) return 1;
@@ -914,7 +917,7 @@ class ModsLib {
 				} else {
 					$smarty->assign('help','');
 				}
-				for ($i=0; $i < count($info->configuration); $i++) {
+				for ($i=0, $count_config = count($info->configuration); $i < $count_config; $i++) {
 					$info->configuration[$i][2] = preg_replace('/\\$([_A-Z]*)/e','$conf[\'_SERVER\'][\'\\1\']',$info->configuration[$i][2]);
 				}
 				$smarty->assign('type',$info->type);
@@ -1013,13 +1016,11 @@ class ModsLib {
 function newer($a,$b) {
 	$aa = split('\.',$a);
 	$bb = split('\.',$b);
-	for($i=0;$i<max(count($aa), count($bb));$i++) {
+	for ($i=0, $max_counts = max(count($aa), count($bb)); $i<$max_counts; $i++) {
 		if (!isset($bb[$i])) { $bb[$i] = '0'; }
 		if (!isset($aa[$i])) { $aa[$i] = '0'; }
 		if ($aa[$i] != $bb[$i]) { return $aa[$i] > $bb[$i]? 1: -1; }
 	} 
 	return 0;
 } 
-
-$modslib = new ModsLib();
-?>
+$modslib = new ModsLib;
