@@ -9,7 +9,9 @@
   * \param $topicName name of the parent topic
   */
 
-function sendForumEmailNotification($event, $object, $forum_info, $title, $data, $author, $topicName, $messageId='', $inReplyTo='', $threadId, $parentId, $contributions='' ) {
+include_once('lib/reportslib.php');
+  
+function sendForumEmailNotification($event, $object, $forum_info, $title, $data, $author, $topicName, $messageId='', $inReplyTo='', $threadId, $parentId, $contributions='', $postId='') {
 	global $tikilib, $prefs, $smarty, $userlib;
 
 	// Per-forum From address overrides global default.
@@ -61,9 +63,13 @@ function sendForumEmailNotification($event, $object, $forum_info, $title, $data,
 		{
 		    foreach ( $attachments as $att )
 		    {
-			$att_data = $commentslib->get_thread_attachment( $att['attId'] );
-			$file = $mail->getFile( $att_data['dir'].$att_data['path'] );
-			$mail->addAttachment( $file, $att_data['filename'], $att_data['filetype'] );
+				$att_data = $commentslib->get_thread_attachment( $att['attId'] );
+				if($att_data['dir'].$att_data['path'] == ""){ // no path to file on disk
+					$file = $att_data['data']; // read file from database
+				} else {
+					$file = $mail->getFile( $att_data['dir'].$att_data['path'] ); // read file from disk
+				}
+				$mail->addAttachment( $file, $att_data['filename'], $att_data['filetype'] );
 		    }
 		}
 
@@ -80,10 +86,14 @@ function sendForumEmailNotification($event, $object, $forum_info, $title, $data,
 	$defaultLanguage = $prefs['site_language'];
 
 	// Users watching this forum or this post
-	if ($prefs['feature_user_watches'] == 'y') {
-		$nots = $tikilib->get_event_watches($event, $event == 'forum_post_topic'? $forum_info['forumId']: $threadId, $forum_info);
-		for ($i = count($nots) - 1; $i >=0; --$i) {
-			$nots[$i]['language'] = $tikilib->get_user_preference($nots[$i]['user'], "language", $defaultLanguage);
+	if ($prefs['feature_user_watches'] == 'y' || $prefs['feature_group_watches'] == 'y') {
+		$nots_raw = $tikilib->get_event_watches($event, $event == 'forum_post_topic'? $forum_info['forumId']: $threadId, $forum_info);
+		$nots = array();
+		foreach( $nots_raw as $n ) {
+			if( $n['user'] != $author ) {
+				$n['language'] = $tikilib->get_user_preference($n['user'], "language", $defaultLanguage);
+				$nots[] = $n;
+			}
 		}
 	}
 
@@ -98,6 +108,12 @@ function sendForumEmailNotification($event, $object, $forum_info, $title, $data,
 		$nots[] = $not;
 	}
 
+	global $reportslib;
+
+	if ($prefs['feature_user_watches'] == 'y' && $prefs['feature_daily_report_watches'] == 'y') {
+		$reportslib->makeReportCache($nots, array("event"=>$event, "forumId"=>$forum_info['forumId'], "forumName"=>$forum_info['name'], "topicId"=>$threadId, "threadId"=>$postId, "threadName"=>$topicName, "user"=>$author));
+	}
+
 	if (count($nots)) {
 		include_once('lib/webmail/tikimaillib.php');
 		$mail = new TikiMail();
@@ -146,24 +162,30 @@ function testEmailInList($nots, $email) {
 
 /** \brief send the email notifications dealing with wiki page  changes to
   * admin notification addresses + watching users addresses (except editor is configured)
-  * \$event: 'wiki_page_created'|'wiki_page_changed'
+  * \$event: 'wiki_page_created'|'wiki_page_changed'|wiki_page_deleted |wiki_file_attached
   */
-function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment, $oldver, $edit_data, $machine, $diff='', $minor=false, $contributions='', $structure_parent_id=0) {
+function sendWikiEmailNotification($wikiEvent, $pageName, $edit_user, $edit_comment, $oldver, $edit_data, $machine='', $diff='', $minor=false, $contributions='', $structure_parent_id=0, $attId=0) {
 	global $tikilib, $prefs, $smarty, $userlib;
 	global $notificationlib; include_once('lib/notifications/notificationlib.php');
 	$nots = array();
 	$defaultLanguage = $prefs['site_language'];
+	if ($wikiEvent == 'wiki_file_attached') {
+		$event = 'wiki_page_changed';
+	} else {
+		$event = $wikiEvent;
+	}
 
 	if ($prefs['feature_user_watches'] == 'y') {
 		$nots = $tikilib->get_event_watches($event, $pageName);
 	}
+	
 	if ($prefs['feature_user_watches'] == 'y' && $event == 'wiki_page_changed') {
 		global $structlib; include_once('lib/structures/structlib.php');
 		$nots2 = $structlib->get_watches($pageName);
 		if (!empty($nots2)) {
 			$nots = array_merge($nots, $nots2);
 		}
-		
+
 		if ($prefs['wiki_watch_editor'] != "y") {
 			for ($i = count($nots) - 1; $i >=0; --$i)
 				if ($nots[$i]['user'] == $edit_user) {
@@ -171,10 +193,12 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
 					break;
 				}
 		}
+		
 		foreach (array_keys($nots) as $i) {
 			$nots[$i]['language'] = $tikilib->get_user_preference($nots[$i]['user'], "language", $defaultLanguage);
 		}
 	}
+
 	if ($prefs['feature_user_watches'] == 'y' && $event == 'wiki_page_created' && $structure_parent_id) {
 		global $structlib; include_once('lib/structures/structlib.php');
 		$nots = array_merge( $nots, $structlib->get_watches('', $structure_parent_id) );
@@ -183,13 +207,12 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
 	// admin notifications
     // If it's a minor change, get only the minor change watches.
 	if( $minor ){
-		$emails = $notificationlib->get_mail_events('wiki_page_changes_incl_minor', 'wikipage' . $pageName); // look for pageName and any page
+		$emails = $notificationlib->get_mail_events('wiki_page_changes_incl_minor', $pageName); // look for pageName and any page
 	} else { // else if it's not minor change, get both watch types.
-		$emails1 = $notificationlib->get_mail_events('wiki_page_changes', 'wikipage' . $pageName); // look for pageName and any page
-		$emails2 = $notificationlib->get_mail_events('wiki_page_changes_incl_minor', 'wikipage' . $pageName); // look for pageName and any page
+		$emails1 = $notificationlib->get_mail_events('wiki_page_changes', $pageName); // look for pageName and any page
+		$emails2 = $notificationlib->get_mail_events('wiki_page_changes_incl_minor', $pageName); // look for pageName and any page
 		$emails = array_merge( $emails1, $emails2 );
 	}
-
 	foreach ($emails as $email) {
 		if ($prefs['wiki_watch_editor'] != "y" && $email == $edit_user)
 		    continue;
@@ -205,10 +228,19 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
 
 	if ($edit_user=='') $edit_user = tra('Anonymous');
 
+	global $reportslib;
+	
+	if ($prefs['feature_user_watches'] == 'y' && $prefs['feature_daily_report_watches'] == 'y') {
+		if ($wikiEvent == 'wiki_file_attached') {
+			$reportslib->makeReportCache($nots, array("event"=>$wikiEvent, "pageName"=>$pageName, 'attId'=>$attId, "editUser"=>$edit_user, "editComment"=>$edit_comment, 'filename'=>$edit_data));
+		} else {
+			$reportslib->makeReportCache($nots, array("event"=>$wikiEvent, "pageName"=>$pageName, "object"=>$pageName, "editUser"=>$edit_user, "editComment"=>$edit_comment, "oldVer"=>$oldver));
+		}
+	}
+
 	if (count($nots)) {
 	    $edit_data = TikiLib::htmldecode($edit_data);
-	    include_once('lib/webmail/tikimaillib.php');
-	    $mail = new TikiMail();
+	    include_once('lib/mail/maillib.php');
 	    $smarty->assign('mail_site', $_SERVER["SERVER_NAME"]);
 	    $smarty->assign('mail_page', $pageName);
 	    $smarty->assign('mail_date', $tikilib->now);
@@ -218,6 +250,7 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
 	    $smarty->assign('mail_oldver', $oldver);
 	    $smarty->assign('mail_newver', $newver);
 	    $smarty->assign('mail_data', $edit_data);
+		$smarty->assign('mail_attId', $attId);
 	    $foo = parse_url($_SERVER["REQUEST_URI"]);
 	    $machine = $tikilib->httpPrefix(). dirname( $foo["path"] );
 	    $smarty->assign('mail_machine', $machine);
@@ -231,20 +264,29 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
 	    $smarty->assign('mail_machine_raw', $tikilib->httpPrefix(). implode('/', $parts));
 	    $smarty->assign_by_ref('mail_pagedata', $edit_data);
 	    $smarty->assign_by_ref('mail_diffdata', $diff);
-	    if ($event == 'wiki_page_created')
-		$smarty->assign('new_page', 'y');
+	    if ($event == 'wiki_page_created') {
+			$smarty->assign('mail_action', 'new');
+	    } elseif ($event == 'wiki_page_deleted') {
+	    	$smarty->assign('mail_action', 'delete');
+		} elseif ($wikiEvent == 'wiki_file_attached') {
+			$smarty->assign('mail_action', 'attach');
+	    } else {
+	    	$smarty->assign('mail_action', 'edit');
+	    }
 
 	    foreach ($nots as $not) {
-		if (isset($not['hash']))
-		    $smarty->assign('mail_hash', $not['hash']);
-		$mail->setUser($not['user']);
-		$mail_data = $smarty->fetchLang($not['language'], "mail/user_watch_wiki_page_changed_subject.tpl");
-		$mail->setSubject(sprintf($mail_data, $pageName));
-		$mail_data = $smarty->fetchLang($not['language'], "mail/user_watch_wiki_page_changed.tpl");
-		$mail->setText($mail_data);
-		$mail->buildMessage();
-		$mail->send(array($not['email']));
-	    }
+				$smarty->assign('watchId', $not['watchId']);
+
+			$mail_subject = $smarty->fetchLang($not['language'], "mail/user_watch_wiki_page_changed_subject.tpl");
+			$mail_data = $smarty->fetchLang($not['language'], "mail/user_watch_wiki_page_changed.tpl");
+
+			tiki_send_admin_mail(
+				$not['email'],
+				$not['user'],
+				sprintf($mail_subject, $pageName),
+				$mail_data
+			);
+		}
 	}
 }
 
@@ -254,13 +296,14 @@ function sendWikiEmailNotification($event, $pageName, $edit_user, $edit_comment,
  * \param $subjectTpl: subject template file or null (ex: "submission_notifcation.tpl")
  * \param $subjectParam: le param to be inserted in the subject or null
  * \param $txtTpl : texte template file (ex: "submission_notifcation.tpl")
+ * \param $from email from to not the default one
  * \ $smarty is supposed to be already built to fit $txtTpl
  * \return the nb of sent emails
  */
-function sendEmailNotification($list, $type, $subjectTpl, $subjectParam, $txtTpl) {
+function sendEmailNotification($list, $type, $subjectTpl, $subjectParam, $txtTpl, $from='') {
     global $smarty, $tikilib, $userlib, $prefs;
 	include_once('lib/webmail/tikimaillib.php');
-	$mail = new TikiMail();
+	$mail = new TikiMail(null, $from);
 	$sent = 0;
 	$defaultLanguage = $prefs['site_language'];
 	$languageEmail = $defaultLanguage;
@@ -317,8 +360,8 @@ function sendErrorEmailNotification($errno, $errstr, $errfile='?', $errline= '?'
         "$errfile, Line $errline\n$err($errno)\n$errstr");
 }
 
-function sendFileGalleryEmailNotification($event, $galleryId, $galleryName, $name, $filename, $description, $action, $user) {
-        global $tikilib, $prefs, $smarty, $userlib;
+function sendFileGalleryEmailNotification($event, $galleryId, $galleryName, $name, $filename, $description, $action, $user, $fileId) {
+        global $tikilib, $prefs, $smarty, $userlib, $reportslib;
 
         $nots = array();
         $defaultLanguage = $prefs['site_language'];
@@ -329,12 +372,20 @@ function sendFileGalleryEmailNotification($event, $galleryId, $galleryName, $nam
                 for ($i = count($nots) - 1; $i >=0; --$i) {
                         $nots[$i]['language'] = $tikilib->get_user_preference($nots[$i]['user'], "language", $defaultLanguage);
                 }
-        }
 
+				if ($prefs['feature_daily_report_watches'] == 'y') {
+					$reportslib->makeReportCache($nots, array("event"=>$event, "name"=>$name, "fileId"=>$fileId, "fileName"=>$filename, "galleryId"=>$galleryId, "galleryName"=>$galleryName, "action"=>$action, "user"=>$user));
+				}
+        }
+        
         if (count($nots)) {
                 include_once('lib/webmail/tikimaillib.php');
                 $mail = new TikiMail();
                 $smarty->assign('galleryName', $galleryName);
+				$smarty->assign('galleryId', $galleryId);
+				$smarty->assign('fname', $name);
+				$smarty->assign('filename', $filename);
+				$smarty->assign('fdescription', $description);
                 $smarty->assign('mail_date', $tikilib->now);
                 $smarty->assign('author', $user);
                 $foo = parse_url($_SERVER["REQUEST_URI"]);
@@ -364,7 +415,7 @@ function sendFileGalleryEmailNotification($event, $galleryId, $galleryName, $nam
  * oldCategoryName, oldCategoryPath, oldDescription, oldParendId, oldParentName,
  * objectName, objectType, objectUrl
  */
-function sendCategoryEmailNotification($values) {        
+function sendCategoryEmailNotification($values) {
         $event=$values['event'];
         $action=$values['action'];
         $categoryId=$values['categoryId'];
@@ -389,7 +440,7 @@ function sendCategoryEmailNotification($values) {
         
         //$event, $categoryId, $categoryName, $categoryPath, 
 		//$description, $parentId, $parentName, $action
-        global $tikilib, $prefs, $smarty, $userlib, $user;
+        global $tikilib, $prefs, $smarty, $userlib, $user, $reportslib;
 
         $nots = array();
         $defaultLanguage = $prefs['site_language'];
@@ -408,6 +459,13 @@ function sendCategoryEmailNotification($values) {
 			for ($i = count($nots) - 1; $i >=0; --$i) {
 				$nots[$i]['language'] = $tikilib->get_user_preference($nots[$i]['user'], "language", $defaultLanguage);
 			}
+			
+			if ($prefs['feature_daily_report_watches'] == 'y') {
+				$cache_data = $values;
+				$cache_data['user'] = $user;
+				$cache_data['event'] = $event;
+				$reportslib->makeReportCache($nots, $cache_data);
+			}
 		}
 
         if (count($nots)) {        		
@@ -425,11 +483,14 @@ function sendCategoryEmailNotification($values) {
                 
                 $foo = parse_url($_SERVER["REQUEST_URI"]);
                 $machine = $tikilib->httpPrefix(). dirname( $foo["path"] );
+				$machine = preg_replace("!/$!", "", $machine); // just incase
                 $smarty->assign('mail_machine', $machine);
 
 				$nots_send = array(); 
                 foreach ($nots as $not) {
-               			if ($nots_send[$not['user']]) break;               			
+					if (!empty($nots_send[$not['user']])) {
+						break;               			
+					}
                			$nots_send[$not['user']] = true;
                         $mail->setUser($not['user']);
                         if ($action == 'category created') {                                                        
@@ -500,5 +561,3 @@ function sendStructureEmailNotification($params) {
 		}
 	}
 }
-
-?>
