@@ -26,11 +26,11 @@
 /**
  * Include Auth_Container base class
  */
-require_once "Auth/Container.php";
+require_once "lib/pear/Auth/Container.php";
 /**
  * Include PEAR package for error handling
  */
-require_once "PEAR.php";
+require_once "lib/pear/PEAR.php";
 
 /**
  * Storage driver for fetching login data from LDAP
@@ -762,5 +762,3 @@ class Auth_Container_LDAP extends Auth_Container
     // }}}
 
 }
-
-?>
