@@ -1,7 +1,7 @@
 <?php
 // PHP Layers Menu 3.2.0-rc (C) 2001-2004 Marco Pratesi - http://www.marcopratesi.it/
 // (copy of original, included in lib/smarty_tiki/function.phplayers.php, modified for Tiki purposes, changes marked using "// [MOD] by <sfnick>")
-// CVS: $Header: /cvsroot/tikiwiki/tiki/lib/phplayers_tiki/lib/layersmenu-common.inc.php,v 1.1.2.1 2006/07/31 16:43:50 luciash Exp $
+// CVS: $Id: /cvsroot/tikiwiki/tiki/lib/phplayers_tiki/lib/layersmenu-common.inc.php,v 1.2.2.1 2008-02-27 15:18:47 nyloth Exp $
 
 /**
 * This file contains the code of the LayersMenuCommon class.
@@ -389,6 +389,7 @@ function setIcondir($icondir)
 		return false;
 	}
 	$this->icondir = $icondir;
+
 	return true;
 }
 
@@ -794,8 +795,10 @@ function _postParse(
 		$this->tree[$cnt]['parsed_text'] = stripslashes($this->tree[$cnt]['text']);
 		$this->tree[$cnt]['parsed_href'] = (ereg_replace(' ', '', $this->tree[$cnt]['href']) == '') ? '#' : $this->prependedUrl . $this->tree[$cnt]['href'];
 		$this->tree[$cnt]['parsed_title'] = ($this->tree[$cnt]['title'] == '') ? '' : ' title="' . stripslashes($this->tree[$cnt]['title']) . '"';
+
 		$fooimg = $this->icondir . $this->tree[$cnt]['icon'];
-		if ($this->tree[$cnt]['icon'] != '' && (substr($this->tree[$cnt]['icon'], 0, 7) == 'http://' || substr($this->tree[$cnt]['icon'], 0, 8) == 'https://')) {
+		//if ($this->tree[$cnt]['icon'] != '' && (substr($this->tree[$cnt]['icon'], 0, 7) == 'http://' || substr($this->tree[$cnt]['icon'], 0, 8) == 'https://')) { // Changed original conditions to allow relative URLs for icons
+		if ($this->tree[$cnt]['icon'] != '') {
 			$this->tree[$cnt]['parsed_icon'] = $this->tree[$cnt]['icon'];
 			if ($this->issetIconsize) {
 				$this->tree[$cnt]['iconwidth'] = $this->iconsize['width'];
@@ -953,5 +956,3 @@ function error($errormsg)
 }
 
 } /* END OF CLASS */
-
-?>
