@@ -14,9 +14,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 class QuizLib extends TikiLib {
-	function QuizLib($db) {
-		parent::TikiLib($db);
-	}
 
 	// Functions for Quizzes ////
 	function get_user_quiz_result($userResultId) {
@@ -33,7 +30,7 @@ class QuizLib extends TikiLib {
 
 	function list_quiz_question_stats($quizId, $offset = 0, $maxRecords = -1, $sort_mode = 'position_asc', $find = '') {
 
-		$query = "select distinct(tqs.`questionId`) from `tiki_quiz_stats` tqs,`tiki_quiz_questions` tqq where tqs.`questionId`=tqq.`questionId` and tqs.`quizId` = ? order by ".$this->convert_sortmode($sort_mode);
+		$query = "select distinct(tqs.`questionId`) from `tiki_quiz_stats` tqs,`tiki_quiz_questions` tqq where tqs.`questionId`=tqq.`questionId` and tqs.`quizId` = ? order by ".$this->convertSortMode($sort_mode);
 
 		$result = $this->query($query,array((int)$quizId));
 		$ret = array();
@@ -67,7 +64,7 @@ class QuizLib extends TikiLib {
 
 	function download_answer($answerUploadId) {
 
-		$query = "SELECT filecontent, filetype, filename, filesize FROM tiki_user_answers_uploads WHERE answerUploadId=?";
+		$query = "SELECT `filecontent`, `filetype`, `filename`, `filesize` FROM `tiki_user_answers_uploads` WHERE `answerUploadId`=?";
 
 		$result = $this->query($query,array((int)$answerUploadId));
 		$ret = array();
@@ -118,7 +115,7 @@ class QuizLib extends TikiLib {
 				$opt["optionText"] = $res["optionText"];
 				$opt["points"] = $res["points"];
 
-				$query3 = "select answerUploadId, filename from tiki_user_answers_uploads where userResultId = ? and questionId = ?";
+				$query3 = "select `answerUploadId`, `filename` from `tiki_user_answers_uploads` where `userResultId` = ? and `questionId` = ?";
 				$result3 = $this->query($query3,array((int)$userResultId,(int)$questionId));
 
 				while ($res2 = $result3->fetchRow()) {
@@ -181,7 +178,7 @@ class QuizLib extends TikiLib {
 	function list_quiz_stats($quizId, $offset, $maxRecords, $sort_mode, $find) {
 		$this->compute_quiz_stats();
 
-		$query = "select passingperct from `tiki_quizzes` where quizId = ?";
+		$query = "select `passingperct` from `tiki_quizzes` where `quizId` = ?";
 		$passingperct = $this->getOne($query,array((int)$quizId));
 
 		if ($find) {
@@ -191,7 +188,7 @@ class QuizLib extends TikiLib {
 		$mid = " where `quizId`=?";
 		$bindvars=array((int)$quizId);
 
-		$query = "select * from `tiki_user_quizzes` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_user_quizzes` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_user_quizzes` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -335,14 +332,14 @@ class QuizLib extends TikiLib {
 		if ($find) {
 			$findesc = '%' . $find . '%';
 
-			$mid = " where `quizId`=? and `question` like ? ";
+			$mid = " where `quizId`=? and `answer` like ? ";
 			$bindvars=array((int)$quizId,$findesc);
 		} else {
 			$mid = " where `quizId`=? ";
 			$bindvars=array((int)$quizId);
 		}
 
-		$query = "select * from `tiki_quiz_results` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_quiz_results` $mid order by " . $this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_quiz_results` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -400,7 +397,7 @@ class QuizLib extends TikiLib {
 			$query = "insert into `tiki_quiz_questions`(`question`,`type`,`quizId`,`position`) values(?,?,?,?)";
 			$bindvars=array($question,$type,(int)$quizId,(int) $position);
 			$result = $this->query($query,$bindvars);
-			$queryid = "select max(`questionId`) from `tiki_quiz_questions` where `question` like ? and type=?";
+			$queryid = "select max(`questionId`) from `tiki_quiz_questions` where `question` like ? and `type`=?";
 			$questionId = $this->getOne($queryid,array(substr($question,0,200)."%",$type));
 		}
 		return $questionId;
@@ -457,7 +454,7 @@ class QuizLib extends TikiLib {
 			$bindvars=array((int) $quizId);
 		}
 
-		$query = "select * from `tiki_quiz_questions` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_quiz_questions` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_quiz_questions` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -487,7 +484,7 @@ class QuizLib extends TikiLib {
 			$bindvars=array();
 		}
 
-		$query = "select * from `tiki_quiz_questions` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_quiz_questions` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_quiz_questions` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -511,14 +508,14 @@ class QuizLib extends TikiLib {
 		if ($find) {
 			$findesc = '%' . $find . '%';
 
-			$mid = " where `questionId`=? and `option` ? ";
+			$mid = " where `questionId`=? and `optionText` like ? ";
 			$bindvars=array((int)$questionId,$findesc);
 		} else {
 			$mid = " where `questionId`=? ";
 			$bindvars=array((int)$questionId);
 		}
 
-		$query = "select * from `tiki_quiz_question_options` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_quiz_question_options` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_quiz_question_options` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -637,8 +634,7 @@ class QuizLib extends TikiLib {
   }
 // Function for Quizzes end ////
 }
-global $dbTiki;
-$quizlib = new QuizLib($dbTiki);
+$quizlib = new QuizLib;
 
 
 // Find the next non-blank or return -1
@@ -844,7 +840,6 @@ class HW_QuizQuestionYesNo extends HW_QuizQuestion {
 class Quiz {
 	var $id;
 	var $bDeleted;
-	var $nVersion;
 	var $timestamp;
 	var $nAuthor;
 	var $bOnline;
@@ -881,7 +876,6 @@ class Quiz {
 		global $userlib;
 		$this->dbFields = array("id",
 														"bDeleted",
-														"nVersion",
 														"timestamp",
 														"nAuthor",
 														"bOnline",
@@ -914,7 +908,6 @@ class Quiz {
 														);
 		$this->id = 0;
 		$this->bDeleted = 0;
-		$this->nVersion = 1;
 		$this->timestamp = $this->now;
 		$this->nAuthor = $userlib->get_user_id($user);
 		$this->sAuthor = $user;
@@ -1007,5 +1000,3 @@ class Quiz {
 
 
 }
-
-?>
