@@ -19,18 +19,12 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 require_once('lib/tikilib.php'); # httpScheme(), get_user_preference
 require_once('lib/webmail/tikimaillib.php');
-require_once( 'lib/db/tikitable.php' );
 require_once( 'lib/db/tiki_registration_fields.php' );
 
 if (!isset($Debug)) $Debug = false;
 
 class RegistrationLib extends TikiLib {
 
-  function RegistrationLib($db) 
-  {
-    $this->TikiLib($db);  
-  }
-  
     // Validate emails...
   function SnowCheckMail($Email,$sender_email,$novalidation,$Debug=false)
   {
@@ -266,7 +260,7 @@ class RegistrationLib extends TikiLib {
   if($prefs['useRegisterPasscode'] == 'y') {
     if($_REQUEST["passcode"]!=$prefs['registerPasscode'])
     {
-      $smarty->assign('msg',tra("Wrong passcode you need to know the passcode to register in this site"));
+      $smarty->assign('msg',tra("Wrong passcode. You need to know the passcode to register at this site"));
       $smarty->display("error.tpl");
       die;
     }
@@ -346,6 +340,7 @@ class RegistrationLib extends TikiLib {
    *  A default Tikiwiki callback that sends the welcome email on user registraion
    *  @access private
    *  @returns true on success, false to halt event proporgation
+   * TODO: CLEANUP duplicates code in userslib.php?
    */
   function callback_tikiwiki_send_email($raisedBy, $data) {
 	global $_REQUEST, $_SESSION, $_SERVER, $prefs, $registrationlib_apass, $email_valid, $smarty, $tikilib, $userlib, $Debug;
@@ -362,9 +357,13 @@ class RegistrationLib extends TikiLib {
 			$apass = $registrationlib_apass;
 			$foo = parse_url($_SERVER["REQUEST_URI"]);
                         $foo1=str_replace("tiki-register","tiki-login_validate",$foo["path"]);
-                        $machine =$tikilib->httpPrefix().$foo1;
+                       	$foo2=str_replace("tiki-register","tiki-assignuser",$foo["path"]); 
 
-                        $smarty->assign('mail_machine',$machine);
+			$machine =$tikilib->httpPrefix().$foo1;
+			$machine_assignuser = $tikilib->httpPrefix().$foo2;
+
+                        $smarty->assign('mail_machine_assignuser',$machine_assignuser);
+			$smarty->assign('mail_machine',$machine);
                         $smarty->assign('mail_site',$mail_site);
                         $smarty->assign('mail_user',$mail_user);
                         $smarty->assign('mail_apass',$apass);
@@ -440,8 +439,4 @@ class RegistrationLib extends TikiLib {
         ask_ticket('register');
     }
 }
-  
-global $dbTiki;
-$registrationlib= new RegistrationLib($dbTiki);
-
-?>
+$registrationlib= new RegistrationLib;
