@@ -1,4 +1,5 @@
 <?php
+// $Id: rsslib.php 22084 2009-10-07 14:14:44Z lphuberdeau $
 
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
@@ -10,16 +11,13 @@ include_once ('lib/userslib.php');
 include_once ('lib/userprefs/scrambleEmail.php');
 include_once ('lib/feedcreator/feedcreator.class.php');
 
+global $dbTiki;
 $userslib = new Userslib($dbTiki);
 
 global $rss_cache_time;
 
 class RSSLib extends TikiLib {
 
-	function RSSLib($db) {
-		$this->TikiLib($db);
-	}
-
 	// ------------------------------------
 	// functions for rss feeds we syndicate
 	// ------------------------------------
@@ -225,7 +223,12 @@ class RSSLib extends TikiLib {
 
 		$dirname = (dirname($urlarray["path"]) != "/" ? "/" : "");
 
-		$url = htmlspecialchars($this->httpPrefix().$_SERVER["REQUEST_URI"]);
+		if ($prefs['index_rss_'.$feed]!='') {
+			$url = $prefs['index_rss_'.$feed];
+		} else {
+			$url = htmlspecialchars($this->httpPrefix().$_SERVER["REQUEST_URI"]);
+		}
+
 		$home = htmlspecialchars($this->httpPrefix().dirname( $urlarray["path"] ).$dirname.$prefs['tikiIndex']);
 		$img = htmlspecialchars($this->httpPrefix().dirname( $urlarray["path"] ).$dirname.$prefs['rssfeed_img']);
 
@@ -299,10 +302,10 @@ class RSSLib extends TikiLib {
 		$rss->feedURL = $url;
 		
 		$image = new FeedImage();
-		$image->title = $prefs['siteTitle'];
+		$image->title = $prefs['browsertitle'];
 		$image->url = $img;
 		$image->link = $home;
-		$image->description = sprintf(tra('Feed provided by %s. Click to visit.'), $prefs['siteTitle']);
+		$image->description = sprintf(tra('Feed provided by %s. Click to visit.'), $prefs['browsertitle']);
 	
 		//optional
 		$image->descriptionTruncSize = 500;
@@ -312,13 +315,12 @@ class RSSLib extends TikiLib {
 
 		global $dbTiki;
         if (!isset($userslib)) $userslib = new Userslib($dbTiki);
-		
 		foreach ($changes["data"] as $data)  {
 			$item = new FeedItem(); 
 			$item->title = $data["$titleId"]; 
-
-			// 2 parameters to replace			
-			if ($urlparam<>'') {
+			if (isset($data['sefurl'])) {
+				$item->link = $this->httpPrefix().dirname($urlarray["path"]).$dirname.$data['sefurl'];
+			} elseif ($urlparam<>'') {			// 2 parameters to replace
 				$item->link = sprintf($read, urlencode($data["$id"]), urlencode($data["$urlparam"]));
 			} else {
 				$item->link = sprintf($read, urlencode($data["$id"]));
@@ -346,29 +348,31 @@ class RSSLib extends TikiLib {
 			//optional
 			//item->descriptionTruncSize = 500;
 			$item->descriptionHtmlSyndicated = true;
+			
 			$item->date = (int) $data["$dateId"]; 
 	
 			$item->source = $url; 
 
 			$item->author = "";
 			if ($authorId<>"") {
-				if ($userslib->user_exists($data["$authorId"])) {
-					$item->author = $data["$authorId"];
-					// only use realname <email> if existing and
-					$tmp = "";
-					if ($this->get_user_preference($data["$authorId"], 'user_information', 'private')=='public') {
-						$tmp = $this->get_user_preference($data["$authorId"], "realName");
-					}
-					$epublic = $this->get_user_preference($data["$authorId"], 'email is public', 'n');
-					if ($epublic!='n') {
-						$res = $userslib->get_user_info($data["$authorId"], false);
-						if ($tmp<>"") $tmp .= ' ';
-						$tmp .= "<".scrambleEmail($res['email'], $epublic).">";
-					}
-					if ($tmp<>"") $item->author = $tmp;
-				} else $item->author = $data["$authorId"];
+				if ($prefs['showAuthor_rss_'.$feed] == 'y') {
+					if ($userslib->user_exists($data["$authorId"])) {
+						$item->author = $data["$authorId"];
+						// only use realname <email> if existing and
+						$tmp = "";
+						if ($this->get_user_preference($data["$authorId"], 'user_information', 'private')=='public') {
+							$tmp = $this->get_user_preference($data["$authorId"], "realName");
+						}
+						$epublic = $this->get_user_preference($data["$authorId"], 'email is public', 'n');
+						if ($epublic!='n') {
+							$res = $userslib->get_user_info($data["$authorId"], false);
+							if ($tmp<>"") $tmp .= ' ';
+							$tmp .= "<".scrambleEmail($res['email'], $epublic).">";
+						}
+						if ($tmp<>"") $item->author = $tmp;
+					} else $item->author = $data["$authorId"];
+				}
 			}
-			 
 			$rss->addItem($item); 
 		} 
 		$data = $rss->createFeed($this->get_rss_version_name($rss_version));
@@ -396,7 +400,7 @@ class RSSLib extends TikiLib {
 			$bindvars=array();
 		}
 
-		$query = "select * from `tiki_rss_modules` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_rss_modules` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_rss_modules` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -421,7 +425,7 @@ class RSSLib extends TikiLib {
 
 		if ($rssId) {
 			$query = "update `tiki_rss_modules` set `name`=?,`description`=?,`refresh`=?,`url`=?,`showTitle`=?,`showPubDate`=? where `rssId`=?";
-			$bindvars=array($name,$description,$refresh,$url,$showTitle,$showPubDate,$rssId);
+			$bindvars=array($name,$description,$refresh,$url,$showTitle,$showPubDate,(int)$rssId);
 		} else {
 			// was: replace into, no clue why.
 			$query = "insert into `tiki_rss_modules`(`name`,`description`,`url`,`refresh`,`content`,`lastUpdated`,`showTitle`,`showPubDate`)
@@ -437,7 +441,7 @@ class RSSLib extends TikiLib {
 	function remove_rss_module($rssId) {
 		$query = "delete from `tiki_rss_modules` where `rssId`=?";
 
-		$result = $this->query($query,array($rssId));
+		$result = $this->query($query,array((int)$rssId));
 		return true;
 	}
 
@@ -445,7 +449,7 @@ class RSSLib extends TikiLib {
 	function get_rss_module($rssId) {
 		$query = "select * from `tiki_rss_modules` where `rssId`=?";
 
-		$result = $this->query($query,array($rssId));
+		$result = $this->query($query,array((int)$rssId));
 
 		if (!$result->numRows())
 			return false;
@@ -491,7 +495,7 @@ class RSSLib extends TikiLib {
 					$links[1][0] = $links2[1][0];
 				}
 		 	} else {
-				preg_match_all("/<link.*?href=\"(.*?)\".*?>/msi", $items[0][$it], $links);
+				preg_match_all("/<link.*?href=[\"'](.*?)[\"'].*?>/msi", $items[0][$it], $links);
 			}
 	 		preg_match_all("/<description[^>]*>(<!\[CDATA\[)?(.*?)(\]\]>)?<\/description>/msi", $items[0][$it], $description);
 			if (count($description[1])<1)
@@ -539,8 +543,10 @@ class RSSLib extends TikiLib {
 	}
 
 	/* refresh content of a certain rss feed */
-	function refresh_rss_module($rssId) {
-		$info = $this->get_rss_module($rssId);
+	function refresh_rss_module($rssId, $info='') {
+		if (empty($info)) {
+			$info = $this->get_rss_module($rssId);
+		}
 		if ($info) {
 			if (($gotit = $this->httprequest($info['url'])) !== false) {
 				$data = $this->rss_iconv($gotit);
@@ -548,7 +554,7 @@ class RSSLib extends TikiLib {
 				return false;
 			}
 			$query = "update `tiki_rss_modules` set `content`=?, `lastUpdated`=? where `rssId`=?";
-			$result = $this->query($query,array((string)$data,(int) $this->now, $rssId));
+			$result = $this->query($query,array((string)$data,(int) $this->now, (int)$rssId));
 			return $data;
 		} else {
 			return false;
@@ -575,7 +581,7 @@ class RSSLib extends TikiLib {
 	function get_rss_showTitle($rssId) {
 		$query = "select `showTitle` from `tiki_rss_modules` where `rssId`=?";
 
-		$showTitle = $this->getOne($query,array($rssId));
+		$showTitle = $this->getOne($query,array((int)$rssId));
 		return $showTitle;
 	}
 
@@ -583,7 +589,7 @@ class RSSLib extends TikiLib {
 	function get_rss_showPubDate($rssId) {
 		$query = "select `showPubDate` from `tiki_rss_modules` where `rssId`=?";
 
-		$showPubDate = $this->getOne($query,array($rssId));
+		$showPubDate = $this->getOne($query,array((int)$rssId));
 		return $showPubDate;
 	}
 
@@ -593,7 +599,7 @@ class RSSLib extends TikiLib {
 
 		// cache too old, get data from feed and update cache
 		if (($info["lastUpdated"] + $info["refresh"] < $this->now) || ($info["content"]=="") || $refresh) {
-			$data = $this->refresh_rss_module($rssId);
+			$data = $this->refresh_rss_module($rssId, $info);
 		}
 
 		// get from cache
@@ -661,7 +667,5 @@ class RSSLib extends TikiLib {
 		return $xmlstr;
 	}
 }
-global $dbTiki;
-$rsslib = new RSSLib($dbTiki);
-
-?>
+global $rsslib;
+$rsslib = new RSSLib;
