@@ -7,10 +7,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 class SearchStatsLib extends TikiLib {
-	function SearchStatsLib($db) {
-		$this->TikiLib($db);
-	}
-
 	function clear_search_stats() {
 		$query = "delete from tiki_search_stats";
 		$result = $this->query($query,array());
@@ -26,7 +22,7 @@ class SearchStatsLib extends TikiLib {
 			$bindvars = array();
 		}
 
-		$query = "select * from `tiki_search_stats` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_search_stats` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_search_stats` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -42,7 +38,4 @@ class SearchStatsLib extends TikiLib {
 		return $retval;
 	}
 }
-global $dbTiki;
-$searchstatslib = new SearchStatsLib($dbTiki);
-
-?>
+$searchstatslib = new SearchStatsLib;
