@@ -1,6 +1,6 @@
 <?php
 
-// $Id: breadcrumb.php 13491 2008-07-10 09:20:32Z lphuberdeau $
+// $Id: breadcrumb.php 17072 2009-03-02 13:39:23Z sylvieg $
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
@@ -11,5 +11,5 @@ $access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));
 
 // setup initial breadcrumb
 $crumbs = array();
-$crumbs[] = new Breadcrumb($prefs['siteTitle'], '', $prefs['tikiIndex']);
+$crumbs[] = new Breadcrumb($prefs['browsertitle'], '', $prefs['tikiIndex']);
 $smarty->assign_by_ref('crumbs', $crumbs);
