@@ -1,15 +1,17 @@
 <?php
 
-// $Id: fullscreen.php 13491 2008-07-10 09:20:32Z lphuberdeau $
+// $Id: fullscreen.php 19556 2009-06-15 06:39:40Z sept_7 $
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
 // details.
 
 //this script may only be included - so its better to die if called directly.
-$access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
+  header("location: index.php");
+  exit;
+}
 
-$smarty->assign('fsquery', preg_replace('/(\?|&(amp;)?)fullscreen=(n|y)/','',$_SERVER['QUERY_STRING']));
 if ( isset($_GET['fullscreen']) ) {
 	if ($_GET['fullscreen'] == 'y') {
 		$_SESSION['fullscreen'] = 'y';
