@@ -1,6 +1,6 @@
 <?php
 
-// $Id: polls.php 13491 2008-07-10 09:20:32Z lphuberdeau $
+// $Id: polls.php 20238 2009-07-20 13:36:20Z sylvieg $
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
@@ -12,18 +12,15 @@ $access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));
 if ( isset($_REQUEST['pollVote']) ) {
 	if ( $tiki_p_vote_poll == 'y' && isset($_REQUEST['polls_optionId']) ) {
 		if( $prefs['feature_poll_anonymous'] == 'y' || $user ) {
-			if ( ! isset($polllib) or ! is_object($polllib) ) {
-				include_once('lib/polls/polllib_shared.php');
-			}
-			if (!$tikilib->user_has_voted($user, 'poll'.$_REQUEST['polls_pollId'])) {
+			global $polllib; include_once('lib/polls/polllib_shared.php');
+			if (($prefs['feature_poll_revote'] == 'y' && $user) || !$tikilib->user_has_voted($user, 'poll'.$_REQUEST['polls_pollId'])) {
 				$polllib->poll_vote($user, $_REQUEST['polls_pollId'], $_REQUEST['polls_optionId']);
-				// Poll vote must go first, or the new vote will be seen as the previous one.
 				$tikilib->register_user_vote($user, 'poll' . $_REQUEST['polls_pollId'], $_REQUEST['polls_optionId']);
 			}
 		}
 	}
 	$pollId = $_REQUEST['polls_pollId'];
-	if ( ! isset($_REQUEST['wikipoll']) ) {
+	if ( ! isset($_REQUEST['wikipoll']) && $tiki_p_view_poll_results == 'y') {
 		header ("location: tiki-poll_results.php?pollId=$pollId");
 	}
 }
