@@ -1,6 +1,6 @@
 <?php
 
-// $Id: userlevels.php 13491 2008-07-10 09:20:32Z lphuberdeau $
+// $Id: userlevels.php 15542 2008-11-06 17:26:14Z sylvieg $
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
@@ -10,8 +10,8 @@
 $access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));
 
 $mylevel = $tikilib->get_user_preference($user,'mylevel',1);
-if ( isset($_REQUEST['level']) and isset($prefs['userlevels'][$_REQUEST['level']]) and $user ) {
-	$tikilib->set_user_preference($user,"mylevel",$_REQUEST['level']);
-	$mylevel = $_REQUEST['level'];
+if ( isset($_REQUEST['mylevel']) and isset($prefs['userlevels'][$_REQUEST['mylevel']]) and $user ) {
+	$tikilib->set_user_preference($user,"mylevel",$_REQUEST['mylevel']);
+	$mylevel = $_REQUEST['mylevel'];
 }
 $smarty->assign('mylevel',$mylevel);
