@@ -5,7 +5,7 @@
 *  The majority of this is _NOT_ my code.  I simply ported it from the
 *  PERL Spreadsheet::WriteExcel module.
 *
-*  The author of the Spreadsheet::WriteExcel module is John McNamara
+*  The author of the Spreadsheet::WriteExcel module is John McNamara 
 *  <jmcnamara@cpan.org>
 *
 *  I _DO_ maintain this code, and John McNamara has nothing to do with the
@@ -32,12 +32,6 @@
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 /**
 * Class for generating Excel XF records (formats)
 *
@@ -270,9 +264,9 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $this->_font_script    = 0;
         $this->_font_family    = 0;
         $this->_font_charset   = 0;
-
+                               
         $this->_num_format     = 0;
-
+                               
         $this->_hidden         = 0;
         $this->_locked         = 0;
 
@@ -286,19 +280,19 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $this->_bg_color       = 0x41;
 
         $this->_pattern        = 0;
-
+                               
         $this->_bottom         = 0;
         $this->_top            = 0;
         $this->_left           = 0;
         $this->_right          = 0;
         $this->_diag           = 0;
-
+                               
         $this->_bottom_color   = 0x40;
         $this->_top_color      = 0x40;
         $this->_left_color     = 0x40;
         $this->_right_color    = 0x40;
         $this->_diag_color     = 0x40;
-
+    
         // Set properties passed to Spreadsheet_Excel_Writer_Workbook::addFormat()
         foreach($properties as $property => $value)
         {
@@ -327,7 +321,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $style   = $this->_locked;
             $style  |= $this->_hidden << 1;
         }
-
+    
         // Flags to indicate if attributes have been set.
         $atr_num     = ($this->_num_format != 0)?1:0;
         $atr_fnt     = ($this->font_index != 0)?1:0;
@@ -340,7 +334,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
                         ($this->_bg_color != 0x41) ||
                         $this->_pattern)?1:0;
         $atr_prot    = $this->_locked | $this->_hidden;
-
+    
         // Zero the default border colour if the border has not been set.
         if ($this->_bottom == 0) {
             $this->_bottom_color = 0;
@@ -357,7 +351,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         if ($this->_diag == 0) {
             $this->_diag_color = 0;
         }
-
+    
         $record         = 0x00E0;              // Record identifier
         if ($this->_BIFF_version == 0x0500) {
             $length         = 0x0010;              // Number of bytes to follow
@@ -365,7 +359,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         if ($this->_BIFF_version == 0x0600) {
             $length         = 0x0014;
         }
-
+                                               
         $ifnt           = $this->font_index;   // Index to FONT record
         $ifmt           = $this->_num_format;  // Index to FORMAT record
         if ($this->_BIFF_version == 0x0500)
@@ -381,22 +375,22 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $align         |= $atr_bdr                << 13;
             $align         |= $atr_pat                << 14;
             $align         |= $atr_prot               << 15;
-
+ 
             $icv            = $this->_fg_color;       // fg and bg pattern colors
             $icv           |= $this->_bg_color      << 7;
-
+     
             $fill           = $this->_pattern;        // Fill and border line style
             $fill          |= $this->_bottom        << 6;
             $fill          |= $this->_bottom_color  << 9;
-
+     
             $border1        = $this->_top;            // Border line style and color
             $border1       |= $this->_left          << 3;
             $border1       |= $this->_right         << 6;
             $border1       |= $this->_top_color     << 9;
-
+     
             $border2        = $this->_left_color;     // Border color
             $border2       |= $this->_right_color   << 7;
-
+         
             $header      = pack("vv",       $record, $length);
             $data        = pack("vvvvvvvv", $ifnt, $ifmt, $style, $align,
                                             $icv, $fill,
@@ -418,7 +412,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
 
             $icv            = $this->_fg_color;      // fg and bg pattern colors
             $icv           |= $this->_bg_color      << 7;
-
+   
             $border1        = $this->_left;          // Border line style and color
             $border1       |= $this->_right         << 4;
             $border1       |= $this->_top           << 8;
@@ -429,7 +423,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $diag_tr_to_lb = 0; // FIXME: add method
             $border1       |= $diag_tl_to_rb        << 30;
             $border1       |= $diag_tr_to_lb        << 31;
-
+     
             $border2        = $this->_top_color;    // Border color
             $border2       |= $this->_bottom_color   << 7;
             $border2       |= $this->_diag_color     << 14;
@@ -447,7 +441,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
 
         return($header.$data);
     }
-
+    
     /**
     * Generate an Excel BIFF FONT record.
     *
@@ -463,7 +457,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $bFamily    = $this->_font_family;  // Font family
         $bCharSet   = $this->_font_charset; // Character set
         $encoding   = 0;                    // TODO: Unicode support
-
+    
         $cch        = strlen($this->_font_name); // Length of font name
         $record     = 0x31;                      // Record identifier
         if ($this->_BIFF_version == 0x0500) {
@@ -486,7 +480,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         if ($this->_font_shadow) {
             $grbit     |= 0x20;
         }
-
+    
         $header  = pack("vv",         $record, $length);
         if ($this->_BIFF_version == 0x0500) {
             $data    = pack("vvvvvCCCCC", $dyHeight, $grbit, $icv, $bls,
@@ -500,9 +494,9 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         }
         return($header . $data. $this->_font_name);
     }
-
+    
     /**
-    * Returns a unique hash key for a font.
+    * Returns a unique hash key for a font. 
     * Used by Spreadsheet_Excel_Writer_Workbook::_storeAllFonts()
     *
     * The elements that form the key are arranged to increase the probability of
@@ -521,7 +515,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $key  = str_replace(" ","_",$key);
         return ($key);
     }
-
+    
     /**
     * Returns the index used by Spreadsheet_Excel_Writer_Worksheet::_XF()
     *
@@ -531,7 +525,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         return($this->_xf_index);
     }
-
+    
     /**
     * Used in conjunction with the set_xxx_color methods to convert a color
     * string into a number. Color range is 0..63 but we will restrict it
@@ -563,36 +557,36 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
                         'white'   => 0x09,
                         'yellow'  => 0x0D
                        );
-
+    
         // Return the default color, 0x7FFF, if undef,
         if($name_color == '') {
             return(0x7FFF);
         }
-
+    
         // or the color string converted to an integer,
         if(isset($colors[$name_color])) {
             return($colors[$name_color]);
         }
-
+    
         // or the default color if string is unrecognised,
         if(preg_match("/\D/",$name_color)) {
             return(0x7FFF);
         }
-
+    
         // or an index < 8 mapped into the correct range,
         if($name_color < 8) {
             return($name_color + 8);
         }
-
+    
         // or the default color if arg is outside range,
         if($name_color > 63) {
             return(0x7FFF);
         }
-
+    
         // or an integer in the valid range
         return($name_color);
     }
-
+    
     /**
     * Set cell alignment.
     *
@@ -604,9 +598,9 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         if (preg_match("/\d/",$location)) {
             return;                      // Ignore numbers
         }
-
+    
         $location = strtolower($location);
-
+    
         if ($location == 'left') {
             $this->_text_h_align = 1;
         }
@@ -650,7 +644,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $this->_text_v_align = 4;
         }
     }
-
+    
     /**
     * This is an alias for the unintuitive setAlign('merge')
     *
@@ -660,7 +654,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->setAlign('merge');
     }
-
+    
     /**
     * Sets the boldness of the text.
     * Bold has a range 100..1000.
@@ -687,12 +681,12 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         }
         $this->_bold = $weight;
     }
-
-
+    
+    
     /************************************
     * FUNCTIONS FOR SETTING CELLS BORDERS
     */
-
+    
     /**
     * Sets the width for the bottom border of the cell
     *
@@ -703,7 +697,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_bottom = $style;
     }
-
+    
     /**
     * Sets the width for the top border of the cell
     *
@@ -714,7 +708,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_top = $style;
     }
-
+    
     /**
     * Sets the width for the left border of the cell
     *
@@ -725,7 +719,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_left = $style;
     }
-
+    
     /**
     * Sets the width for the right border of the cell
     *
@@ -736,8 +730,8 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_right = $style;
     }
-
-
+    
+    
     /**
     * Set cells borders to the same style
     *
@@ -751,17 +745,17 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $this->setLeft($style);
         $this->setRight($style);
     }
-
-
+    
+    
     /*******************************************
     * FUNCTIONS FOR SETTING CELLS BORDERS COLORS
     */
-
+    
     /**
     * Sets all the cell's borders to the same color
     *
     * @access public
-    * @param mixed $color The color we are setting. Either a string (like 'blue'),
+    * @param mixed $color The color we are setting. Either a string (like 'blue'), 
     *                     or an integer (range is [8...63]).
     */
     function setBorderColor($color)
@@ -771,7 +765,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $this->setLeftColor($color);
         $this->setRightColor($color);
     }
-
+    
     /**
     * Sets the cell's bottom border color
     *
@@ -783,7 +777,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $value = $this->_getColor($color);
         $this->_bottom_color = $value;
     }
-
+    
     /**
     * Sets the cell's top border color
     *
@@ -795,7 +789,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $value = $this->_getColor($color);
         $this->_top_color = $value;
     }
-
+    
     /**
     * Sets the cell's left border color
     *
@@ -807,7 +801,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $value = $this->_getColor($color);
         $this->_left_color = $value;
     }
-
+    
     /**
     * Sets the cell's right border color
     *
@@ -819,8 +813,8 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $value = $this->_getColor($color);
         $this->_right_color = $value;
     }
-
-
+    
+    
     /**
     * Sets the cell's foreground color
     *
@@ -835,7 +829,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $this->_pattern = 1;
         }
     }
-
+      
     /**
     * Sets the cell's background color
     *
@@ -850,7 +844,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
             $this->_pattern = 1;
         }
     }
-
+    
     /**
     * Sets the cell's color
     *
@@ -862,7 +856,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $value = $this->_getColor($color);
         $this->_color = $value;
     }
-
+    
     /**
     * Sets the fill pattern attribute of a cell
     *
@@ -874,7 +868,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_pattern = $arg;
     }
-
+    
     /**
     * Sets the underline of the text
     *
@@ -886,7 +880,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_underline = $underline;
     }
-
+ 
     /**
     * Sets the font style as italic
     *
@@ -898,7 +892,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     }
 
     /**
-    * Sets the font size
+    * Sets the font size 
     *
     * @access public
     * @param integer $size The font size (in pixels I think).
@@ -907,7 +901,7 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
     {
         $this->_size = $size;
     }
-
+    
     /**
     * Sets text wrapping
     *
@@ -1036,4 +1030,3 @@ class Spreadsheet_Excel_Writer_Format extends PEAR
         $this->_font_name = $font_family;
     }
 }
-?>
