@@ -9,7 +9,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 ini_set( 'include_path', ini_get( 'include_path' ) . ":lib/sheet" );
 
 // Nice dependencies, mostly for excel support. Don't try changing the order.
-require_once( "PEAR.php" );
+require_once( "lib/pear/PEAR.php" );
 require_once( "lib/sheet/excel/reader_ole.php" );
 require_once( "lib/sheet/excel/reader.php" );
 require_once( "lib/sheet/excel/writer/format.php" );
@@ -726,8 +726,8 @@ class TikiSheetFormHandler extends TikiSheetDataHandler
 		{
 			for( $x = 0; $sheet->getColumnCount() > $x; $x++ )
 			{
-				$calc = $sheet->calcGrid[$y][$x];
-				$value = $sheet->dataGrid[$y][$x];
+				$calc = str_replace('\n', ' ', $sheet->calcGrid[$y][$x]);
+				$value = str_replace('\n', ' ', $sheet->dataGrid[$y][$x]);
 				$width = $sheet->cellInfo[$y][$x]['width'];
 				$height = $sheet->cellInfo[$y][$x]['height'];
 				$format = $sheet->cellInfo[$y][$x]['format'];
@@ -1929,6 +1929,4 @@ class SheetLib extends TikiLib
 	}
 	
 } // }}}1
-
-$sheetlib = &new SheetLib( $tikilib->db );
-?>
+$sheetlib = new SheetLib;
