@@ -18,16 +18,23 @@ if (strpos($_SERVER['SCRIPT_NAME'],basename(__FILE__)) !== false) {
 include_once('lib/init/tra.php');
 
 function smarty_block_tr($params, $content, &$smarty) {
-	if (empty($content) )
+
+	if ($content == '')
 		return;
 	if (empty($params['lang'])) {
 		$lang = '';
 	} else {
 		$lang = $params['lang'];
 	}
+
+	$args = array();
+	foreach( $params as $key => $value ) {
+		if( is_int( $key ) )
+			$args[$key] = $value;
+	}
+
 	if (empty($params['interactive']) || $params['interactive'] == 'y')
-		return tra($content,$lang);
+		return tra($content,$lang, false, $args);
 	else
 		return tra($content,$lang, true);
 }
-?>
