@@ -7,7 +7,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 function smarty_function_editform($params, &$smarty) {
-	global $prefs, $base_url;
+	global $prefs, $url_path;
 
 	include_once 'lib/tikifck.php';
 	if (!isset($params['InstanceName']))       $params['InstanceName'] = 'fckedit';
@@ -15,6 +15,9 @@ function smarty_function_editform($params, &$smarty) {
 	if (isset($params['Meat']))       $fcked->Meat = $params['Meat'];
 	if (isset($params['Width']))      $fcked->Width = $params['Width'];
 	if (isset($params['Height']))     $fcked->Height = $params['Height'];
+	if ($prefs['feature_ajax'] == 'y' && $prefs['feature_ajax_autosave'] == 'y') {
+		$fcked->Config['autoSaveSelf'] = htmlentities($_SERVER['REQUEST_URI']);
+	}
 	if (isset($params['ToolbarSet'])) {
 		$fcked->ToolbarSet = $params['ToolbarSet'];
 	} else {
@@ -26,8 +29,6 @@ function smarty_function_editform($params, &$smarty) {
 		$fcked->Config['AutoDetectLanguage'] = false;
 	}
 	$fcked->Config['DefaultLanguage'] = $prefs['language'];
-	$fcked->Config['CustomConfigurationsPath'] = $base_url.'setup_fckeditor.php';
+	$fcked->Config['CustomConfigurationsPath'] = $url_path.'setup_fckeditor.php';
 	echo $fcked->CreateHtml();
 }
-
-?>
