@@ -8,7 +8,11 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 function smarty_function_memusage($params, &$smarty)
 {
-    if (function_exists('memory_get_usage')) {
+    if (function_exists('memory_get_peak_usage')) {
+			// PHP 5.2+
+      $memusage=memory_get_peak_usage();
+    } elseif (function_exists('memory_get_usage')) {
+			//PHP 4 >= 4.3.2, PHP 5
       $memusage=memory_get_usage();
     } else {
       $memusage=0;
@@ -33,7 +37,3 @@ function smarty_function_memusage($params, &$smarty)
       print (tra("Unknown"));
     }
 }
-
-
-
-?>
