@@ -8,6 +8,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 function smarty_function_poll($params, &$smarty) {
 	global $polllib, $dbTiki, $commentslib, $prefs;
+	global $tiki_p_view_poll_results, $tiki_p_vote_poll;
     extract($params);
     // Param = zone
 	if (!is_object($polllib)) {
@@ -25,6 +26,9 @@ function smarty_function_poll($params, &$smarty) {
     }
 	if ($id == "current")
 		$id = $polllib->get_random_poll("c");
+	if ($tiki_p_view_poll_results != 'y' && $tiki_p_vote_poll != 'y') {
+		return tra('You do not have permission to use this feature');
+	}
     if($id) {
       $menu_info = $polllib->get_poll($id);
 	if ($menu_info) {
@@ -35,14 +39,11 @@ function smarty_function_poll($params, &$smarty) {
 			} else
 				$comments_count = 0;
       $smarty->assign('comments_cant', $comments_count);
-      $smarty->assign('ownurl','tiki-poll_results.php?pollId='.$id);
+      if ($tiki_p_view_poll_results == 'y')
+		  $smarty->assign('ownurl','tiki-poll_results.php?pollId='.$id);
       $smarty->assign('menu_info',$menu_info);
       $smarty->assign('channels',$channels);
       $smarty->display('tiki-poll.tpl');
 	}
     }
 }
-
-
-
-?>
