@@ -6,6 +6,8 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   exit;
 }
 
+require_once 'lib/init/tra.php';
+
 function smarty_prefilter_tr($source) {
   // Now replace the matched language strings with the entry in the file
 //  $return = preg_replace_callback('/\{tr[^\{]*\}([^\{]+)\{\/tr\}/', '_translate_lang', $source);
@@ -32,4 +34,3 @@ function _translate_lang($key) {
 		return $s;
     }
 }
-?>
