@@ -1,11 +1,11 @@
 <?php
-// $Id: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.141.2.24 2008-02-28 14:57:12 sylvieg Exp $
+// $Id: $
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 	header("location: index.php");
 	exit;
 }
-/*
- * Smarty plugin
+/**
+ * \brief Smarty plugin to use wiki page as a template resource
  * -------------------------------------------------------------
  * File:     resource.wiki.php
  * Type:     resource
@@ -15,24 +15,32 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
  */
 function smarty_resource_wiki_source($page, &$tpl_source, &$smarty) {
 	global $tikilib, $user;
-	if (!$tikilib->user_has_perm_on_object($user, $page, 'wiki page', 'tiki_p_use_as_template')) {
-		return false;
-	}
+
+	 if (!$tikilib->user_has_perm_on_object($user, $page, 'wiki page', 'tiki_p_use_as_template')) {
+		$tpl_source= tra('Permission denied: the specified wiki page cannot be used as Smarty template resource').'<br />';
+		// TODO: do not cache ! and return the message only once should be enough...
+		return true;
+	 }
+
 	$info = $tikilib->get_page_info($page);
 	if (empty($info)) {
 		return false;
 	}
-	$tpl_source = $tikilib->parse_data($info['data'],$info['is_html']);
+	$tpl_source = $tikilib->parse_data($info['data'], array('is_html' => $info['is_html'], 'print'=>'y'));
 	return true;
 }
 
 function smarty_resource_wiki_timestamp($page, &$tpl_timestamp, &$smarty) {
-	global $tikilib;
+	global $tikilib, $user;
 	$info = $tikilib->get_page_info($page);
 	if (empty($info)) {
 		return false;
 	}
-	$tpl_timestamp = $info['lastModif'];
+	if (preg_match("/\{([A-Z0-9_]+) */", $info['data'])) { // there are some plugins - so it can be risky to cache the page
+		$tpl_timestamp = $tikilib->now;
+	} else {
+		$tpl_timestamp = $info['lastModif'];
+	}
 	return true;
 }
 
