@@ -8,9 +8,9 @@ if (strpos($_SERVER['SCRIPT_NAME'],basename(__FILE__)) !== false) {
 class StructLib extends TikiLib {
 	var $displayLanguageOrder;
 
-	function StructLib($db) {
+	function __construct() {
 		global $prefs;
-		$this->TikiLib($db);
+		parent::__construct();
 
 		$this->displayLanguageOrder = array();
 	}
@@ -140,7 +140,7 @@ class StructLib extends TikiLib {
 			$this->query($query, array((int)$previous['page_ref_id'], (int)$pos, (int)$page_ref_id));
 			//Remove the space created by the demotion			
 			$query = "update `tiki_structures` set `pos`=`pos`-1 where `pos`>? and `parent_id`=?";
-			$this->query($query,array((int)$parent_info["pos"], (int)$parent_info["parent_id"]));  
+			$this->query($query,array((int)$page_info["pos"], (int)$page_info["parent_id"])); 
 			if ($prefs['feature_user_watches'] == 'y') {
 				include_once('lib/notifications/notificationemaillib.php');
 				sendStructureEmailNotification(array('action'=>'move_down', 'page_ref_id'=>$page_ref_id, 'parent_id'=>$previous['page_ref_id']));
@@ -169,6 +169,9 @@ class StructLib extends TikiLib {
 			$query = 'update `tiki_structures` set `pos`=? where `page_ref_id`=?';
 			$this->query($query,array((int)$res['pos'], (int)$page_info['page_ref_id']) );
 			$this->query($query,array((int)$page_info['pos'], (int)$res['page_ref_id']) );
+		} elseif ($page_info['pos'] > 1) { // a bug occured - try to fix
+			$query = 'update `tiki_structures` set `pos`=? where `page_ref_id`=?';
+			$this->query($query,array($page_info['pos']-1, (int)$page_info['page_ref_id']) );
 		}
 	}
   /** \brief Create a structure entry with the given name
@@ -180,16 +183,15 @@ class StructLib extends TikiLib {
       \param alias An alias for the wiki page name.
       \return the new entries page_ref_id or null if not created.
   */
-  function s_create_page($parent_id, $after_ref_id, $name, $alias='') {
-	  global $prefs;
-    $ret = null;
-    // If the page doesn't exist then create a new wiki page!
-	$newpagebody = tra("Table of contents") . ":" . "{toc}"; 
-	$created = $this->create_page($name, 0, $newpagebody, $this->now, tra('created from structure'), 'system', '0.0.0.0', '', false, '', array('parent_id'=>$parent_id));
-		// if were not trying to add a duplicate structure head
-		if ($created or isset($parent_id)) {
-            //Get the page Id
-		    $query = 'select `page_id` from `tiki_pages` where `pageName`=?';
+	function s_create_page($parent_id, $after_ref_id, $name, $alias='', $structure_id=null) {
+		global $prefs;
+		$ret = null;
+		// If the page doesn't exist then create a new wiki page!
+		$newpagebody = tra("Table of contents") . ":" . "{toc}"; 
+		$created = $this->create_page($name, 0, $newpagebody, $this->now, tra('created from structure'), 'system', '0.0.0.0', '', false, '', array('parent_id'=>$parent_id));
+		
+		if (!empty($parent_id) || $created || ! $this->page_is_in_structure($name)) { // if were not trying to add a duplicate structure head
+			$query = 'select `page_id` from `tiki_pages` where `pageName`=?';
 			$page_id = $this->getOne($query,array($name));
 			if (isset($after_ref_id)) {
 				$max = $this->getOne('select `pos` from `tiki_structures` where `page_ref_id`=?',array((int)$after_ref_id));
@@ -204,8 +206,8 @@ class StructLib extends TikiLib {
 			}
             //Create a new structure entry
 			$max++;
-			$query = 'insert into `tiki_structures`(`parent_id`,`page_id`,`page_alias`,`pos`) values(?,?,?,?)';
-			$result = $this->query($query,array((int)$parent_id,(int)$page_id,$alias,(int)$max));
+			$query = 'insert into `tiki_structures`(`parent_id`,`page_id`,`page_alias`,`pos`, `structure_id`) values(?,?,?,?,?)';
+			$result = $this->query($query,array((int)$parent_id, (int)$page_id, $alias, (int)$max, (int)$structure_id));
 			//Get the page_ref_id just created
 			if (isset($parent_id)) {
 				$parent_check = ' and `parent_id`=?';
@@ -218,6 +220,10 @@ class StructLib extends TikiLib {
 			$query .= 'where `page_id`=? and `page_alias`=? and `pos`=?';
 			$query .= $parent_check;
 			$ret = $this->getOne($query,$attributes);
+			if (empty($parent_id)) {
+				$query = 'update `tiki_structures` set `structure_id`=? where `page_ref_id`=?';
+				$this->query($query, array($ret, $ret));
+			}
 			if ($prefs['feature_user_watches'] == 'y') {
 				include_once('lib/notifications/notificationemaillib.php');
 				sendStructureEmailNotification(array('action'=>'add', 'page_ref_id'=>$ret, 'name'=>$name));
@@ -251,7 +257,7 @@ class StructLib extends TikiLib {
       $level++;
     }
 		//Get all child nodes for this page_ref_id
-    $query = 'select `page_ref_id`, `page_alias`, `pageName`, `flag`, `user`';
+    $query = 'select `page_ref_id`, `page_alias`, `pageName`, `flag`, `user`, `pos` as db_pos ';
     $query .= 'from `tiki_structures` ts, `tiki_pages` tp ';
     $query .= 'where ts.`page_id` = tp.`page_id` and `parent_id`=? order by `pos` asc';
 		$result = $this->query($query,array((int)$page_ref_id));
@@ -260,6 +266,7 @@ class StructLib extends TikiLib {
 		while ($res = $result->fetchRow()) {
       //Add
       $aux['first']       = ($pos == 1);
+	  $aux['db_pos'] = $res['db_pos'];
       $aux['last']        = false;
       $aux['page_ref_id'] = $res['page_ref_id'];
       $aux['pageName']    = $res['pageName'];
@@ -321,7 +328,15 @@ class StructLib extends TikiLib {
 		}
 		$query = "SELECT ts.`parent_id`,tuw.`email`,tuw.`user`, tuw.`event`";
 		$query .= " FROM `tiki_structures` ts";
-		$query .= " LEFT JOIN `tiki_user_watches` tuw ON (tuw.`object`=ts.`page_ref_id` AND tuw.`event`=?)";
+		$query .= " LEFT JOIN (
+			SELECT watchId, user, event, object, title, type, url, email FROM `tiki_user_watches`
+			UNION DISTINCT
+				SELECT watchId, uu.login as user, event, object, title, type, url, uu.email 
+				FROM 
+					`tiki_group_watches` tgw
+					INNER JOIN users_usergroups ug ON tgw.`group` = ug.groupName
+					INNER JOIN users_users uu ON ug.userId = uu.userId AND uu.email IS NOT NULL AND uu.email <> ''
+			) tuw ON (tuw.`object`=ts.`page_ref_id` AND tuw.`event`=?)";
 		if (empty($page_ref_id)) {
 			$query .= " LEFT JOIN `tiki_pages` tp ON ( tp.`page_id`=ts.`page_id`)";
 			$query .= " WHERE tp.`pageName`=?";
@@ -351,8 +366,9 @@ class StructLib extends TikiLib {
   */
 	function s_get_structure_info($page_ref_id) {
 		$parent_id = $this->getOne('select `parent_id` from `tiki_structures` where `page_ref_id`=?', array((int)$page_ref_id));
-		if (!$parent_id)
+		if (!$parent_id) {
 			return $this->s_get_page_info($page_ref_id);
+		}
 		return $this->s_get_structure_info($parent_id);
 	}
   /**Returns an array of info about the parent
@@ -378,7 +394,7 @@ class StructLib extends TikiLib {
 		if( !$multilinguallib )
 			include_once('lib/multilingual/multilinguallib.php');
 
-		$this->displayLanguageOrder = $multilinguallib->preferedLangs();
+		$this->displayLanguageOrder = $multilinguallib->preferredLangs();
 	}
 
 	function build_language_order_clause( &$args, $pageTable = 'tp', $structTable = 'ts' )
@@ -409,7 +425,7 @@ class StructLib extends TikiLib {
 	function s_get_page_info($page_ref_id) {
 		if( empty( $this->displayLanguageOrder ) )
 		{
-			$query =  'select `pos`, `page_ref_id`, `parent_id`, ts.`page_id`, `pageName`, `page_alias` ';
+			$query =  'select `pos`, `page_ref_id`, `parent_id`, ts.`page_id`, `pageName`, `page_alias`, `structure_id` ';
 			$query .= 'from `tiki_structures` ts, `tiki_pages` tp ';
 			$query .= 'where ts.`page_id`=tp.`page_id` and `page_ref_id`=?';
 			$result = $this->query($query,array((int)$page_ref_id));
@@ -425,7 +441,8 @@ class StructLib extends TikiLib {
 					`parent_id`, 
 					ts.`page_id`, 
 					`pageName`, 
-					`page_alias`
+					`page_alias`,
+					`structure_id`
 				FROM
 					`tiki_structures` ts
 					LEFT JOIN tiki_translated_objects a ON a.type = 'wiki page' AND a.objId = ts.page_id
@@ -449,6 +466,7 @@ class StructLib extends TikiLib {
 	// it's used only in {toc} thing hardcoded in parse tikilib->parse -- (mose)
 	// the $tocPrefix can be used to Prefix a subtree as it would start from a given number (e.g. 2.1.3)
 	function build_subtree_toc($id,$slide=false,$order='asc',$tocPrefix='') {
+		global $user, $tikilib;
 		$ret = array();
 		$cant = $this->getOne('select count(*) from `tiki_structures` where `parent_id`=?',array((int)$id));
 		if ($cant) {
@@ -456,7 +474,7 @@ class StructLib extends TikiLib {
 			$args = array();
 			if( ! $this->displayLanguageOrder ) {
 				$query = 'select `page_ref_id`, `pageName`, `page_alias`, tp.`description` from `tiki_structures` ts, `tiki_pages` tp ';
-				$query.= 'where ts.`page_id`=tp.`page_id` and `parent_id`=? order by '.$this->convert_sortmode('pos_'.$order);
+				$query.= 'where ts.`page_id`=tp.`page_id` and `parent_id`=? order by '.$this->convertSortMode('pos_'.$order);
 				$args[] = (int) $id;
 
 			} else {
@@ -482,12 +500,15 @@ class StructLib extends TikiLib {
 					)
 				WHERE
 					parent_id = ?
-				";
+				order by ".$this->convertSortMode('pos_'.$order);
 				$args[] = (int) $id;
 			}
 			$result = $this->query($query, $args);
 			$prefix=1;
 			while ($res = $result->fetchRow()) {
+				if (!$tikilib->user_has_perm_on_object($user, $res['pageName'], 'wiki page', 'tiki_p_view' ) ) {
+					continue;
+				}
 				$res['prefix']=($tocPrefix=='')?'':"$tocPrefix.";
 				$res['prefix'].=$prefix;
 				$prefix++;
@@ -595,7 +616,7 @@ function get_struct_ref_id($pageName) {
 			$query  = 'select `page_ref_id` ';
 			$query .= 'from `tiki_structures` ts ';
 			$query .= 'where `parent_id`=? ';
-			$query .= 'order by '.$this->convert_sortmode('pos_asc');
+			$query .= 'order by '.$this->convertSortMode('pos_asc');
 			$result1 = $this->query($query,array((int)$page_ref_id));
 			if ($result1->numRows()) {
 				$res = $result1->fetchRow();
@@ -611,7 +632,7 @@ function get_struct_ref_id($pageName) {
 		$query  = 'select `page_ref_id` ';
         $query .= 'from `tiki_structures` ts ';
 		$query .= 'where `parent_id`=? and `pos`>? ';
-		$query .= 'order by '.$this->convert_sortmode('pos_asc');
+		$query .= 'order by '.$this->convertSortMode('pos_asc');
 		$result2 = $this->query($query,array((int)$parent_id, (int)$page_pos));
 		if ($result2->numRows()) {
 			$res = $result2->fetchRow();
@@ -627,7 +648,7 @@ function get_struct_ref_id($pageName) {
   	        $query  = 'select `page_ref_id` ';
 		    $query .= 'from `tiki_structures` ts ';
 			$query .= 'where `parent_id`=? ';
-			$query .= 'order by '.$this->convert_sortmode('pos_desc');
+			$query .= 'order by '.$this->convertSortMode('pos_desc');
 			$result = $this->query($query,array($page_ref_id));
 			if ($result->numRows()) {
 				//There are more children
@@ -646,7 +667,7 @@ function get_struct_ref_id($pageName) {
 		$query  = 'select `page_ref_id` ';
 		$query .= 'from `tiki_structures` ts ';
 		$query .= 'where `parent_id`=? and `pos`<? ';
-		$query .= 'order by '.$this->convert_sortmode('pos_desc');
+		$query .= 'order by '.$this->convertSortMode('pos_desc');
 		$result =  $this->query($query,array((int)$parent_id, (int)$pos));
 		if ($result->numRows()) {
 			//There is a previous sibling
@@ -684,7 +705,7 @@ function get_struct_ref_id($pageName) {
 	  $query =  'select `pos`, `page_ref_id`, `parent_id`, ts.`page_id`, `pageName`, `page_alias` ';
 		$query .= 'from `tiki_structures` ts, `tiki_pages` tp ';
     $query .= 'where ts.`page_id`=tp.`page_id` and `parent_id`=? ';
-		$query .= 'order by '.$this->convert_sortmode('pos_asc');
+		$query .= 'order by '.$this->convertSortMode('pos_asc');
         $result = $this->query($query,array((int)$parent_id));
 		while ($res = $result->fetchRow()) {
 			//$ret[] = $this->populate_page_info($res);
@@ -758,7 +779,7 @@ function s_get_structure_pages($page_ref_id) {
  		$query =  'select `pos`, `page_ref_id`, `parent_id`, ts.`page_id`, `pageName`, `page_alias` ';
 		$query .= 'from `tiki_structures` ts, `tiki_pages` tp ';
     		$query .= 'where ts.`page_id`=tp.`page_id` and `parent_id`=? ';
-		$query .= 'order by '.$this->convert_sortmode('pos_asc');
+		$query .= 'order by '.$this->convertSortMode('pos_asc');
    		$result = $this->query($query,array((int)$page_ref_id));
 		while ($res = $result->fetchRow()) {
 			$ret = array_merge($ret,$this->s_get_structure_pages($res['page_ref_id']));
@@ -803,7 +824,7 @@ function list_structures($offset, $maxRecords, $sort_mode, $find='', $exact_matc
 		$query = "select `page_ref_id`,`parent_id`,ts.`page_id`,`page_alias`,`pos`,
 			`pageName`,tp.`hits`,`data`,tp.`description`,`lastModif`,`comment`,`version`,
 			`user`,`ip`,`flag`,`points`,`votes`,`cache`,`wiki_cache`,`cache_timestamp`,
-			`pageRank`,`creator`,`page_size` from `tiki_structures` as ts $join_tables $mid order by ".$this->convert_sortmode($sort_mode);
+			`pageRank`,`creator`,`page_size` from `tiki_structures` as ts $join_tables $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_structures` ts $join_tables $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -844,6 +865,7 @@ function list_structures($offset, $maxRecords, $sort_mode, $find='', $exact_matc
   //the base.
   function structure_to_webhelp($page_ref_id, $dir, $top) {
   	global $style_base;
+	global $prefs;
     //The first task is to convert the structure into an array with the
     //proper format to produce a WebHelp project.
 	//We have to create something in the form
@@ -915,7 +937,16 @@ function list_structures($offset, $maxRecords, $sort_mode, $find='', $exact_matc
   		$i++;
 	}
 	fclose($fw);
-  }
+
+// write the title page, using:
+// Browser Title, Site Title, Site subtitle
+	$fw = fopen("$base/content.html",'w+');
+	$titlepage = "<h1>". $prefs['browsertitle'] . "</h1><h2>". $prefs['sitetitle'] ."</h2><h3>".  $prefs['sitesubtitle']  ."</h3>";
+	$titlepage = 
+	fwrite($fw, $titlepage);
+	fclose($fw);
+
+	}
   function structure_to_tree($page_ref_id) {
 	$query = 'select * from `tiki_structures` ts,`tiki_pages` tp where tp.`page_id`=ts.`page_id` and `page_ref_id`=?';
 	$result = $this->query($query,array((int)$page_ref_id));
@@ -994,7 +1025,41 @@ function list_structures($offset, $maxRecords, $sort_mode, $find='', $exact_matc
 		$this->query($query, array($structure_id, $pos+1, $page_ref_id));
 	}
   }
+  /* transform a structure into a menu */
+  function to_menu($channels, $structure, $sectionLevel=0, $cumul=0) {
+	  global $smarty;
+	  include_once('lib/smarty_tiki/function.sefurl.php');
+	  $options = array();
+	  $cant = 0;
+	  if (empty($channels)) {
+		  return array('cant'=>0, 'data'=>array());
+	  }
+	  foreach ($channels as $channel) {
+		  if (empty($channel['sub'])) {
+			  if (isset($options[$cant-1]['sectionLevel'])) {
+				  $level = $options[$cant-1]['sectionLevel'];
+				  while ($level-- > $sectionLevel) {
+					  $options[]= array('type' => '-', 'sectionLevel'=>$level);
+					  ++$cant;
+				  }
+			  }
+		  }
+		  $option['name'] = empty($channel['page_alias'])? $channel['pageName']: $channel['page_alias'];
+		  $option['type'] = empty($channel['sub'])? 'o': ($sectionLevel?$sectionLevel:'s');
+		  $option['url'] = smarty_function_sefurl(array('page'=>$channel['pageName'], 'structure'=>$structure, 'page_ref_id'=>$channel['page_ref_id'], 'sefurl'=>'n'), $smarty);
+		  $option['canonic'] = '(('.$channel['pageName'].'))';
+		  $option['sefurl'] = smarty_function_sefurl(array('page'=>$channel['pageName'], 'structure'=>$structure, 'page_ref_id'=>$channel['page_ref_id']), $smarty);
+		  $option['position'] = $cant + $cumul;
+		  $option['sectionLevel'] = $sectionLevel;
+		  ++$cant;
+		  $options[] = $option;
+		  if (!empty($channel['sub'])) {
+			  $oSub =  $this->to_menu($channel['sub'], $structure, $sectionLevel+1, $cant+$cumul);
+			  $cant += $oSub['cant'];
+			  $options = array_merge($options, $oSub['data']);
+		  }
+	  }
+	  return array('data'=>$options, 'cant'=>$cant);
+  }
 }
-global $dbTiki;
-$structlib = new StructLib($dbTiki);
-?>
+$structlib = new StructLib;
