@@ -7,9 +7,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 class TagLineLib extends TikiLib {
-	function TagLineLib($db) {
-		$this->TikiLib($db);
-	}
 
 	function list_cookies($offset, $maxRecords, $sort_mode, $find) {
 		if ($find) {
@@ -19,7 +16,7 @@ class TagLineLib extends TikiLib {
 			$mid = "";
 			$bindvars = array();
 		}
-		$query = "select * from `tiki_cookies` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query = "select * from `tiki_cookies` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_cookies` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -70,7 +67,4 @@ class TagLineLib extends TikiLib {
 		$result = $this->query($query,array());
 	}
 }
-global $dbTiki;
-$taglinelib = new TagLineLib($dbTiki);
-
-?>
+$taglinelib = new TagLineLib;
