@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: /cvsroot/tikiwiki/tiki/lib/tikihelplib.php,v 1.8.2.1 2008-02-11 03:27:46 nkoth Exp $
+ * $Id: tikihelplib.php 23436 2009-11-22 18:43:06Z jonnybradley $
  * Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
  * All Rights Reserved. See copyright.txt for details and a complete list of authors.
  * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
@@ -40,11 +40,11 @@ function help_doclink($params) {
     }
     
     if ($prefs['feature_help'] == 'y' and $url) {
-        $ret = '<a title="'.$desc.'" href="'
+    	if (!isset($desc)) $desc = tra('Help link');
+        $ret = '<a title="'.htmlentities($desc).'" href="'
         .$prefs['helpurl'].$url.'" target="tikihelp" class="tikihelp">'
         .'<img src="pics/icons/help.png"'
         .' border="0" height="16" width="16" alt="'.tra('Help','',true).'" /></a>';
     }
     return $ret;
 }
-?>
