@@ -1,16 +1,21 @@
 
+var tracker_dynamic_options;
+
 function selectValues(args,me,filter) {
 	var req = null;
 	var envdoc = this;
 	var tabsel = me.split(",");
 	var filtervalue = "";
-	var sel = new Array();
+	
+	tracker_dynamic_options = new Array()
 
 	for (var i=0; i < tabsel.length; i++)
 	{
-		sel[i] = document.getElementsByName("ins_" + tabsel[i])[0];
-		while (sel[i].childNodes.length != 0) {
-			sel[i].removeChild(sel[i].lastChild);
+		tracker_dynamic_options[i] = document.getElementsByName("ins_" + tabsel[i])[0];
+		if (typeof tracker_dynamic_options[i] == "undefined")
+			tracker_dynamic_options[i] = document.getElementsByName("track[" + tabsel[i]+"]")[0];
+		while (tracker_dynamic_options[i].childNodes.length != 0) {
+			tracker_dynamic_options[i].removeChild(tracker_dynamic_options[i].lastChild);
 		}
 	}
 
@@ -18,7 +23,7 @@ function selectValues(args,me,filter) {
 		filtervalue = "&filtervalue=";
 		var selct = document.getElementsByName(filter)[0].childNodes;
 		for (var i=0; i < selct.length; i++) {
-			if (selct[i].nodeType == 1) {
+			if (selct[i].nodeType == 1 && selct[i].childNodes.length) {
 				filtervalue += selct[i].childNodes[0].nodeValue;
 				break;
 			}
