@@ -69,7 +69,7 @@ class CatBrowseTreeMaker extends TreeMaker {
 		$this->itemID = $this->prefix . 'id' . $nodeinfo["id"];
 
 		$this->jsscriptblock .= "setFlipWithSign('" . $this->itemID . "'); ";
-		return '<a class="link" id="flipper' . $this->itemID . '" href="javascript:flipWithSign(\'' . $this->itemID . '\')">[+]</a>&nbsp;';
+		return '<a class="link categflipper" id="flipper' . $this->itemID . '" href="javascript:flipWithSign(\'' . $this->itemID . '\')">[+]</a>&nbsp;';
 	}
 
 	//
@@ -97,5 +97,3 @@ class CatBrowseTreeMaker extends TreeMaker {
 		return "\t" . '</li>';
 	}
 }
-
-?>
