@@ -22,10 +22,6 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
  *
  */
 class UserModulesLib extends TikiLib {
-	function UserModulesLib($db) {
-		$this->TikiLib($db);
-	}
-
 	function unassign_user_module($moduleId, $user) {
 		$query = "delete from `tiki_user_assigned_modules` where `moduleId`=? and `user`=?";
 		$result = $this->query($query,array($moduleId, $user));
@@ -147,7 +143,7 @@ class UserModulesLib extends TikiLib {
 	}
 	// Return the list of modules that can be assigned by the user
 	function get_user_assignable_modules($user) {
-		global $prefs;
+		global $prefs,$userlib;
 
 		$query = "select * from `tiki_modules`";
 		$result = $this->query($query,array());
@@ -158,11 +154,10 @@ class UserModulesLib extends TikiLib {
 			$mod_ok = 0;
 
 			// The module must not be assigned
-			$isas = $this->getOne(
-				"select count(*) from `tiki_user_assigned_modules` where `moduleId`=? and `user`=?",array($res['moduleId'],$user));
+			$isas = $this->getOne("select count(*) from `tiki_user_assigned_modules` where `moduleId`=? and `user`=?",array($res['moduleId'],$user));
 
 			if (!$isas) {
-				if ($res["groups"] && $prefs['modallgroups'] != 'y' && $user != 'admin') {
+				if ($res["groups"] && $prefs['modallgroups'] != 'y' && (!$userlib->user_has_permission($user,'tiki_p_admin'))) {
 					$groups = unserialize($res["groups"]);
 
 					$ins = array_intersect($groups, $user_groups);
@@ -238,7 +233,4 @@ class UserModulesLib extends TikiLib {
 		}
 	} 
 }
-global $dbTiki;
-$usermoduleslib = new UserModulesLib($dbTiki);
-
-?>
+$usermoduleslib = new UserModulesLib;
