@@ -667,6 +667,9 @@ class htmlMimeMail {
 * @return mixed
 */
 	function send($recipients, $type = 'mail') {
+		if ( ! empty($recipients) && is_string($recipients) ) {
+			$recipients = array($recipients);
+		}
 		if (!defined('CRLF')) {
 			$this->setCrlf($type == 'mail' ? "\n" : "\r\n");
 		}
@@ -693,7 +696,9 @@ class htmlMimeMail {
 			$to = $this->_encodeHeader(implode(', ', $recipients), $this->build_params['head_charset']);
 
 			if (!empty($this->return_path)) {
-				$result = mail($to, $subject, $this->output, implode(CRLF, $headers), '-f' . $this->return_path);
+				// Set the sender for sendmail and use only the email address when the syntax of return_path is like 'Name <email>'
+				$additional_parameters = '-f' . preg_replace('/^.*<(.*?)>.*$/', '$1', $this->return_path);
+				$result = mail($to, $subject, $this->output, implode(CRLF, $headers), $additional_parameters);
 			} else {
 				$result = mail($to, $subject, $this->output, implode(CRLF, $headers));
 			}
@@ -2382,5 +2387,3 @@ class smtp {
 		return TRUE;
 	}
 } // class smtp
-
-?>
