@@ -16,7 +16,7 @@
 // +----------------------------------------------------------------------+
 // | Authors: Richard Heyes <richard@phpguru.org>                         |
 // +----------------------------------------------------------------------+
-require_once ('PEAR.php');
+require_once ('lib/pear/PEAR.php');
 
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
@@ -724,5 +724,3 @@ class Mail_mimeDecode extends PEAR {
 		return $return;
 	}
 } // End of class
-
-?>
