@@ -1,8 +1,8 @@
 <?php
 /*
- * Tiki-Wiki ANAME plugin. Go to http://www.TikiMODS.com for more Tikiwiki Plugins.
+ * Tiki ANAME plugin.
  *
- * DESCRIPTION: Puts an anchor into a wiki page. Use in conjunction with the ALINK plugin, which makes links to the anchor.
+ * DESCRIPTION: Creates an anchor in a wiki page. Use in conjunction with the ALINK plugin, which specifies a link to the anchor.
  * 
  * INSTALLATION: Just put this file into your Tikiwiki site's lib/wiki-plugins folder.
  * 
@@ -18,7 +18,19 @@
 
 
 function wikiplugin_aname_help() {
-        return tra("Puts an anchor into a wiki page. Use in conjunction with the ALINK plugin, which makes links to the anchor").":<br />~np~{ANAME()}anchorname{ANAME}~/np~";
+        return tra("Creates an anchor in a wiki page. Use in conjunction with the ALINK plugin, which specifies a link to the anchor").":<br />~np~{ANAME()}anchorname{ANAME}~/np~";
+}
+
+function wikiplugin_aname_info() {
+	return array(
+		'name' => tra('Anchor Name'),
+		'documentation' => 'PluginAname',
+		'description' => tra('Inserts an anchor in the wiki page. Anchors can be linked to using the ALINK plugin.'),
+		'prefs' => array('wikiplugin_aname'),
+		'body' => tra('The name of the anchor.'),
+		'params' => array(),
+		'icon' => 'pics/icons/anchor.png',
+	);
 }
 
 function wikiplugin_aname($data, $params)
@@ -32,5 +44,3 @@ function wikiplugin_aname($data, $params)
 
 	return "<a id=\"$data\"></a>";
 }
-
-?>
