@@ -14,9 +14,33 @@ function wikiplugin_article_help() {
 
         return $help;
 }
+
+function wikiplugin_article_info() {
+	return array(
+		'name' => tra('Article'),
+		'documentation' => 'PluginArticle',
+		'description' => tra('Includes an article\'s content within the page.'),
+		'prefs' => array( 'feature_articles', 'wikiplugin_article' ),
+		'params' => array(
+			'Field' => array(
+				'required' => false,
+				'name' => tra('Field'),
+				'description' => tra('The article field to display. Default field is Heading.'),
+				'filter' => 'word',
+			),
+			'Id' => array(
+				'required' => false,
+				'name' => tra('Article ID'),
+				'description' => tra('The article to display. If no value is provided, most recent article will be used.'),
+				'filter' => 'digits',
+			),
+		),
+	);
+}
+
 function wikiplugin_article($data, $params) {
 	global $tikilib,$user,$userlib;
-	include_once('lib/stats/statslib.php');
+	global $statslib; include_once('lib/stats/statslib.php');
 
 	extract ($params,EXTR_SKIP);
 
@@ -39,5 +63,3 @@ function wikiplugin_article($data, $params) {
 	$article_data = $tikilib->get_article($Id);
 	return $article_data[$Field].$add;
 }
-
-?>
