@@ -6,12 +6,62 @@ function wikiplugin_code_help() {
 	return tra($help);
 }
 
+function wikiplugin_code_info() {
+	return array(
+		'name' => tra('Code'),
+		'documentation' => 'PluginCode',
+		'description' => tra('Displays a snippet of code'),
+		'prefs' => array('wikiplugin_code'),
+		'body' => tra('code'),
+		'icon' => 'pics/icons/page_white_code.png',
+		'params' => array(
+			'caption' => array(
+				'required' => false,
+				'name' => tra('Caption'),
+				'description' => tra('Code snippet label.'),
+			),
+			'wrap' => array(
+				'required' => false,
+				'name' => tra('Word Wrap'),
+				'description' => tra('0|1, Enable word wrapping on the code to avoid breaking the layout.'),
+			),
+			'colors' => array(
+				'required' => false,
+				'name' => tra('Colors'),
+				'description' => tra('Syntax highlighting to use. May not be used with line numbers. Available: php, html, sql, javascript, css, java, c, doxygen, delphi, ...'),
+			),
+			'ln' => array(
+				'required' => false,
+				'name' => tra('Line numbers'),
+				'description' => tra('0|1, may not be used with colors.'),
+			),
+			'wiki' => array(
+				'required' => false,
+				'name' => tra('Wiki syntax'),
+				'description' => tra('0|1, parse wiki syntax within the code snippet.'),
+			),
+			'rtl' => array(
+				'required' => false,
+				'name' => tra('Right to left'),
+				'description' => tra('0|1, switch the text display from left to right to right to left'),
+			),
+			'ishtml' => array(
+				'required' => false,
+				'name' => tra('Content is HTML'),
+				'description' => tra('0|1, display the content as is instead of escaping HTML special chars'),
+			),
+		),
+	);
+}
+
 function wikiplugin_code($data, $params) {
 	if ( is_array($params) ) {
 		extract($params, EXTR_SKIP);
 	}
 	$code = trim($data);
+
 	$parse_wiki = ( isset($wiki) && $wiki == 1 );
+	$escape_html = ( ! isset($ishtml) || $ishtml != 1 );
 
 	// Detect if GeSHI (Generic Syntax Highlighter) is available
 	$geshi_paths = array(
@@ -29,11 +79,13 @@ function wikiplugin_code($data, $params) {
 	// If 'color' is specified and GeSHI installed, use syntax highlighting with GeSHi
 	if ( isset($colors) && $colors != 'highlights' && class_exists('GeSHI') ) {
 
-		$geshi =& new GeSHi(TikiLib::htmldecode($code), $colors);
+		$geshi =& new GeSHi($code, $colors);
 
 		if ( version_compare(GESHI_VERSION, 1.1) == -1) { // Old API
 			if ( isset($ln) && $ln > 0 ) {
-				$geshi->enable_line_numbers(GESHI_FANCY_LINE_NUMBERS);
+				$geshi->set_code_style('background: #f5f5f5;'); //improves line spacing and fancy numbers
+				$geshi->set_header_type(GESHI_HEADER_PRE_TABLE); //allows user to select code from screen without line numbers for copying and pasting
+				$geshi->enable_line_numbers(GESHI_FANCY_LINE_NUMBERS); //highlights every 5th line number
 				$geshi->start_line_numbers_at($ln);
 			}
 			$geshi->set_link_target('_blank');
@@ -48,9 +100,11 @@ function wikiplugin_code($data, $params) {
 			$out = trim($out);
 		}
 
+		if ( ! $escape_html ) $out = TikiLib::htmldecode($out);
+
 	} elseif ( isset($colors) && ( $colors == 'highlights' || $colors == 'php' ) ) {
 
-		$out = highlight_string(TikiLib::htmldecode($code), true);
+		$out = highlight_string($code, true);
 
 		// Convert &nbsp; into spaces and <br /> tags into real line breaks, since it will be displayed in a <pre> tag
 		$out = str_replace('&nbsp;', ' ', $out);
@@ -63,6 +117,8 @@ function wikiplugin_code($data, $params) {
 		$out = ereg_replace("^\s*(<[^>]+>)\n", '\\1', $out);
 		$out = trim($out);
 
+		if ( ! $escape_html ) $out = TikiLib::htmldecode($out);
+
 	} else {
 
 		$out = trim($code);
@@ -78,6 +134,7 @@ function wikiplugin_code($data, $params) {
 			$out = $code;
 		}
 
+		if ( $escape_html ) $out = htmlentities($out,ENT_COMPAT,"utf-8");
 	}
 
 	if ( isset($wrap) && $wrap == 1 ) {
@@ -103,6 +160,4 @@ function wikiplugin_code($data, $params) {
 	}
 
 	return $out;
-}
-
-?>
+}
\ No newline at end of file
