@@ -16,16 +16,27 @@ function wikiplugin_copyright_help() {
 	return tra("Insert copyright notices").":<br />~np~{COPYRIGHT()}~title~~year~~authors~".tra("text")."{COPYRIGHT}~/np~";
 }
 
+function wikiplugin_copyright_info() {
+	return array(
+		'name' => tra('Copyright'),
+		'documentation' => 'PluginCopyright',
+		'description' => tra('Insert copyright notices'),
+		'prefs' => array( 'wiki_feature_copyrights', 'wikiplugin_copyright' ),
+		'body' => tra('Pattern to display the copyright in. May contain ~title~, ~year~ and ~authors~.'),
+		'params' => array(
+		),
+	);
+}
+
 function wikiplugin_copyright($data, $params) {
 	global $dbTiki;
 
-	$copyrightslib = new CopyrightsLib($dbTiki);
+	$copyrightslib = new CopyrightsLib;
 
 	if (!isset($_REQUEST['page'])) {
 		return '';
 	}
 
-	//extract($params);
 	$result = '';
 
 	$copyrights = $copyrightslib->list_copyrights($_REQUEST['page']);
@@ -46,5 +57,3 @@ function wikiplugin_copyright($data, $params) {
 
 	return $result;
 }
-
-?>
