@@ -9,6 +9,22 @@ function wikiplugin_lastmod_help() {
         return tra("The last_mod plugin replaces itself with last modification time of the named wiki page, or the current page if no name given").":<br />~np~{LASTMOD(page=>pagename)/}~/np~";
 }
 
+function wikiplugin_lastmod_info() {
+	return array(
+		'name' => tra('Last Modification'),
+		'documentation' => 'PluginLastMod',			
+		'description' => tra("The last_mod plugin replaces itself with last modification time of the named wiki page, or the current page if no name given"),
+		'prefs' => array('feature_wiki', 'wikiplugin_lastmod'),
+		'params' => array(
+			'page' => array(
+				'required' => false,
+				'name' => tra('Page'),
+				'description' => tra('Page name to display information of. Default value is current page.'),
+			),
+		),
+	);
+}
+
 function wikiplugin_lastmod($data, $params) {
 
 	global $tikilib;
@@ -23,10 +39,8 @@ function wikiplugin_lastmod($data, $params) {
 
 	}
 
-	$lastmod = $tikilib->date_format( "%a, %e %b %Y %H:%M:%S %0", $tikilib->page_exists_modtime($page) );
+	$lastmod = $tikilib->date_format( "%a, %e %b %Y %H:%M:%S %Z", $tikilib->page_exists_modtime($page) );
 
 	return $lastmod;
 
 }
-
-?>
