@@ -15,6 +15,26 @@ function wikiplugin_quote_help() {
 	return tra("Quote text by surrounding the text with a box, like the [QUOTE] BBCode").":<br />~np~{QUOTE(replyto=>name)}".tra("text")."{QUOTE}~/np~";
 }
 
+function wikiplugin_quote_info() {
+	return array(
+		'name' => tra('Quote'),
+		'documentation' => 'PluginQuote',
+		'description' => tra("Quote text by surrounding the text with a box, like the [QUOTE] BBCode"),
+		'prefs' => array( 'wikiplugin_quote' ),
+		'body' => tra('Quoted text'),
+		'icon' => 'pics/icons/quotes.png',
+		'filter' => 'text',
+		'params' => array(
+			'replyto' => array(
+				'required' => false,
+				'name' => tra('Reply to'),
+				'description' => tra('Name of the quoted person.'),
+				'filter' => 'text',
+			),
+		),
+	);
+}
+
 function wikiplugin_quote($data, $params) {
 	/* set default values for some args */
 	
@@ -25,7 +45,7 @@ function wikiplugin_quote($data, $params) {
     
 	extract ($params, EXTR_SKIP);
 	if (!empty($replyto)) {
-		$caption = $replyto . tra(' wrote:');
+		$caption = $replyto .' '.tra('wrote:');
 	} else {
 		$caption = tra('Quote:');
 	}
@@ -39,5 +59,3 @@ function wikiplugin_quote($data, $params) {
 //    if (substr($data, 0, 1) != "\n") $data = "\n".$data;
 	return $begin . $data . $end;
 }
-
-?>
