@@ -22,10 +22,27 @@ You can change your defaults
 
  */
 
- function wikiplugin_skype_help() {
+function wikiplugin_skype_help() {
         return tra("Clickable Skype link").":<br />~np~{SKYPE(action->call|chat)}name or number{SKYPE}~/np~";
 }
 
+function wikiplugin_skype_info() {
+	return array(
+		'name' => tra('Skype'),
+		'documentation' => 'PluginSkype',
+		'description' => tra('Clickable Skype link'),
+		'prefs' => array( 'wikiplugin_skype' ),
+		'body' => tra('Name or number to call or chat with.'),
+		'params' => array(
+			'action' => array(
+				'required' => false,
+				'name' => tra('Action'),
+				'description' => 'call|chat',
+			),
+		),
+	);
+}
+
 function wikiplugin_skype($data, $params) {
 
 	extract ($params,EXTR_SKIP);
@@ -51,5 +68,3 @@ $ret2 = "<a href='skype:$data?$action' onclick='return skypeCheck();'>$data?$act
 	
 	return $ret1.$ret2;
 }
-
-?>
