@@ -10,6 +10,25 @@ function wikiplugin_sort_help() {
 	return tra("Sorts the plugin content in the wiki page").":<br />~np~{SORT(sort=>asc|desc|reverse|shuffle)}".tra("data")."{SORT}~/np~ - ''".tra("one data per line")."''";
 }
 
+function wikiplugin_sort_info() {
+	return array(
+		'name' => tra('Sort'),
+		'documentation' => 'PluginSort',
+		'description' => tra('Sorts the plugin content in the wiki page'),
+		'prefs' => array( 'wikiplugin_sort' ),
+		'body' => tra('Data to sort, one entry per line.'),
+		'filter' => 'text',
+		'params' => array(
+			'sort' => array(
+				'required' => false,
+				'name' => tra('Order'),
+				'description' => tra('asc|desc|shuffle'),
+				'filter' => 'alpha',
+			),
+		),
+	);
+}
+
 function wikiplugin_sort($data, $params) {
 	global $tikilib;
 
@@ -17,7 +36,7 @@ function wikiplugin_sort($data, $params) {
 
 	$sort = (isset($sort)) ? $sort : "asc";
 
-	$lines = explode("\n", $data); // separate lines into array
+	$lines = preg_split("/\n+/", $data, -1, PREG_SPLIT_NO_EMPTY); // separate lines into array
 	// $lines = array_filter( $lines, "chop" ); // remove \n  
 	srand ((float)microtime() * 1000000); // needed for shuffle;
 
@@ -40,5 +59,3 @@ function wikiplugin_sort($data, $params) {
 	$data = trim($data);
 	return $data;
 }
-
-?>
