@@ -5,6 +5,43 @@ function wikiplugin_trackerfilter_help() {
   $help .= "~np~{TRACKERFILTER(filters=>2/d:4/r:5,action=>Name of submit button,displayList=y|n,line=y|n,TRACKERLIST_params )}Notice{TRACKERFILTER}~/np~";
   return $help;
 }
+
+function wikiplugin_trackerfilter_info() {
+	require_once 'lib/wiki-plugins/wikiplugin_trackerlist.php';
+	$list = wikiplugin_trackerlist_info();
+	$params = array_merge( $list['params'], array(
+		'filters' => array(
+			'required' => true,
+			'name' => tra('Filters'),
+			'description' => tra('Example:') . '2/d:4/r:5',
+		),
+		'action' => array(
+			'required' => false,
+			'name' => tra('Action'),
+			'description' => tra('Label on the submit button'),
+		),
+		'displayList' => array(
+			'required' => false,
+			'name' => tra('Display List'),
+			'description' => 'y|n',
+		),
+		'line' => array(
+			'required' => false,
+			'name' => tra('Line'),
+			'description' => 'y|n - displays all the filter on the same line',
+		),
+	) );
+
+return array(
+		'name' => tra('Tracker Filter'),
+		'documentation' => 'PluginTrackerFilter',
+		'description' => tra("Filters the items of a tracker, fields are indicated with numeric ids."),
+		'prefs' => array( 'feature_trackers', 'wikiplugin_trackerfilter' ),
+		'body' => tra('notice'),
+		'params' => $params,
+	);
+}
+
 function wikiplugin_trackerfilter($data, $params) {
 	global $smarty, $prefs;
 	global $trklib;	include_once('lib/trackers/trackerlib.php');
@@ -17,8 +54,7 @@ function wikiplugin_trackerfilter($data, $params) {
 		$smarty->assign('msgTrackerFilter', $_REQUEST['msgTrackerFilter']);
 	}
 	if (!isset($filters)) {
-		$smarty->assign('msg', tra("missing parameters"));
-		return $dataRes.$smarty->fetch("error_simple.tpl");
+		return tra('missing parameters').' filters';
 	}
 	$listfields = split(':',$filters);
 	foreach ($listfields as $i=>$f) {
@@ -47,11 +83,11 @@ function wikiplugin_trackerfilter($data, $params) {
 			}
 		}
 	}
+	if (empty($trackerId) || !($tracker = $trklib->get_tracker($trackerId))) {
+		return $smarty->fetch("wiki-plugins/error_tracker.tpl");
+	}
 	if ($displayList == 'y' || isset($_REQUEST['filter']) || isset($_REQUEST['tr_offset']) || isset($_REQUEST['tr_sort_mode'])) {
 	  
-		if (!isset($trackerId) || !($tracker = $trklib->get_tracker($trackerId))) {
-			return $smarty->fetch("wiki-plugins/error_tracker.tpl");
-		}
 		if (!isset($fields)) {
 			$smarty->assign('msg', tra("missing parameters"));
 			return $msg;
@@ -87,7 +123,11 @@ function wikiplugin_trackerfilter($data, $params) {
 	}
 
 	$filters = wikiplugin_trackerFilter_get_filters($trackerId, $listfields, $formats);
+	if (!is_array($filters)) {
+		return $filters;
+	}
 	$smarty->assign_by_ref('filters', $filters);
+	//echo '<pre>';print_r($filters); echo '</pre>';
 	$smarty->assign_by_ref('trackerId', $trackerId);
 	$smarty->assign_by_ref('line', $line);
 	static $iTrackerFilter = 0;
@@ -182,7 +222,7 @@ function wikiplugin_trackerFilter_get_filters($trackerId=0, $listfields='', $for
 				foreach ($field['options_array'] as $val) {
 					$opt['id'] = $val;
 					$opt['name'] = $val;
-					if (!empty($_REQUEST['f_'.$fieldId]) && $_REQUEST['f_'.$fieldId][0] == $val) {
+					if (!empty($_REQUEST['f_'.$fieldId]) && ((!is_array($_REQUEST['f_'.$fieldId]) && $_REQUEST['f_'.$fieldId] == $val) || (is_array($_REQUEST['f_'.$fieldId]) && in_array($val, $_REQUEST['f_'.$fieldId])))) {
 						$opt['selected'] = 'y';
 						$selected = true;
 					} else {
@@ -191,6 +231,27 @@ function wikiplugin_trackerFilter_get_filters($trackerId=0, $listfields='', $for
 					$opts[] = $opt;
 				}
 				break;
+			case 'c': // checkbox
+				$opt['id'] = 'y';
+				$opt['name'] = 'Yes';
+				if (!empty($_REQUEST['f_'.$fieldId]) && $_REQUEST['f_'.$fieldId] == 'y') {
+					$opt['selected'] = 'y';
+					$selected = true;
+				} else {
+					$opt['selected'] = 'n';
+				}
+				$opts[] = $opt;
+				$opt['id'] = 'n';
+				$opt['name'] = 'No';
+				if (!empty($_REQUEST['f_'.$fieldId]) && $_REQUEST['f_'.$fieldId] == 'n') {
+					$opt['selected'] = 'y';
+					$selected = true;
+				} else {
+					$opt['selected'] = 'n';
+				}
+				$opts[] = $opt;
+				$formats[$fieldId] = 'r';
+				break;
 			case 'n': // numeric
 			case 'D': // drop down + other
 			case 't': // text
@@ -200,6 +261,9 @@ function wikiplugin_trackerFilter_get_filters($trackerId=0, $listfields='', $for
 			case 'y': // country
 			case 'w': //dynamic item lists
 			case 'r': //item link
+			case 'k': //page selector
+			case 'u': // user
+			case 'g': // group
 				if (isset($status)) {
 					$res = $trklib->list_tracker_field_values($trackerId, $fieldId, $status);
 				} else {
@@ -216,15 +280,13 @@ function wikiplugin_trackerFilter_get_filters($trackerId=0, $listfields='', $for
 					}
 					$opts[] = $opt;
 				}
-				break;		
+				break;
 		
 			default:
-				$smarty->assign('msg', tra("tracker field type not processed yet"));
-				return $dataRes.$smarty->fetch("error_simple.tpl");
+				return tra('tracker field type not processed yet').' '.$field['type'];
 			}
 		}
 		$filters[] = array('name' => $field['name'], 'fieldId' => $fieldId, 'format'=>$formats[$fieldId], 'opts' => $opts, 'selected'=>$selected);
 	}
 	return $filters;
 }
-?>
