@@ -10,6 +10,19 @@ function wikiplugin_usercount_help() {
         return tra("Displays the number of registered users").":<br />~np~{USERCOUNT()}groupname{USERCOUNT}~/np~";
 }
 
+function wikiplugin_usercount_info() {
+	return array(
+		'name' => tra('User Count'),
+		'documentation' => 'PluginUserCount',		
+		'description' => tra('Displays the number of registered users'),
+		'prefs' => array( 'wikiplugin_usercount' ),
+		'body' => tra('Group name'),
+		'icon' => 'pics/icons/group_gear.png',
+		'params' => array(
+		),
+	);
+}
+
 function wikiplugin_usercount($data, $params) {
         global $tikilib;
 
@@ -21,5 +34,3 @@ function wikiplugin_usercount($data, $params) {
 
         return $numusers;
 }
-
-?>
