@@ -1,5 +1,5 @@
 <?php
-// $Id: /cvsroot/tikiwiki/tiki/lib/wiki/wikilib.php,v 1.110.2.11 2008-02-27 15:18:48 nyloth Exp $
+// $Id: wikilib.php 25606 2010-02-23 22:47:00Z pkdille $
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
@@ -12,9 +12,6 @@ if( !defined( 'PLUGINS_DIR' ) ) {
 
 
 class WikiLib extends TikiLib {
-    function WikiLib($db) {
-	$this->TikiLib($db);
-    }
 
     //Special parsing for multipage articles
     function get_number_of_pages($data) {
@@ -62,7 +59,7 @@ class WikiLib extends TikiLib {
      *  Get the contributors for page
      *  the returned array does not contain the user $last (usually the current or last user)
      */
-    function get_contributors($page, $last='') {
+    function get_contributors($page, $last='', $versions=true) {
 		static $cache_page_contributors;
 		if ($cache_page_contributors['page'] == $page) {
 			if (empty($last)) {
@@ -76,7 +73,12 @@ class WikiLib extends TikiLib {
 			}
 			return $ret;
 		}
-		$query = "select DISTINCT `user` from `tiki_history` where `pageName`=? order by `version` desc";
+		if ($versions) {
+			$vstring = ',`version`';
+		} else {
+			$vstring = '';
+		}
+		$query = "select DISTINCT `user`$vstring from `tiki_history` where `pageName`=? order by `version` desc";
 		$result = $this->query($query,array($page));
 		$cache_page_contributors = array();
 		$cache_page_contributors['contributors'] = array();
@@ -126,13 +128,12 @@ class WikiLib extends TikiLib {
 	function wiki_rename_page($oldName, $newName) {
 		global $prefs, $tikilib;
 		// if page already exists, stop here
+		$newName = trim($newName);
 		if ($this->page_exists($newName)) {
 			// if it is a case change of same page: allow it, else stop here
-			if (strcasecmp($oldName, $newName) <> 0) return false;
+			if (strcasecmp(trim($oldName), $newName) <> 0 ) return false;
 		}
 
-		// Since page link have HTML chars fixed;
-		$newName = htmlspecialchars( $newName );
 		$tmpName = "TmP".$newName."TmP";
 
 		// 1st rename the page in tiki_pages, using a tmpname inbetween for
@@ -152,12 +153,19 @@ class WikiLib extends TikiLib {
 		$this->query($query, array( $newName, $tmpName ) );
 
 		// get pages linking to the old page
-		$query = "select `fromPage` from `tiki_links` where `toPage`=?";
+		$query = "select `fromPage`, `reltype` from `tiki_links` where `toPage`=?";
 		$result = $this->query($query, array( $oldName ) );
 
 		$linksToOld=array();
 		while ($res = $result->fetchRow()) {			
 		    $page = $res['fromPage'];
+			$types = $res['reltype'];
+
+			$semantics = array();
+			if( ! empty($types) ) {
+				$semantics = explode(',', $types );
+			}
+
 		    $is_wiki_page = true;
 		    if (substr($page,0,11) == 'objectlink:') {
 		    	$is_wiki_page = false;
@@ -177,12 +185,17 @@ class WikiLib extends TikiLib {
 				$comment_info = $commentslib->get_comment($objectId);
 				$data = $comment_info['data'];
 		    }
-		    $oldName = quotemeta( $oldName );
- 		    if (strstr($newName, " "))
-		    	$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$oldName(?= |\n|\t|\r|\,|\;|$)/", "((".$newName."))", $data);
-		    else
-		    	$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$oldName(?= |\n|\t|\r|\,|\;|$)/", $newName, $data);
-		    $data = preg_replace("/(?<=\(\()$oldName(?=\)\)|\|)/", $newName, $data);
+		    $quotedOldName = preg_quote( $oldName, '/' );
+			foreach( $semantics as $sem ) {
+				$data = str_replace( "($sem($oldName", "($sem($newName", $data );
+			}
+
+			if (strstr($newName, " "))
+				$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$quotedOldName(?= |\n|\t|\r|\,|\;|$)/", "((".$newName."))", $data);
+			else
+				$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$quotedOldName(?= |\n|\t|\r|\,|\;|$)/", $newName, $data);
+			$data = preg_replace("/(?<=\(\()$quotedOldName(?=\)\)|\|)/", $newName, $data);
+
 		    if ($is_wiki_page) {
 		    	$query = "update `tiki_pages` set `data`=?,`page_size`=? where `pageName`=?";
 		    	$this->query($query, array( $data,(int) strlen($data), $page));
@@ -233,6 +246,8 @@ class WikiLib extends TikiLib {
 		$newId = 'wikipage' . $newName;
 		$query = "update `tiki_user_watches` set `object`=? where `object`=?";
 		$this->query($query, array( $newId, $oldId ) );
+		$query = "update `tiki_group_watches` set `object`=? where `object`=?";
+		$this->query($query, array( $newId, $oldId ) );
 
 		// theme_control_objects(objId,name)
 		$oldId = md5('wiki page' . $oldName);
@@ -278,6 +293,8 @@ class WikiLib extends TikiLib {
 		// user watches
 		$query = "update `tiki_user_watches` set `object`=?, `title`=?, `url`=? where `object`=? and `type` = 'wiki page'";
 		$this->query($query, array( $newName, $newName, 'tiki-index.php?page='.$newName, $oldName ) );
+		$query = "update `tiki_group_watches` set `object`=?, `title`=?, `url`=? where `object`=? and `type` = 'wiki page'";
+		$this->query($query, array( $newName, $newName, 'tiki-index.php?page='.$newName, $oldName ) );
 
 		// now send notification email to all on the watchlist:
 		if ($prefs['feature_user_watches'] == 'y') {
@@ -291,6 +308,7 @@ class WikiLib extends TikiLib {
 				$smarty->assign('mail_newname', $newName);
 				$smarty->assign('mail_date', $this->now);
 				$smarty->assign('mail_user', $user);
+				$smarty->assign('watchId', $nots['watchId']);
 				$foo = parse_url($_SERVER["REQUEST_URI"]);
 				$machine = $tikilib->httpPrefix(). $foo["path"];
 				$smarty->assign('mail_machine', $machine);
@@ -313,6 +331,10 @@ class WikiLib extends TikiLib {
 		if ($prefs['wikiHomePage'] == $oldName) {
 			$tikilib->set_preference('wikiHomePage', $newName);
 		}
+		if ($prefs['feature_trackers'] == 'y') {
+			global $trklib; include_once('lib/trackers/trackerlib.php');
+			$trklib->rename_page($oldName, $newName);
+		}
 
 		return true;
 	}
@@ -335,6 +357,32 @@ class WikiLib extends TikiLib {
 		$res = $result->fetchRow();
 		return $res;
 	}
+	function get_parse($page, &$canBeRefreshed) {
+		global $prefs, $user;
+		$content = '';
+		$canBeRefreshed = false;
+		if ($prefs['wiki_cache'] > 0 && empty($user) ) {
+			$cache_info = $this->get_cache_info($page);
+			if (!empty($cache_info['cache_timestamp']) && $cache_info['cache_timestamp'] + $prefs['wiki_cache'] > $this->now) {
+				$content = $cache_info['cache'];
+				$canBeRefreshed = true;
+			} else {
+				$info = $this->get_page_info($page);
+				if (!empty($info)) {
+					$content = $this->parse_data($info['data'],  array('is_html' => $info['is_html']));
+					if (!empty($info['wiki_cache'])) {
+						$this->update_cache($page, $content);
+					}
+				}
+			}
+		} else {
+			$info = $this->get_page_info($page);
+			if (!empty($info)) {
+				$content = $this->parse_data($info['data'], array('is_html' => $info['is_html']));
+			}
+		}
+		return $content;
+	}
 
 	function update_cache($page, $data) {
 
@@ -363,14 +411,21 @@ class WikiLib extends TikiLib {
 
 	function wiki_attach_file($page, $name, $type, $size, $data, $comment, $user, $fhash) {
 		$comment = strip_tags($comment);
-		$query = "insert into `tiki_wiki_attachments`(`page`,`filename`,`filesize`,`filetype`,`data`,`created`,`hits`,`user`,`comment`,`path`) values(?,?,?,?,?,?,0,?,?,?)";
-		$this->blob_encode($data);
-		$result = $this->query($query,array("$page","$name", (int) $size,"$type","$data", (int) $this->now,"$user","$comment","$fhash"));
+		$now = $this->now;
+		$query = "insert into `tiki_wiki_attachments`(`page`,`filename`,`filesize`,`filetype`,`data`,`created`,`hits`,`user`,`comment`,`path`) values(?,?,?,?,?,?,?,?,?,?)";
+		//$this->blob_encode($data);
+		$result = $this->query($query,array($page, $name, (int)$size, $type, $data, (int)$now, 0, $user, $comment, $fhash));
 
 		global $prefs;
-	        if ($prefs['feature_score'] == 'y') {
-        	    $this->score_event($user, 'wiki_attach_file');
-	        }
+		if ($prefs['feature_score'] == 'y') {
+			$this->score_event($user, 'wiki_attach_file');
+		}
+		if ($prefs['feature_user_watches'] = 'y') {
+			include_once('lib/notifications/notificationemaillib.php');
+			$query = 'select `attId` from `tiki_wiki_attachments` where `page`=? and `filename`=? and `created`=? and `user`=?';
+			$attId = $this->getOne($query, array($page, $name, $now, $user));
+			sendWikiEmailNotification('wiki_file_attached', $page, $user, $comment, '', $name, '','', false, '', 0,$attId);
+		}
 	}
 	function get_wiki_attach_file($page, $name, $type, $size) {
 		$query = 'select * from `tiki_wiki_attachments` where `page`=? and `filename`=? and `filetype`=? and `filesize`=?';
@@ -389,7 +444,7 @@ class WikiLib extends TikiLib {
 	    $bindvars=array($page);
 	}
 
-	$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`hits`,`created`,`comment` from `tiki_wiki_attachments` $mid order by ".$this->convert_sortmode($sort_mode);
+	$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`hits`,`created`,`comment` from `tiki_wiki_attachments` $mid order by ".$this->convertSortMode($sort_mode);
 	$query_cant = "select count(*) from `tiki_wiki_attachments` $mid";
 	$result = $this->query($query,$bindvars,$maxRecords,$offset);
 	$cant = $this->getOne($query_cant,$bindvars);
@@ -414,7 +469,7 @@ class WikiLib extends TikiLib {
 			$bindvars=array();
 		}
 		$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`hits`,`created`,`comment`,`path` ";
-		$query.= " from `tiki_wiki_attachments` $mid order by ".$this->convert_sortmode($sort_mode);
+		$query.= " from `tiki_wiki_attachments` $mid order by ".$this->convertSortMode($sort_mode);
 		$query_cant = "select count(*) from `tiki_wiki_attachments` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
@@ -502,7 +557,7 @@ class WikiLib extends TikiLib {
     }
 
     function wiki_link_structure() {
-	$query = "select `pageName` from `tiki_pages` order by ".$this->convert_sortmode("pageName_asc");
+	$query = "select `pageName` from `tiki_pages` order by ".$this->convertSortMode("pageName_asc");
 
 	$result = $this->query($query);
 
@@ -530,7 +585,7 @@ class WikiLib extends TikiLib {
     function remove_last_version($page, $comment = '') {
 
 	$this->invalidate_cache($page);
-	$query = "select * from `tiki_history` where `pageName`=? order by ".$this->convert_sortmode("lastModif_desc");
+	$query = "select * from `tiki_history` where `pageName`=? order by ".$this->convertSortMode("lastModif_desc");
 	$result = $this->query($query, array( $page ) );
 
 	if ($result->numRows()) {
@@ -558,36 +613,54 @@ class WikiLib extends TikiLib {
     }
 
     // Like pages are pages that share a word in common with the current page
-    function get_like_pages($page) {
-	global $user, $tikilib;
-	preg_match_all("/([A-Z])([a-z]+)/", $page, $words);
+	function get_like_pages($page) {
+		global $user, $tikilib, $prefs, $semanticlib;
 
-	// Add support to ((x)) in either strict or full modes
-	preg_match_all("/(([A-Za-z]|[\x80-\xFF])+)/", $page, $words2);
-	$words = array_unique(array_merge($words[0], $words2[0]));
-	$exps = array();
-	$bindvars=array();
-	foreach ($words as $word) {
-	    $exps[] = " `pageName` like ?";
-	    $bindvars[] = "%$word%";
-	}
+		// If pagealias are defined, they should be used instead of generic search
+		if( $prefs['feature_wiki_pagealias'] == 'y' ) {
+			require_once 'lib/wiki/semanticlib.php';
 
-	$exp = implode(" or ", $exps);
-	if ($exp) {
-		$query = "select `pageName` from `tiki_pages` where $exp";
-		$result = $this->query($query,$bindvars);
-		$ret = array();
+			$links = $semanticlib->getLinksUsing(
+				explode( ',', $prefs['wiki_pagealias_tokens'] ),
+				array( 'toPage' => $page ) );
 
-		while ($res = $result->fetchRow()) {
-			if ($tikilib->user_has_perm_on_object($user, $page, 'wiki page', 'tiki_p_view'))
-						$ret[] = $res["pageName"];
+			if( count($links) > 0 ) {
+				$likepages = array();
+				foreach( $links as $row )
+					$likepages[] = $row['fromPage'];
+
+				return $likepages;
+			}
 		}
 
-		return $ret;
-	} else {
-		return array();
+		preg_match_all("/([A-Z])([a-z]+)/", $page, $words);
+
+		// Add support to ((x)) in either strict or full modes
+		preg_match_all("/(([A-Za-z]|[\x80-\xFF])+)/", $page, $words2);
+		$words = array_unique(array_merge($words[0], $words2[0]));
+		$exps = array();
+		$bindvars=array();
+		foreach ($words as $word) {
+			$exps[] = " `pageName` like ?";
+			$bindvars[] = "%$word%";
+		}
+
+		$exp = implode(" or ", $exps);
+		if ($exp) {
+			$query = "select `pageName` from `tiki_pages` where $exp";
+			$result = $this->query($query,$bindvars);
+			$ret = array();
+
+			while ($res = $result->fetchRow()) {
+				if ($tikilib->user_has_perm_on_object($user, $res['pageName'], 'wiki page', 'tiki_p_view'))
+					$ret[] = $res["pageName"];
+			}
+
+			return $ret;
+		} else {
+			return array();
+		}
 	}
-    }
 
     function is_locked($page, $info=null) {
 	if (!$info) {
@@ -597,18 +670,19 @@ class WikiLib extends TikiLib {
 	}
 	return ($info["flag"] == 'L')? $info["user"] : null;
     }
-    function is_editable($page, $user, $info=null) {
-	global $tiki_p_admin, $tiki_p_admin_wiki, $prefs;
-      if ($tiki_p_admin == 'y' || $tiki_p_admin_wiki == 'y')
-            return true;
-      else {
+	function is_editable($page, $user, $info=null) {
+		global $prefs;
+		$perms = Perms::get( array( 'type' => 'wiki page', 'object' => $page ) );
+		if ($perms->admin_wiki) {
+			return true;
+		}
+
 		if ($prefs['feature_wiki_userpage'] == 'y' and strcasecmp(substr($page, 0, strlen($prefs['feature_wiki_userpage_prefix'])), $prefs['feature_wiki_userpage_prefix']) == 0 and strcasecmp($page, $prefs['feature_wiki_userpage_prefix'].$user) != 0)
 			return false;
-		if (!$this->user_has_perm_on_object($user,$page,'wiki page','tiki_p_edit'))
+		if (!$perms->edit )
 			return false;
 		return ($this->is_locked($page, $info) == null || $user == $this->is_locked($page, $info))? true : false;
 	}
-    }
 
     function lock_page($page) {
 	global $user, $tikilib;
@@ -666,69 +740,108 @@ class WikiLib extends TikiLib {
 	return $ret;
     }
 
-    function list_plugins($with_help = false) {
-	$files = array();
-	
-	if (is_dir(PLUGINS_DIR)) {
-	    if ($dh = opendir(PLUGINS_DIR)) {
-		while (($file = readdir($dh)) !== false) {
-		    if (preg_match("/^wikiplugin_.*\.php$/", $file))
-			array_push($files, $file);
-		}
-		closedir ($dh);
-	    }
-	}
-	sort($files);
-	if ($with_help) {
-		global $cachelib;
-		if (!$cachelib->isCached('plugindesc')) {
-			$plugins = array();
-			foreach ($files as $pfile) {
-					$pinfo['file'] = $pfile;
-				$pinfo["help"] = $this->get_plugin_description($pfile);
-				$pinfo["name"] = strtoupper(str_replace(".php", "", str_replace("wikiplugin_", "", $pfile)));
-				$plugins[] = $pinfo;
+	function list_plugins($with_help = false, $area_name = 'wikiedit') {
+		if (isset($_SESSION['wysiwyg']) && $_SESSION['wysiwyg'] == 'y') {
+			// disable all plugin insert help functions
+			$area_name = '';	
+		}	
+		if ($with_help) {
+			global $cachelib, $headerlib;
+			if (empty($_REQUEST['xjxfun'])) { $headerlib->add_jsfile( 'tiki-jsplugin.php' ); }
+			$cachetag = 'plugindesc' . $this->get_language() . $area_name;
+			if (!$cachelib->isCached( $cachetag ) ) {
+				$list = $this->plugin_get_list();
+
+				$plugins = array();
+				foreach ($list as $name) {
+					$pinfo["help"] = $this->get_plugin_description($name, $enabled, $area_name);
+					$pinfo["name"] = strtoupper($name);
+
+					if( $enabled )
+						$plugins[] = $pinfo;
+				}
+				$cachelib->cacheItem($cachetag,serialize($plugins));
+			} else {
+				$plugins = unserialize($cachelib->getCached($cachetag));
 			}
-			$cachelib->cacheItem("plugindesc",serialize($plugins));
+			return $plugins;
 		} else {
-			$plugins = unserialize($cachelib->getCached("plugindesc"));
+			// Only used by PluginManager ... what is that anyway?
+			$files = array();
+
+			if (is_dir(PLUGINS_DIR)) {
+				if ($dh = opendir(PLUGINS_DIR)) {
+					while (($file = readdir($dh)) !== false) {
+						if (preg_match("/^wikiplugin_.*\.php$/", $file))
+							array_push($files, $file);
+					}
+					closedir ($dh);
+				}
+			}
+			sort($files);
+
+			return $files;
 		}
-		return $plugins;
-	} else {
-		return $files;
-    }
 	}
 
     //
     // Call 'wikiplugin_.*_description()' from given file
     //
-    function get_plugin_description($file) {
+    function get_plugin_description($name, &$enabled, $area_name = 'wikiedit') {
     	global $tikilib;
         $data = '';
-        $fp = fopen(PLUGINS_DIR . '/' . $file, 'r');
-        while(!feof($fp)) {
-              $data .= fread($fp,4096);
-        }
-        fclose($fp);
-        $func_name = str_replace('.php', '', $file). '_help';
-    	if (!preg_match('#.*?function\s+' . $func_name .
-    	                '[\s|^]*\([\s|^]*\)[\s|^]*(.+)#msi', $data, $prematch)
-    	    || !preg_match('#\{((?:(?R)|[^{}]+)+)}#ms',
-    	            $prematch[1], $matches)) {
-    	   return '';
-    	}
-        $fun = create_function('', $matches[1]);
-        $ret = $tikilib->parse_data($fun());
-        return $ret;
+
+		if( ( ! $info = $this->plugin_info( $name ) ) && $this->plugin_exists( $name, true ) )
+		{
+			$enabled = true;
+
+			$func_name = "wikiplugin_{$name}_help";
+			if( ! function_exists( $func_name ) )
+				return false;
+
+			$ret = $func_name();
+			return $tikilib->parse_data($ret);
+		}
+		else
+		{
+			global $smarty;
+			$enabled = true;
+
+			$ret = $info;
+
+			if( isset( $ret['prefs'] ) )
+			{
+				global $prefs, $headerlib;
+
+				// If the plugin defines required preferences, they should all be to 'y'
+				foreach( $ret['prefs'] as $pref )
+					if( ! isset( $prefs[$pref] ) || $prefs[$pref] != 'y' )
+					{
+						$enabled = false;
+						return;
+					}
+			}
+
+			if( isset( $ret['documentation'] ) && ctype_alnum( $ret['documentation'] ) ) {
+				$ret['documentation'] = "http://doc.tikiwiki.org/{$ret['documentation']}";
+			}
+			
+			$smarty->assign( 'area_name', $area_name );
+			$smarty->assign( 'plugin', $ret );
+			$smarty->assign( 'plugin_name', strtoupper( $name ) );
+			return $smarty->fetch( 'tiki-plugin_help.tpl' );
+		}
     }
 
-	// get all modified pages for a user (if actionlog is not clean
+	// get all modified pages for a user (if actionlog is not clean)
 	function get_user_all_pages($user, $sort_mode) {
-		$query = "select  distinct(p.`pageName`), p.`user` as lastEditor, p.`creator`, max(a.`lastModif`) as date from `tiki_actionlog` as a, `tiki_pages` as p where a.`object`= p.`pageName` and a.`user`= ? group by p.`pagename` order by ".$this->convert_sortmode($sort_mode);
-		$result = $this->query($query, array($user));
+		$query = "select  p.`pageName`, p.`user` as lastEditor, p.`creator`, max(a.`lastModif`) as date from `tiki_actionlog` as a, `tiki_pages` as p where a.`object`= p.`pageName` and a.`user`= ? and (a.`action`=? or a.`action`=?) group by p.`pageName`, p.`user`, p.`creator` order by ".$this->convertSortMode($sort_mode);
+		$result = $this->query($query, array($user, 'Updated', 'Created'));
 		$ret = array();
 		while ($res = $result->fetchRow()) {
+			if ($this->user_has_perm_on_object($user, $res['pageName'], 'wiki page', 'tiki_p_view')) {
 				$ret[] = $res;
+			}
 		}
 		return $ret;
 	}
@@ -759,14 +872,55 @@ class WikiLib extends TikiLib {
 
 	    return $this->query($query, $bindvals) ? true : false;
 	}
-	function sefurl($page) {
-		global $prefs;
+	function sefurl($page, $with_next='', $all_langs='') {
+		global $prefs, $smarty;
+		if( basename( $_SERVER['PHP_SELF'] ) == 'tiki-all_languages.php' ) {
+			return 'tiki-all_languages.php?page='.urlencode($page);
+		}
+
+        $script_name = 'tiki-index.php';
+        if ($all_langs == 'y') {
+           $script_name = 'tiki-all_languages.php';
+        }
+
+		$href = "$script_name?page=".urlencode($page);
+		if ($with_next) {
+			$href .= '&amp;';
+		}
 		if ($prefs['feature_sefurl'] == 'y') {
-			return urlencode($page);
+			include_once('tiki-sefurl.php');
+			return  filter_out_sefurl($href, $smarty, 'wiki');
 		} else {
-			return 'tiki-index.php?page='.urlencode($page);
+			return $href;
 		}
 	}
+
+	function bestlang($url) {
+		global $prefs;
+		if ($prefs['feature_multilingual'] != 'y' || $prefs['feature_best_language'] != 'y') {
+			return $url;
+		}
+		$parsed_url = parse_url($url);
+		if (!empty($parsed_url["query"])) {
+			$ret = $url . "&amp;bl=y";
+		} else {
+			$ret = $url . "?bl=y";
+		}
+		return $ret; 	
+	}
+
+	function url_for_operation_on_a_page($script_name, $page, $with_next) {
+		$href = "$script_name?page=".urlencode($page);
+		if ($with_next) {
+			$href .= '&amp;';
+		}
+		return $href;
+	}
+
+	function editpage_url($page, $with_next) {
+		return $this->url_for_operation_on_a_page('tiki-editpage.php', $page, $with_next);
+	}
+
 	function move_attachments($old, $new) {
 		$query = 'update `tiki_wiki_attachments` set `page`=? where `page`=?';
 		$this->query($query, array($new, $old));
@@ -775,11 +929,25 @@ class WikiLib extends TikiLib {
 		$query = 'insert into `tiki_pages` (`pageName`,`hits`,`data`,`lastModif`,`comment`,`version`,`user`,`ip`,`description`,`creator`,`page_size`,`is_html`,`created`, `flag`,`points`,`votes`,`pageRank`,`lang`,`lockedby`) select ?,`hits`,`data`,`lastModif`,`comment`,`version`,`user`,`ip`,`description`,`creator`,`page_size`,`is_html`,`created`, `flag`,`points`,`votes`,`pageRank`,`lang`,`lockedby` from `tiki_pages` where `pageName`=?';
 		$this->query($query, array($new, $old));
 	}
+	function refresh_backlinks() {
+		global $tikilib, $prefs;
+		$tikilib->query('delete from tiki_links', array());
+		if ($prefs['feature_backlinks'] == 'n')
+			return;
+		$listpages = $tikilib->list_pageNames();
+		if ($listpages['cant']) {
+			foreach ($listpages['data'] as $from) {
+				$info = $tikilib->get_page_info($from['pageName']);
+				$pages = $tikilib->get_pages($info['data'], true);
+				foreach($pages as $to=>$types) {
+					$tikilib->replace_link($from['pageName'], $to, $types);
+					//echo '<br />FROM:'.$from['pageName']." TO: $to "; print_r($types);
+				}
+			}
+		}
+	}
 
 }
 
 global $wikilib;
-global $dbTiki;
-$wikilib = new WikiLib($dbTiki);
-
-?>
+$wikilib = new WikiLib;
