@@ -17,7 +17,7 @@ require_once ('tiki-setup.php');
 include_once ('lib/banners/bannerlib.php');
 
 if (!isset($bannerlib)) {
-	$bannerlib = new BannerLib($dbTiki);
+	$bannerlib = new BannerLib;
 }
 
 // CHECK FEATURE BANNERS HERE
@@ -29,5 +29,3 @@ if ($prefs['feature_banners'] != 'y') {
 }
 $banner = $bannerlib->select_banner($_REQUEST["zone"]);
 print ($banner);
-
-?>
