@@ -1,30 +1,48 @@
 <?php
-
-// $Id: /cvsroot/tikiwiki/tiki/tiki-admin_calendars.php,v 1.34.2.2 2008-02-12 19:20:11 sylvieg Exp $
-
-// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// (c) Copyright 2002-2009 by authors of the Tiki Wiki/CMS/Groupware Project
+// 
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
-
-// Initialization
+// $Id: /cvsroot/tikiwiki/tiki/tiki-admin_calendars.php,v 1.34.2.2 2008-02-12 19:20:11 sylvieg Exp $
 $section = 'calendar';
 require_once ('tiki-setup.php');
-
+require_once ('lib/categories/categlib.php');
 include_once ('lib/calendar/calendarlib.php');
-
+if ($prefs['feature_groupalert'] == 'y') {
+	include_once ('lib/groupalert/groupalertlib.php');
+}
 if ($tiki_p_admin_calendar != 'y' and $tiki_p_admin != 'y') {
 	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 	$smarty->display("error.tpl");
 	die;
 }
-
 if (!isset($_REQUEST["calendarId"])) {
 	$_REQUEST["calendarId"] = 0;
 } else {
-	 $smarty->assign('individual', $userlib->object_has_one_permission($_REQUEST["calendarId"], 'calendar'));
+	// Check if calendar belongs to perspective
+	$category_jails = $categlib->get_jail();
+	if(!isset($filter['categId']) && !empty($category_jails))
+	{
+		$categories = $categlib->get_object_categories('calendar', $_REQUEST["calendarId"]);
+		if (empty ($categories))
+			$smarty->assign('individual', $userlib->object_has_one_permission($_REQUEST["calendarId"], 'calendar'));
+		else
+		{
+			$intersection = array_intersect($category, $category_jails);
+			if (!empty ($intersection))
+				$smarty->assign('individual', $userlib->object_has_one_permission($_REQUEST["calendarId"], 'calendar'));
+			else
+			{
+					$smarty->assign('errortype', 404);
+					$smarty->assign('msg',tra("Object doesn't exists"));
+					$smarty->display("error.tpl");
+					die;
+			}
+		}
+	}
+	
 }
-
 if (isset($_REQUEST["drop"])) {
 	$area = "delcalendar";
 	if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
@@ -32,10 +50,9 @@ if (isset($_REQUEST["drop"])) {
 		$calendarlib->drop_calendar($_REQUEST["drop"]);
 		$_REQUEST["calendarId"] = 0;
 	} else {
-		key_get($area); 
+		key_get($area);
 	}
 }
-
 if (isset($_REQUEST["save"])) {
 	check_ticket('admin-calendars');
 	$customflags["customlanguages"] = $_REQUEST["customlanguages"];
@@ -45,20 +62,42 @@ if (isset($_REQUEST["save"])) {
 	$customflags["custompriorities"] = $_REQUEST["custompriorities"];
 	$customflags["customsubscription"] = isset($_REQUEST["customsubscription"]) ? $_REQUEST["customsubscription"] : 'n';
 	$customflags["personal"] = $_REQUEST["personal"];
+	$customflags['customstatus'] = isset($_REQUEST['customstatus']) ? $_REQUEST['customstatus'] : 'y';
 	$options = $_REQUEST['options'];
-	if (!preg_match('/^[0-9a-fA-F]{3,6}$/',$options['customfgcolor'])) $options['customfgcolor'] = '000000';
-	if (!preg_match('/^[0-9a-fA-F]{3,6}$/',$options['custombgcolor'])) $options['custombgcolor'] = 'ffffff';
-	$options['startday'] = $_REQUEST['startday_Hour']*60*60;
-	$options['endday'] = $_REQUEST['endday_Hour']*60*60 - 1;
-	$extra = array('calname','description','location','description','language','category','participants','url');
-	foreach ($extra as $ex) {
+	if (array_key_exists('customcolors', $options) && strPos($options['customcolors'], '-') > 0) {
+		$customColors = explode('-', $options['customcolors']);
+		if (!preg_match('/^[0-9a-fA-F]{3,6}$/', $customColors[0])) $options['customfgcolor'] = '000000';
+		else $options['customfgcolor'] = $customColors[0];
+		if (!preg_match('/^[0-9a-fA-F]{3,6}$/', $customColors[1])) $options['custombgcolor'] = 'ffffff';
+		else $options['custombgcolor'] = $customColors[1];
+	}
+	if (!preg_match('/^[0-9a-fA-F]{3,6}$/', $options['customfgcolor'])) $options['customfgcolor'] = '';
+	if (!preg_match('/^[0-9a-fA-F]{3,6}$/', $options['custombgcolor'])) $options['custombgcolor'] = '';
+	$options['startday'] = $_REQUEST['startday_Hour'] * 60 * 60;
+	$options['endday'] = $_REQUEST['endday_Hour'] * 60 * 60 - 1;
+	$extra = array(
+		'calname',
+		'description',
+		'location',
+		'description',
+		'language',
+		'category',
+		'participants',
+		'url',
+		'status',
+		'status_calview'
+	);
+	foreach($extra as $ex) {
 		if (isset($_REQUEST['show'][$ex]) and $_REQUEST['show'][$ex] == 'on') {
 			$options["show_$ex"] = 'y';
 		} else {
 			$options["show_$ex"] = 'n';
 		}
 	}
-	$_REQUEST["calendarId"] = $calendarlib->set_calendar($_REQUEST["calendarId"],$user,$_REQUEST["name"],$_REQUEST["description"],$customflags,$options);
+	$_REQUEST["calendarId"] = $calendarlib->set_calendar($_REQUEST["calendarId"], $user, $_REQUEST["name"], $_REQUEST["description"], $customflags, $options);
+	if ($prefs['feature_groupalert'] == 'y') {
+		$groupalertlib->AddGroup('calendar', $_REQUEST["calendarId"], $_REQUEST['groupforAlert'], !empty($_REQUEST['showeachuser']) ? $_REQUEST['showeachuser'] : 'n');
+	}
 	if ($_REQUEST['personal'] == 'y') {
 		$userlib->assign_object_permission("Registered", $_REQUEST["calendarId"], "calendar", "tiki_p_view_calendar");
 		$userlib->assign_object_permission("Registered", $_REQUEST["calendarId"], "calendar", "tiki_p_view_events");
@@ -70,8 +109,8 @@ if (isset($_REQUEST["save"])) {
 		$cat_objid = $_REQUEST["calendarId"];
 		$cat_desc = $_REQUEST["description"];
 		$cat_name = $_REQUEST["name"];
-		$cat_href = "tiki-calendar.php?calIds[]=".$_REQUEST["calendarId"];
-		include_once("categorize.php");
+		$cat_href = "tiki-calendar.php?calIds[]=" . $_REQUEST["calendarId"];
+		include_once ("categorize.php");
 	}
 }
 if (isset($_REQUEST['clean']) && isset($_REQUEST['days'])) {
@@ -91,10 +130,9 @@ if ($prefs['feature_categories'] == 'y') {
 		}
 	}
 }
-
 if ($_REQUEST["calendarId"]) {
 	$info = $calendarlib->get_calendar($_REQUEST["calendarId"]);
-	setcookie("activeTabs".urlencode(substr($_SERVER["REQUEST_URI"],1)),"tab2");
+	$cookietab = 2;
 } else {
 	$info = array();
 	$info["name"] = '';
@@ -105,9 +143,10 @@ if ($_REQUEST["calendarId"]) {
 	$info["customcategories"] = 'n';
 	$info["custompriorities"] = 'n';
 	$info["customsubscription"] = 'n';
+	$info['customstatus'] = 'y';
 	$info["customurl"] = 'n';
-	$info["customfgcolor"] = '000000';
-	$info["custombgcolor"] = 'ffffff';
+	$info["customfgcolor"] = '';
+	$info["custombgcolor"] = '';
 	$info["show_calname"] = 'y';
 	$info["show_description"] = 'y';
 	$info["show_category"] = 'n';
@@ -119,8 +158,29 @@ if ($_REQUEST["calendarId"]) {
 	$info["personal"] = 'n';
 	$info["startday"] = '25200';
 	$info["endday"] = '72000';
+	$info["defaulteventstatus"] = 0;
+	if (!empty($_REQUEST['show']) && $_REQUEST['show'] == 'mod') {
+		$cookietab = '2';
+	} else {
+		if (!isset($cookietab)) { $cookietab = '1'; }
+	}
 }
-
+if ($prefs['feature_groupalert'] == 'y') {
+	$info["groupforAlertList"] = array();
+	$info["groupforAlert"] = $groupalertlib->GetGroup('calendar', $_REQUEST["calendarId"]);
+	$all_groups = $userlib->list_all_groups();
+	if (is_array($all_groups)) {
+		foreach($all_groups as $g) {
+			$groupforAlertList[$g] = ($g == $info['groupforAlert']) ? 'selected' : '';
+		}
+	}
+	$showeachuser = $groupalertlib->GetShowEachUser('calendar', $_REQUEST['calendarId'], $info['groupforAlert']);
+	$smarty->assign('groupforAlert', $info['groupforAlert']);
+	$smarty->assign_by_ref('groupforAlertList', $groupforAlertList);
+	$smarty->assign_by_ref('showeachuser', $showeachuser);
+}
+setcookie('tab', $cookietab);
+$smarty->assign_by_ref('cookietab', $cookietab);
 $smarty->assign('name', $info["name"]);
 $smarty->assign('description', $info["description"]);
 $smarty->assign('owner', $info["user"]);
@@ -133,6 +193,7 @@ $smarty->assign('customsubscription', $info["customsubscription"]);
 $smarty->assign('customurl', $info["customurl"]);
 $smarty->assign('customfgcolor', $info["customfgcolor"]);
 $smarty->assign('custombgcolor', $info["custombgcolor"]);
+$smarty->assign('customColors', $info["customfgcolor"] . "-" . $info["custombgcolor"]);
 $smarty->assign('show_calname', $info["show_calname"]);
 $smarty->assign('show_description', $info["show_description"]);
 $smarty->assign('show_category', $info["show_category"]);
@@ -142,71 +203,73 @@ $smarty->assign('show_participants', $info["show_participants"]);
 $smarty->assign('show_url', $info["show_url"]);
 $smarty->assign('calendarId', $_REQUEST["calendarId"]);
 $smarty->assign('personal', $info["personal"]);
-$smarty->assign('startday', $info["startday"] < 0 ?0: round($info['startday']/(60*60)));
-$smarty->assign('endday', $info["endday"] < 0 ?0: round($info['endday']/(60*60)));
-$smarty->assign('hours', array('0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20','21','22','23','24'));
-
+$smarty->assign('startday', $info["startday"] < 0 ? 0 : round($info['startday'] / (60 * 60)));
+$smarty->assign('endday', $info["endday"] < 0 ? 0 : round($info['endday'] / (60 * 60)));
+$smarty->assign('hours', array(
+	'0',
+	'1',
+	'2',
+	'3',
+	'4',
+	'5',
+	'6',
+	'7',
+	'8',
+	'9',
+	'10',
+	'11',
+	'12',
+	'13',
+	'14',
+	'15',
+	'16',
+	'17',
+	'18',
+	'19',
+	'20',
+	'21',
+	'22',
+	'23'
+));
+$smarty->assign('defaulteventstatus', $info['defaulteventstatus']);
+$smarty->assign('eventstatus', array(
+	0 => tra('Tentative') ,
+	1 => tra('Confirmed') ,
+	2 => tra('Cancelled')
+));
+$smarty->assign_by_ref('info', $info);
 if (!isset($_REQUEST["sort_mode"])) {
 	$sort_mode = 'name_desc';
 } else {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
-
 $smarty->assign_by_ref('sort_mode', $sort_mode);
-
 if (isset($_REQUEST["find"])) {
 	$find = $_REQUEST["find"];
 } else {
 	$find = '';
 }
-
 $smarty->assign('find', $find);
-
-$calendars = $calendarlib->list_calendars(0, -1, $sort_mode, $find);
-
-foreach (array_keys($calendars["data"]) as $i) {
-	$calendars["data"][$i]["individual"] = $userlib->object_has_one_permission($i, 'calendar');
-}
-
 if (!isset($_REQUEST["offset"])) {
 	$offset = 0;
 } else {
 	$offset = $_REQUEST["offset"];
 }
 $smarty->assign_by_ref('offset', $offset);
-
-$cant_pages = ceil($calendars["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
-if ($calendars["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
+$calendars = $calendarlib->list_calendars($offset, $maxRecords, $sort_mode, $find);
+foreach(array_keys($calendars["data"]) as $i) {
+	$calendars["data"][$i]["individual"] = $userlib->object_has_one_permission($i, 'calendar');
 }
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
-}
-
+$smarty->assign_by_ref('cant', $calendars['cant']);
 $smarty->assign_by_ref('calendars', $calendars["data"]);
-
 // $cat_type = 'calendar';
 // $cat_objid = $_REQUEST["calendarId"];
 // include_once ("categorize_list.php");
 include_once ('tiki-section_options.php');
-
 ask_ticket('admin-calendars');
-
 // disallow robots to index page:
 $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
-
 // Display the template
 $smarty->assign('uses_tabs', 'y');
 $smarty->assign('mid', 'tiki-admin_calendars.tpl');
 $smarty->display("tiki.tpl");
-
-?>
