@@ -9,15 +9,25 @@ require_once ('tiki-setup.php');
 require_once ('lib/tikilib.php');
 require_once ('lib/rss/rsslib.php');
 
+if ($prefs['feature_articles'] != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_articles");
+	$smarty->display("error.tpl");
+	die;
+}
+
 if ($prefs['rss_articles'] != 'y') {
 	$errmsg=tra("rss feed disabled");
 	require_once ('tiki-rss_error.php');
 }
 
-if ($tiki_p_read_article != 'y') {
-	$smarty->assign('errortype', 401);
-	$errmsg=tra("Permission denied you cannot view this section");
-	require_once ('tiki-rss_error.php');
+$res=$access->authorize_rss(array('tiki_p_read_article','tiki_p_admin_cms'));
+if($res) {
+   if($res['header'] == 'y') {
+      header('WWW-Authenticate: Basic realm="'.$tikidomain.'"');
+      header('HTTP/1.0 401 Unauthorized');
+   }
+   $errmsg=$res['msg'];
+   require_once ('tiki-rss_error.php');
 }
 
 $feed = "articles";
@@ -42,7 +52,7 @@ $uniqueid .= '/'.$articleLang;
 
 if ($topic and !$tikilib->user_has_perm_on_object($user,$topic,'topic','tiki_p_topic_read')) {
 	$smarty->assign('errortype', 401);
-	$errmsg=tra("Permission denied you cannot view this section");
+	$errmsg=tra("Permission denied. You cannot view this section");
 	require_once ('tiki-rss_error.php');
 }
 
@@ -65,11 +75,13 @@ if ($output["data"]=="EMPTY") {
 	$tmp = $prefs['desc_rss_'.$feed];
 	if ($desc<>'') $desc = $tmp;
 
-	$changes = $tikilib -> list_articles(0, $prefs['max_rss_articles'], $dateId.'_desc', '', $tikilib->now, $user, '', $topic, 'y', '', '', '', '', $articleLang);
+	$changes = $tikilib -> list_articles(0, $prefs['max_rss_articles'], $dateId.'_desc', '', 0, $tikilib->now, $user, '', $topic, 'y', '', '', '', '', $articleLang);
 	$tmp = array();
+	include_once('tiki-sefurl.php');
 	foreach ($changes["data"] as $data)  {
-		$data["$descId"] = $tikilib->parse_data($data["$descId"]);
+		$data["$descId"] = $tikilib->parse_data($data[$descId], array('print'=>true));
 		$data["body"] = null;
+		$data['sefurl'] = filter_out_sefurl(sprintf($readrepl, $data['articleId']), $smarty, 'article', $data['title']);
 		$tmp[] = $data;
 	}
 	$changes["data"] = $tmp;
@@ -78,5 +90,3 @@ if ($output["data"]=="EMPTY") {
 }
 header("Content-type: ".$output["content-type"]);
 print $output["data"];
-
-?>
