@@ -25,7 +25,7 @@ if ($tiki_p_admin_calendar != 'y') {
 }
 
 if (isset($_REQUEST["import"]) && isset($_REQUEST["calendarId"]) && isset($_FILES["fileCSV"])) {
-	if ($calendarlib->importCSV($_FILES["fileCSV"]["name"], $_REQUEST["calendarId"]))
+	if ($calendarlib->importCSV($_FILES["fileCSV"]["tmp_name"], $_REQUEST["calendarId"]))
 		$smarty->assign('updated', "y");
 }
 $calendars = $calendarlib->list_calendars(); // no check perm as p_admin only
@@ -39,5 +39,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-calendar_import.tpl');
 $smarty->display("tiki.tpl");
-
-?>
