@@ -9,15 +9,17 @@
 // Initialization
 require_once ('tiki-setup.php');
 
-if (!isset($prefs['email_due']) || $prefs['email_due'] < 0) {
-	$smarty->assign('msg', tra('This feature is disabled'));
+if ((isset($prefs['email_due']) && $prefs['email_due'] < 0 ) && $prefs['validateUsers'] != 'y') {
+	$smarty->assign('msg', tra('This feature is disabled'.$prefs['validateUsers']));
 	$smarty->display('error.tpl');
 	die;
 }
 
 if (isset($_REQUEST['user']) && isset($_REQUEST['pass'])) {
 	if ($userlib->confirm_email($_REQUEST['user'], $_REQUEST['pass'])) {
-		$_SESSION["$user_cookie_site"] = $user = $_REQUEST['user'];
+		if (empty($user)) {
+			$_SESSION["$user_cookie_site"] = $user = $_REQUEST['user'];
+		}
 		header('Location: tiki-information.php?msg='.urlencode('Account validated successfully.'));
 		die;
 	}
@@ -25,4 +27,3 @@ if (isset($_REQUEST['user']) && isset($_REQUEST['pass'])) {
 
 $smarty->assign('msg', tra('Problem. Try to log in again to receive new confirmation instructions.'));
 $smarty->display('error.tpl');
-?>
