@@ -11,9 +11,13 @@ session.
 The parameters in the session will be stored under 
 $_SESSION['tiki_cookie_jar'][ $parameter_name ]
 */
+$tikiroot = dirname($_SERVER['PHP_SELF']);
+$session_params = session_get_cookie_params();
+session_set_cookie_params($session_params['lifetime'],$tikiroot);
+unset($session_params);
+
 session_start();
 
 if( isset( $_GET ) )
 	foreach( $_GET as $key=>$value )
 		$_SESSION['tiki_cookie_jar'][$key] = $value;
-?>
