@@ -68,7 +68,7 @@ $smarty->assign_by_ref('struct_info',$struct_info);
 
 if (!$tikilib->user_has_perm_on_object($user,$struct_info["pageName"],'wiki page','tiki_p_view')) {
 	$smarty->assign('errortype', 401);
-	$smarty->assign('msg',tra('Permission denied you cannot view this page'));
+	$smarty->assign('msg',tra('Permission denied. You cannot view this page.'));
 	$smarty->display("error.tpl");
 	die;
 }
@@ -124,5 +124,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-create_webhelp.tpl');
 $smarty->display("tiki.tpl");
-
-?>
