@@ -9,22 +9,6 @@
 // Initialization
 require_once ('tiki-setup.php');
 
-//ini_set('include_path','.;pear/');
-//include('foobar.php');
-/*
-hfd
-require_once "lib/NNTP.php";
-$nntp = new Net_NNTP;
-$ret = $nntp->connect("news.php.net");
-$groups = $nntp->getGroups();
-//print_r($groups);
-$z = $nntp->selectGroup('php.announce');
-print_r($z);
-$h = $nntp->splitHeaders(1);
-print_r($h);
-$b = $nntp->getBody(1);
-print_r($b);
-*/
 if ($prefs['feature_custom_home'] != 'y') {
 	$smarty->assign('msg', tra("This feature has been disabled"));
 
@@ -35,5 +19,3 @@ if ($prefs['feature_custom_home'] != 'y') {
 // Display the template
 $smarty->assign('mid', 'tiki-custom_home.tpl');
 $smarty->display("tiki.tpl");
-
-?>
\ No newline at end of file
