@@ -1,13 +1,13 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-download_forum_attachment.php,v 1.8.2.6 2007/07/09 18:30:56 nkoth Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-download_forum_attachment.php,v 1.13 2007-05-18 16:01:26 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 // Initialization
-$output_zip = 'n';
+$force_no_compression = true;
 require_once ('tiki-setup.php');
 
 include_once ('lib/commentslib.php');
@@ -24,12 +24,10 @@ if (!isset($_REQUEST["attId"])) {
 $commentslib = new Comments($dbTiki);
 $info = $commentslib->get_thread_attachment($_REQUEST["attId"]);
 
-if ($tiki_p_forum_read != 'y' or !$tikilib->user_has_perm_on_object($user,$info["forumId"],'forum','tiki_p_forum_read')) {
-		$smarty->assign('msg',tra("Permission denied you cannot view this page"));
-	    $smarty->display("error.tpl");
-		die;
+if ( empty($info['filetype']) || $info['filetype'] == 'application/x-octetstream' || $info['filetype'] == 'application/octet-stream' ) {
+	include_once('lib/mime/mimelib.php');
+	$info['filetype'] = tiki_get_mime($info['filename'], 'application/octet-stream');
 }
-
 $type = &$info["filetype"];
 $file = &$info["filename"];
 $content = &$info["data"];
@@ -48,5 +46,3 @@ if ($info["dir"]) {
 } else {
 	echo "$content";
 }
-
-?>
