@@ -24,6 +24,10 @@ if ($prefs['feature_userfiles'] != 'y') {
 }
 
 $info = $userfileslib->get_userfile($user, $_REQUEST["fileId"]);
+if ( empty($info['filetype']) || $info['filetype'] == 'application/x-octetstream' || $info['filetype'] == 'application/octet-stream' ) {
+	include_once('lib/mime/mimelib.php');
+	$info['filetype'] = tiki_get_mime($info['filename'], 'application/octet-stream');
+}
 $type = &$info["filetype"];
 $file = &$info["filename"];
 $content = &$info["data"];
@@ -37,5 +41,3 @@ if ($info["path"]) {
 } else {
 	echo "$content";
 }
-
-?>
