@@ -15,7 +15,8 @@ include_once ('lib/articles/artlib.php');
 $smarty->assign('headtitle',tra('Edit article'));
 
 if ($prefs['feature_freetags'] == 'y') {
-	global $freetaglib;include_once('lib/freetag/freetaglib.php');
+	global $freetaglib;
+	include_once('lib/freetag/freetaglib.php');
 }
 
 if ($prefs['feature_articles'] != 'y') {
@@ -37,7 +38,16 @@ if (isset($_REQUEST["articleId"])) {
 	$articleId = 0;
 }
 
+// We need separate numbering of previews, since we access preview images by this number
+if (isset($_REQUEST["previewId"])) {
+	$previewId = $_REQUEST["previewId"];
+} else {
+	$previewId = rand();
+}
+
 $smarty->assign('articleId', $articleId);
+$smarty->assign('previewId', $previewId);
+$smarty->assign('imageIsChanged', (isset($_REQUEST['imageIsChanged']) && $_REQUEST['imageIsChanged']=='y')?'y':'n');
 
 if (isset($_REQUEST["templateId"]) && $_REQUEST["templateId"] > 0) {
 	$template_data = $tikilib->get_template($_REQUEST["templateId"]);
@@ -46,7 +56,7 @@ if (isset($_REQUEST["templateId"]) && $_REQUEST["templateId"] > 0) {
 	$_REQUEST["body"] = $template_data["content"];
 }
 
-$smarty->assign('allowhtml', 'on');
+$smarty->assign('allowhtml', 'y');
 $publishDate = $tikilib->now;
 $cur_time = explode(',', $tikilib->date_format('%Y,%m,%d,%H,%M,%S', $publishDate));
 $expireDate = $tikilib->make_time($cur_time[3], $cur_time[4], $cur_time[5], $cur_time[1], $cur_time[2], $cur_time[0]+1);
@@ -66,8 +76,9 @@ $smarty->assign('hasImage', 'n');
 $smarty->assign('image_name', '');
 $smarty->assign('image_type', '');
 $smarty->assign('image_size', '');
-$smarty->assign('image_x', 0);
-$smarty->assign('image_y', 0);
+$smarty->assign('image_data', '');
+$smarty->assign('image_x', $prefs['article_image_size_x']);
+$smarty->assign('image_y', $prefs['article_image_size_y']);
 $smarty->assign('heading', '');
 $smarty->assign('body', '');
 $smarty->assign('author', '');
@@ -75,6 +86,7 @@ $smarty->assign('type', 'Article');
 $smarty->assign('rating', 7);
 $smarty->assign('edit_data', 'n');
 $smarty->assign('emails', '');
+$smarty->assign('userEmail', $userlib->get_user_email($user));
 
 // If the articleId is passed then get the article data
 // GGG - You have to check for the actual value of the articleId because it
@@ -132,12 +144,6 @@ if (isset($_REQUEST["articleId"]) and $_REQUEST["articleId"] > 0) {
 	$data = $article_data["image_data"];
 	$imgname = $article_data["image_name"];
 
-	if ($hasImage == 'y') {
-		$smarty->assign('tempimg', 'article_image.php?id='.$_REQUEST["articleId"]);
-	} else {
-		$smarty->assign('tempimg', 'n');
-	}
-
 	$body = $article_data["body"];
 	$heading = $article_data["heading"];
 	$smarty->assign('parsed_body', $tikilib->parse_data($body));
@@ -166,7 +172,7 @@ if (empty($_REQUEST['emails']) || $prefs['feature_cms_emails'] != 'y')
 elseif (!empty($_REQUEST['emails'])) {
 	$emails = split(',', $_REQUEST['emails']);
 	foreach ($emails as $email) {
-		if (!validate_email($email, 'y'))
+		if (!validate_email($email, $prefs['validateEmail']))
 			$errors[] = tra('Invalid email:').' '.$email;
 	}
 }
@@ -222,6 +228,7 @@ if (isset($_REQUEST["preview"]) or !empty($errors)) {
 	if (!isset($_REQUEST["lang"])) $_REQUEST['lang'] = '';
 	if (!isset($_REQUEST["type"])) $_REQUEST['type'] = '';
 	if (!isset($_REQUEST['emails'])) $_REQUEST['emails'] = '';
+	if (!isset($_REQUEST['from'])) $_REQUEST['from'] = '';
 
   $smarty->assign('topline', $_REQUEST["topline"]);
   $smarty->assign('subtitle', $_REQUEST["subtitle"]);
@@ -239,15 +246,16 @@ if (isset($_REQUEST["preview"]) or !empty($errors)) {
 	$smarty->assign('rating', $_REQUEST["rating"]);
 	$smarty->assign('entrating', floor($_REQUEST["rating"]));
 	$smarty->assign_by_ref('emails', $_REQUEST['emails']);
+	$smarty->assign_by_ref('from', $_REQUEST['from']);
 	$imgname = $_REQUEST["image_name"];
 	$data = urldecode($_REQUEST["image_data"]);
 
 	// Parse the information of an uploaded file and use it for the preview
 	if (isset($_FILES['userfile1']) && is_uploaded_file($_FILES['userfile1']['tmp_name'])) {
 		$fp = fopen($_FILES['userfile1']['tmp_name'], "rb");
-
 		$data = fread($fp, filesize($_FILES['userfile1']['tmp_name']));
 		fclose ($fp);
+
 		$imgtype = $_FILES['userfile1']['type'];
 		$imgsize = $_FILES['userfile1']['size'];
 		$imgname = $_FILES['userfile1']['name'];
@@ -257,19 +265,16 @@ if (isset($_REQUEST["preview"]) or !empty($errors)) {
 		$smarty->assign('image_size', $imgsize);
 		$hasImage = 'y';
 		$smarty->assign('hasImage', 'y');
+		// Create preview cache image, for display afterwards
+		$cachefile = $prefs['tmpDir'];
+		if ($tikidomain) { $cachefile.= "/$tikidomain"; }
+		$cachefile.= "/article_preview.".$previewId;
+		if (move_uploaded_file($_FILES['userfile1']['tmp_name'], $cachefile)) {
+			$smarty->assign('imageIsChanged', 'y');
+		}
+
 	}
 
-	if ($hasImage == 'y') {
-		$tmpfname = $prefs['tmpDir'] . "/articleimage" . "." . $_REQUEST["articleId"];
-		$fp = fopen($tmpfname, "wb");
-		if ($fp) {
-			fwrite($fp, $data);
-			fclose ($fp);
-			$smarty->assign('tempimg', $tmpfname);
-		} else {
-			$smarty->assign('tempimg', 'n');
-		}
-	}
 
 	$smarty->assign('heading', $_REQUEST["heading"]);
 	$smarty->assign('edit_data', 'y');
@@ -355,17 +360,23 @@ if (isset($_REQUEST['save']) && empty($errors)) {
 	$imgsize = $_REQUEST["image_size"];
 
 	if (isset($_FILES['userfile1']) && is_uploaded_file($_FILES['userfile1']['tmp_name'])) {
-		$fp = fopen($_FILES['userfile1']['tmp_name'], "rb");
-
-		$imgdata = fread($fp, filesize($_FILES['userfile1']['tmp_name']));
+		$file_name = $_FILES['userfile1']['name'];
+		$file_tmp_name = $_FILES['userfile1']['tmp_name'];
+		$tmp_dest = $prefs['tmpDir'] . "/" . $file_name.".tmp";
+		if (!move_uploaded_file($file_tmp_name, $tmp_dest)) {
+			$smarty->assign('msg', tra('Errors detected'));
+			$smarty->display("error.tpl");
+			die();
+	  }
+    $fp = fopen($tmp_dest, "rb");
+		$imgdata = fread($fp, filesize($tmp_dest));
 		fclose ($fp);
+		if(is_file($tmp_dest)) {
+			@unlink($tmp_dest);
+		}
 		$imgtype = $_FILES['userfile1']['type'];
 		$imgsize = $_FILES['userfile1']['size'];
 		$imgname = $_FILES['userfile1']['name'];
-		$topiccachefile = $prefs['tmpDir'];
-		if ($tikidomain) { $topiccachefile.= "/$tikidomain"; }
-		$topiccachefile.= "/article.".$_REQUEST["id"];
-		@unlink($topiccachefile);
 	}
 
 	// Parse $edit and eliminate image references to external URIs (make them internal)
@@ -392,18 +403,47 @@ if (isset($_REQUEST['save']) && empty($errors)) {
 		}
 	}
 
-	$artid = $artlib->replace_article(strip_tags($_REQUEST["title"], '<a><pre><p><img><hr><b><i>'), $_REQUEST["authorName"],
-		$_REQUEST["topicId"], $useImage, $imgname, $imgsize, $imgtype, $imgdata, $heading, $body, $publishDate, $expireDate, $user,
-		$articleId, $_REQUEST["image_x"], $_REQUEST["image_y"], $_REQUEST["type"], $_REQUEST["topline"], $_REQUEST["subtitle"],
-		$_REQUEST["linkto"], $_REQUEST["image_caption"], $_REQUEST["lang"], $_REQUEST["rating"], $isfloat, $emails);
+	$artid = $artlib->replace_article(strip_tags($_REQUEST["title"], '<a><pre><p><img><hr><b><i>')
+																	, $_REQUEST["authorName"]
+																		, $_REQUEST["topicId"]
+																		, $useImage
+																		, $imgname
+																		, $imgsize
+																		, $imgtype
+																		, $imgdata
+																		, $heading
+																		, $body
+																		, $publishDate
+																		, $expireDate
+																		, $user
+																		, $articleId
+																		, $_REQUEST["image_x"]
+																		, $_REQUEST["image_y"]
+																		, $_REQUEST["type"]
+																		, $_REQUEST["topline"]
+																		, $_REQUEST["subtitle"]
+																		, $_REQUEST["linkto"]
+																		, $_REQUEST["image_caption"]
+																		, $_REQUEST["lang"]
+																		, $_REQUEST["rating"]
+																		, $isfloat
+																		, $emails
+																		, $_REQUEST['from']
+																		);
 
 	$cat_type = 'article';
 	$cat_objid = $artid;
 	$cat_desc = substr($_REQUEST["heading"], 0, 200);
 	$cat_name = $_REQUEST["title"];
+	$cat_object_exists = (bool) $artid;
 	$cat_href = "tiki-read_article.php?articleId=" . $cat_objid;
 	include_once("categorize.php");
 	include_once ("freetag_apply.php");
+	// Remove image cache because image may have changed, and we
+	// don't want to show the old image
+	@$artlib->delete_image_cache("article",$_REQUEST["id"]);
+	// Remove preview cache because it won't be used any more
+	@$artlib->delete_image_cache("preview",$previewId);
 
 	header ("location: tiki-read_article.php?articleId=$artid");
 }
@@ -423,6 +463,7 @@ $smarty->assign_by_ref('types', $types);
 if ($prefs['feature_cms_templates'] == 'y' && $tiki_p_use_content_templates == 'y') {
 	$templates = $tikilib->list_templates('cms', 0, -1, 'name_asc', '');
 }
+
 $smarty->assign_by_ref('templates', $templates["data"]);
 
 if ($prefs['feature_multilingual'] == 'y') {
@@ -433,11 +474,12 @@ if ($prefs['feature_multilingual'] == 'y') {
 
 $cat_type = 'article';
 $cat_objid = $articleId;
+$cat_object_exists = (bool) $articleId;
 include_once ("categorize_list.php");
 
 if ($prefs['feature_freetags'] == 'y') {
     include_once ("freetag_list.php");
-    if ($_REQUEST["preview"]) {
+    if (isset($_REQUEST['preview'])) {
 	$smarty->assign('taglist',$_REQUEST["freetag_string"]);
     }
 }
@@ -453,13 +495,9 @@ include_once ('tiki-section_options.php');
 include_once("textareasize.php");
 
 global $wikilib; include_once('lib/wiki/wikilib.php');
-$plugins = $wikilib->list_plugins(true);
+$plugins = $wikilib->list_plugins(true, 'body');
 $smarty->assign_by_ref('plugins', $plugins);
 
-include_once ('lib/quicktags/quicktagslib.php');
-$quicktags = $quicktagslib->list_quicktags(0,100,'taglabel_desc','','articles');
-$smarty->assign_by_ref('quicktags', $quicktags["data"]);
-
 ask_ticket('edit-article');
 
 // disallow robots to index page:
@@ -468,5 +506,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the Index Template
 $smarty->assign('mid', 'tiki-edit_article.tpl');
 $smarty->display("tiki.tpl");
-
-?>
