@@ -13,7 +13,7 @@ require_once ('lib/tikilib.php'); # httpScheme()
 include_once ('lib/banners/bannerlib.php');
 
 if (!isset($bannerlib)) {
-	$bannerlib = new BannerLib($dbTiki);
+	$bannerlib = new BannerLib;
 }
 
 // CHECK FEATURE BANNERS AND ADMIN PERMISSION HERE
@@ -56,6 +56,8 @@ if (isset($_REQUEST["bannerId"]) && $_REQUEST["bannerId"] > 0) {
 	$smarty->assign('bannerId', $info["bannerId"]);
 	$smarty->assign('client', $info["client"]);
 	$smarty->assign('maxImpressions', $info["maxImpressions"]);
+	$smarty->assign('maxUserImpressions', $info["maxUserImpressions"]);
+	$smarty->assign('maxClicks', $info["maxClicks"]);
 	$smarty->assign('fromDate', $info["fromDate"]);
 	$smarty->assign('toDate', $info["toDate"]);
 	$smarty->assign('useDates', $info["useDates"]);
@@ -71,21 +73,20 @@ if (isset($_REQUEST["bannerId"]) && $_REQUEST["bannerId"] > 0) {
 	$smarty->assign("use", $info["which"]);
 	$smarty->assign("zone", $info["zone"]);
 	if ($info["which"] == 'useFlash') {
-		$matches=array();
-		preg_match('/SWFFix\.embedSWF\([\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'")]*)[\'" ]*/', $info["HTMLData"], $matches);
-		$smarty->assign("movieUrl", $matches[1]);
-		$smarty->assign("movieId", $matches[2]);
-		$smarty->assign("movieWidth", $matches[3]);
-		$smarty->assign("movieHeight", $matches[4]);
-		$smarty->assign("movieVersion", $matches[5]);
-		$smarty->assign("movieInstallUrl", $matches[6]);
-		$smarty->assign("movieFlashVars", $matches[7]);
-		$smarty->assign("movieParams", $matches[8]);
-		$smarty->assign("movieAttributes", $matches[9]);
-	
+		if (preg_match('/(swfobject|SWFFix)\.embedSWF\([\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*,[\'" ]*([^,\'"]*)[\'" ]*/m', $info['HTMLData'], $matches)) {
+			$smarty->assign("movieUrl", $matches[2]);
+			$smarty->assign("movieId", $matches[3]);
+			$smarty->assign("movieWidth", $matches[4]);
+			$smarty->assign("movieHeight", $matches[5]);
+			$smarty->assign("movieVersion", $matches[6]);
+		} else if (preg_match('/width="*([0-9]*).*height="*([0-9]*).*"([^"]\.swf"/mi', $info['HTMLData'], $matches)) {
+			$smarty->assign("movieUrl", $matches[3]);
+			$smarty->assign("movieWidth", $matches[1]);
+			$smarty->assign("movieHeight", $matches[2]);
+		}
 	}
 	$smarty->assign("HTMLData", $info["HTMLData"]);
-	$smarty->assign("fixedURLdata", $info["fixedURLData"]);
+	$smarty->assign("fixedURLData", $info["fixedURLData"]);
 	$smarty->assign("textData", $info["textData"]);
 	$smarty->assign("url", $info["url"]);
 	$smarty->assign("imageName", $info["imageName"]);
@@ -110,6 +111,8 @@ if (isset($_REQUEST["bannerId"]) && $_REQUEST["bannerId"] > 0) {
 } else {
 	$smarty->assign('client', '');
 	$smarty->assign('maxImpressions', -1);
+	$smarty->assign('maxUserImpressions', -1);
+	$smarty->assign('maxClicks', -1);
 	$smarty->assign('fromDate', $tikilib->now);
 	$cur_time = explode(',', $tikilib->date_format('%Y,%m,%d,%H,%M,%S', $publishDate));
 	$smarty->assign('toDate', $tikilib->make_time($cur_time[3], $cur_time[4], $cur_time[5], $cur_time[1], $cur_time[2], $cur_time[0]+1));
@@ -160,6 +163,8 @@ if (isset($_REQUEST["save"]) || isset($_REQUEST["create_zone"])) {
 	$smarty->assign('toTime', $_REQUEST["toTimeHour"].':'.$_REQUEST["toTimeMinute"]);
 	$smarty->assign('client', $_REQUEST["client"]);
 	$smarty->assign('maxImpressions', $_REQUEST["maxImpressions"]);
+	$smarty->assign('maxUserImpressions', $_REQUEST["maxUserImpressions"]);
+	$smarty->assign('maxClicks', $_REQUEST["maxClicks"]);
 	$smarty->assign('HTMLData', $_REQUEST["HTMLData"]);
 	$smarty->assign('fixedURLData', $_REQUEST["fixedURLData"]);
 	$smarty->assign('textData', $_REQUEST["textData"]);
@@ -304,12 +309,17 @@ if (isset($_REQUEST["save"]) || isset($_REQUEST["create_zone"])) {
 
 	if (!isset($_REQUEST["create_zone"])) {
 		if ($_REQUEST["use"] == "useFlash") {
-			$_REQUEST["HTMLData"]=$bannerlib->embed_flash($_REQUEST["movieUrl"],$_REQUEST["movieId"],$_REQUEST["movieInstallUrl"],$_REQUEST["movieWidth"],$_REQUEST["movieHeight"],$_REQUEST["movieVersion"],"","","");
+			$params['movie'] = $_REQUEST['movieUrl'];
+			if (!empty($_REQUEST['movieWidth'])) $params['width'] = $_REQUEST['movieWidth'];
+			if (!empty($_REQUEST['movieHeight'])) $params['height'] = $_REQUEST['movieHeight'];
+			if (!empty($_REQUEST['movieVersion'])) $params['version'] = $_REQUEST['movieVersion'];
+			$_REQUEST['HTMLData'] = $tikilib->embed_flash($params, 'y');
+			$_REQUEST['textData'] = $tikilib->embed_flash($params, 'n');
 		}
 		$bannerId = $bannerlib->replace_banner($_REQUEST["bannerId"], $_REQUEST["client"], $_REQUEST["url"], '',
 			'', $_REQUEST["use"], $_REQUEST["imageData"], $_REQUEST["imageType"], $_REQUEST["imageName"], $_REQUEST["HTMLData"],
 			$_REQUEST["fixedURLData"], $_REQUEST["textData"], $fromDate, $toDate, $useDates, $Dmon, $Dtue, $Dwed, $Dthu, $Dfri,
-			$Dsat, $Dsun, $fromTime, $toTime, $_REQUEST["maxImpressions"], $_REQUEST["zone"]);
+			$Dsat, $Dsun, $fromTime, $toTime, $_REQUEST["maxImpressions"],$_REQUEST["maxClicks"], $_REQUEST["zone"], $_REQUEST["maxUserImpressions"]);
 
 		header("location:tiki-list_banners.php");
 		
@@ -318,7 +328,7 @@ if (isset($_REQUEST["save"]) || isset($_REQUEST["create_zone"])) {
 
 $zones = $bannerlib->banner_get_zones();
 $smarty->assign_by_ref('zones', $zones);
-$clients = $userlib->get_users(0, -1, 'login_desc', '');
+$clients = $userlib->get_users(0, -1, 'login_asc', '');
 $smarty->assign_by_ref('clients', $clients["data"]);
 
 ask_ticket('edit-banner');
@@ -329,5 +339,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-edit_banner.tpl');
 $smarty->display("tiki.tpl");
-
-?>
