@@ -9,7 +9,6 @@
 // Initialization
 $section = 'blogs';
 require_once ('tiki-setup.php');
-
 include_once ('lib/blogs/bloglib.php');
 
 $smarty->assign('headtitle',tra('Create Blog'));
@@ -38,28 +37,7 @@ if (isset($_REQUEST["blogId"])) {
 
 $smarty->assign('individual', 'n');
 
-if ($userlib->object_has_one_permission($blogId, 'blog')) {
-	$smarty->assign('individual', 'y');
-
-	if ($tiki_p_admin != 'y') {
-		// Now get all the permissions that are set for this type of permissions 'image gallery'
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'blogs');
-
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-
-			if ($userlib->object_has_permission($user, $_REQUEST["blogId"], 'blog', $permName)) {
-				$$permName = 'y';
-
-				$smarty->assign("$permName", 'y');
-			} else {
-				$$permName = 'n';
-
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-}
+$tikilib->get_perm_object($blogId, 'blog');
 
 $smarty->assign('blogId', $blogId);
 $smarty->assign('title', '');
@@ -176,7 +154,6 @@ if (isset($_REQUEST['preview']) || $category_needed) {
 }
 
 
-$sections = 'blogs';
 $cat_type = 'blog';
 $cat_objid = $blogId;
 include_once ("categorize_list.php");
@@ -194,5 +171,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the Index Template
 $smarty->assign('mid', 'tiki-edit_blog.tpl');
 $smarty->display("tiki.tpl");
-
-?>
