@@ -73,29 +73,43 @@ if (!isset($_REQUEST["try"]))
 $editstyle = preg_replace("/[^-_a-z\d]/i","",$_REQUEST["editstyle"]);
 $styledir = "styles";
 
-if (isset($_REQUEST["edit"])and $_REQUEST["edit"]) {
-	$action = 'edit';
-
-	//	$data = implode("",file("$styledir/$editstyle.css"));
+function get_style_path($editstyle, $styledir) {
+    global $tikidomain;
 	if ($tikidomain and is_file("$styledir/$tikidomain/$editstyle.css")) {
-		$data = load_css2_file("$styledir/$tikidomain/$editstyle.css", $styledir);
+		return "$styledir/$tikidomain/$editstyle.css";
 	} else {
-		$data = load_css2_file("$styledir/$editstyle.css", $styledir);
-	}
-} elseif (isset($_REQUEST["save"])and $_REQUEST["save"]) {
+		return "$styledir/$editstyle.css";
+	}    
+}
+
+function get_style_mod($editstyle, $styledir) {
+	$style=get_style_path($editstyle, $styledir);
+	$stat=stat($style);
+	return $stat['mode'] & 0666;
+}
+
+if (isset($_REQUEST["edit"])and $_REQUEST["edit"]) {
+
+	$action = 'edit';
+	$data = load_css2_file(get_style_path($editstyle, $styledir), $styledir);
+
+} elseif ((isset($_REQUEST["save"]) and $_REQUEST["save"]) or (isset($_REQUEST["save2"]) and $_REQUEST["save2"])) {
 	check_ticket('edit-css');
-	$action = 'display';
+	$action = 'edit';
 
 	$data = '';
 	if ($tikidomain and is_dir("$styledir/$tikidomain")) {
-		$fp = fopen("$styledir/$tikidomain/$editstyle.css", "w");
+		$style = "$styledir/$tikidomain/$editstyle.css";
 	} else {
-		$fp = fopen("$styledir/$editstyle.css", "w");
+		$style = "$styledir/$editstyle.css";
 	}
 
+	$mod=NULL;
+	$mod = get_style_mod($editstyle, $styledir);
+	$fp = fopen($style, "w");
 	if (!$fp) {
 		$smarty->assign('errortype', 401);
-		$smarty->assign('msg', tra("You do not have permission to write the style sheet"));
+		$smarty->assign('msg', tra("You do not have permission to write the style sheet")." $style");
 
 		$smarty->display("error.tpl");
 		die;
@@ -103,6 +117,16 @@ if (isset($_REQUEST["edit"])and $_REQUEST["edit"]) {
 
 	fwrite($fp, $_REQUEST["data"]);
 	fclose ($fp);
+	if ($mod !== NULL) {
+		chmod($style, $mod);
+	}
+
+	if ($_REQUEST["save2"]) {
+		$action = 'display';
+		header("location: tiki-edit_css.php?editstyle=$editstyle");
+	} else {
+		header("location: tiki-edit_css.php?editstyle=$editstyle&edit=".tra('Edit')."");
+	}
 } else {
 	$action = 'display';
 
@@ -145,5 +169,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 
 $smarty->assign('mid', 'tiki-edit_css.tpl');
 $smarty->display("tiki.tpl");
-
-?>
