@@ -6,9 +6,7 @@
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-// Initialization
 require_once ('tiki-setup.php');
-
 include_once ('lib/quizzes/quizlib.php');
 
 if ($prefs['feature_quizzes'] != 'y') {
@@ -22,32 +20,11 @@ if (!isset($_REQUEST["quizId"])) {
 	$_REQUEST["quizId"] = 0;
 }
 
-
 $smarty->assign('quizId', $_REQUEST["quizId"]);
 
 $smarty->assign('individual', 'n');
 
-if ($userlib->object_has_one_permission($_REQUEST["quizId"], 'quiz')) {
-	$smarty->assign('individual', 'y');
-
-	if ($tiki_p_admin != 'y') {
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'quizzes');
-
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-
-			if ($userlib->object_has_permission($user, $_REQUEST["quizId"], 'quiz', $permName)) {
-				$$permName = 'y';
-
-				$smarty->assign("$permName", 'y');
-			} else {
-				$$permName = 'n';
-
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-}
+$tikilib->get_perm_object($_REQUEST["quizId"], 'quiz');
 
 if ($tiki_p_admin_quizzes != 'y') {
 	$smarty->assign('errortype', 401);
@@ -57,6 +34,13 @@ if ($tiki_p_admin_quizzes != 'y') {
 	die;
 }
 
+$auto_query_args = array(
+			'quizId',
+			'offset',
+			'sort_mode',
+			'find',
+);
+
 $_REQUEST["questionsPerPage"] = 999;
 
 $info = array();
@@ -79,21 +63,10 @@ $info["timeLimit"] = 60 * 60;
 if (isset($_REQUEST["save"])) {
 	check_ticket('edit-quiz');
 
-// 	print $_REQUEST["publish_Hour"]."<br>";
-// 	print $_REQUEST["publish_Minute"]."<br>";
-// 	print $_REQUEST["publish_Month"]."<br>";
-// 	print $_REQUEST["publish_Day"]."<br>";
-// 	print $_REQUEST["publish_Year"]."<br>";
-
-
  	# convert from the displayed 'site' time to 'server' time
  	$publishDate = $tikilib->make_time($_REQUEST["publish_Hour"], $_REQUEST["publish_Minute"], 0, $_REQUEST["publish_Month"], $_REQUEST["publish_Day"], $_REQUEST["publish_Year"]);
  	$expireDate = $tikilib->make_time($_REQUEST["expire_Hour"], $_REQUEST["expire_Minute"], 0, $_REQUEST["expire_Month"], $_REQUEST["expire_Day"], $_REQUEST["expire_Year"]);
 
-//  	print $publishDate."<br>";
-//  	print $expireDate."<br>";
-//  	die;
-
 	if (isset($_REQUEST["canRepeat"]) && $_REQUEST["canRepeat"] == 'on') {
 		$_REQUEST["canRepeat"] = 'y';
 	} else {
@@ -136,7 +109,6 @@ if (isset($_REQUEST["save"])) {
 		$_REQUEST["timeLimited"] = 'n';
 	}
 
-	// GGG Have to change $quizlib->replace_quiz to take publish and expire dates.
 	$qid = $quizlib->replace_quiz($_REQUEST["quizId"], $_REQUEST["name"],
 																$_REQUEST["description"],	$_REQUEST["canRepeat"],
 																$_REQUEST["storeResults"], $_REQUEST["immediateFeedback"],
@@ -155,7 +127,6 @@ if (isset($_REQUEST["save"])) {
 	$quizId = 0;
 
 } elseif ($_REQUEST["quizId"]) {
-	// GGG Have to change $quizlib->get_quiz to handle publish and expire dates.  Maybe it does automagically!
 	$info = $quizlib->get_quiz($_REQUEST["quizId"]);
 
 	if (!isset($info["publishDate"])){
@@ -251,32 +222,12 @@ for ($i = 0; $i < $temp_max; $i++) {
 	}
 }
 
-$cant_pages = ceil($channels["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
-if ($channels["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
-}
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
-}
+$smarty->assign_by_ref('cant_pages', $channels["cant"]);
 
 $smarty->assign_by_ref('channels', $channels["data"]);
 
 // Fill array with possible number of questions per page
-$qpp = array(
-	1,
-	2,
-	3,
-	4
-);
+$qpp = array( 1, 2, 3, 4 );
 
 for ($i = 5; $i < 50; $i += 5)
 	$qpp[] = $i;
@@ -311,5 +262,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-edit_quiz.tpl');
 $smarty->display("tiki.tpl");
-
-?>
