@@ -8,9 +8,10 @@
 
 // Initialization
 require_once('tiki-setup.php');
-
 include_once('lib/quizzes/quizlib.php');
 
+$auto_query_args = array('quizId', 'questionId', 'sort_mode', 'offset', 'find');
+
 if ($prefs['feature_quizzes'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_quizzes");
 
@@ -18,14 +19,6 @@ if ($prefs['feature_quizzes'] != 'y') {
 	die;
 }
 
-if ($tiki_p_admin_quizzes != 'y') {
-	$smarty->assign('errortype', 401);
-	$smarty->assign('msg', tra("You don't have permission to use this feature"));
-
-	$smarty->display("error.tpl");
-	die;
-}
-
 if (!isset($_REQUEST["quizId"])) {
 	$smarty->assign('msg', tra("No quiz indicated"));
 
@@ -33,32 +26,20 @@ if (!isset($_REQUEST["quizId"])) {
 	die;
 }
 
+$tikilib->get_perm_object($_REQUEST["quizId"], 'quiz');
+
+if ($tiki_p_admin_quizzes != 'y') {
+	$smarty->assign('errortype', 401);
+	$smarty->assign('msg', tra("You don't have permission to use this feature"));
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 $smarty->assign('quizId', $_REQUEST["quizId"]);
 
 $smarty->assign('individual', 'n');
 
-if ($userlib->object_has_one_permission($_REQUEST["quizId"], 'quiz')) {
-	$smarty->assign('individual', 'y');
-
-	if ($tiki_p_admin != 'y') {
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'quizzes');
-
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-
-			if ($userlib->object_has_permission($user, $_REQUEST["quizId"], 'quiz', $permName)) {
-				$$permName = 'y';
-
-				$smarty->assign("$permName", 'y');
-			} else {
-				$$permName = 'n';
-
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-}
-
 $quiz_info = $quizlib->get_quiz($_REQUEST["quizId"]);
 $smarty->assign('quiz_info', $quiz_info);
 
@@ -162,22 +143,7 @@ $channels = $quizlib->list_quiz_questions($_REQUEST["quizId"], $offset, $maxReco
 // $questions = $quizlib->list_all_questions(0, -1, 'position_desc', '');
 // $smarty->assign('questions', $questions["data"]);
 
-$cant_pages = ceil($channels["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
-if ($channels["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
-}
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
-}
+$smarty->assign_by_ref('cant_pages', $channels["cant"]);
 
 $smarty->assign_by_ref('channels', $channels["data"]);
 
@@ -203,5 +169,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-edit_quiz_questions.tpl');
 $smarty->display("tiki.tpl");
-
-?>
