@@ -13,6 +13,21 @@ require_once ('tiki-setup.php');
 
 include_once ('lib/structures/structlib.php');
 
+if($prefs['feature_wiki'] != 'y') {
+    $smarty->assign('msg', tra('This feature is disabled').': feature_wiki');
+    $smarty->display('error.tpl');
+    die;  
+}
+if($prefs['feature_wiki_structure'] != 'y') {
+    $smarty->assign('msg', tra('This feature is disabled').': feature_wiki_structure');
+    $smarty->display('error.tpl');
+    die;  
+}
+if (!isset($_REQUEST["page_ref_id"])) {
+	$smarty->assign('msg', tra("No structure indicated"));
+	$smarty->display("error.tpl");
+	die;
+}
 if ($tiki_p_view != 'y') {
 // This allows tiki_p_view in, in order to see structure tree - security hardening for editing features below.
 	$smarty->assign('errortype', 401);
@@ -22,12 +37,6 @@ if ($tiki_p_view != 'y') {
 	die;
 }
 
-if (!isset($_REQUEST["page_ref_id"])) {
-	$smarty->assign('msg', tra("No structure indicated"));
-	$smarty->display("error.tpl");
-	die;
-}
-
 if (isset($_REQUEST['move_to'])) {
 	check_ticket('edit-structure');
 	$structlib->move_to_structure($_REQUEST['page_ref_id'], $_REQUEST['structure_id'], $_REQUEST['begin']);
@@ -40,18 +49,19 @@ $smarty->assign('page_ref_id', $_REQUEST["page_ref_id"]);
 $smarty->assign('structure_id', $structure_info["page_ref_id"]);
 $smarty->assign('structure_name', $structure_info["pageName"]);
 
-if ($tiki_p_edit_structures  == 'y' && $tikilib->user_has_perm_on_object($user,$structure_info["pageName"],'wiki page','tiki_p_edit','tiki_p_edit_categorized'))
+if (!$tikilib->user_has_perm_on_object($user,$structure_info["pageName"],'wiki page','tiki_p_view')) {
+	$smarty->assign('errortype', 401);
+	$smarty->assign('msg',tra('Permission denied. You cannot view this page.'));
+	$smarty->display("error.tpl");
+	die;
+}
+
+if ($tiki_p_edit_structures  == 'y')
 	$editable = 'y';
 else
 	$editable = 'n';
 $smarty->assign('editable', $editable);
 	
-if (!$tikilib->user_has_perm_on_object($user,$structure_info["pageName"],'wiki page','tiki_p_view')) {
-	$smarty->assign('errortype', 401);
-	$smarty->assign('msg',tra('Permission denied you cannot view this page'));
-	$smarty->display("error.tpl");
-	die;
-}
 
 $alert_categorized = array();
 $alert_in_st = array();
@@ -69,10 +79,11 @@ if (isset($_REQUEST["remove"])) {
   $remove_info = $structlib->s_get_page_info($_REQUEST["remove"]);
   	$structs = $structlib->get_page_structures($remove_info['pageName'],$structure);
     //If page is member of more than one structure, do not give option to remove page
-    $single_struct = count($structs) == 1; 
-	if ($tiki_p_remove == 'y' && $single_struct && $tikilib->user_has_perm_on_object($user,$remove_info["pageName"],'wiki page','tiki_p_edit','tiki_p_edit_categorized'))
+    $single_struct = (count($structs) == 1);
+	$perms = $tikilib->get_perm_object($remove_info['pageName'],'wiki page', $tikilib->get_page_info($remove_info['pageName']) , false);
+	if ($single_struct && $perms['tiki_p_remove'] == 'y') {
 		$smarty->assign('page_removable', 'y');
-	else
+	} else
 		$smarty->assign('page_removable', 'n');
 	$smarty->assign('removepage', $_REQUEST["remove"]);
 	$smarty->assign('removePageName', $remove_info["pageName"]);
@@ -94,8 +105,8 @@ if (isset($_REQUEST["sremove"])) {
   if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
     key_check($area);
 		$page = $page_info["pageName"];
-		require ('tiki-pagesetup.php');
-		$structlib->s_remove_page($_REQUEST["sremove"], $tiki_p_remove == 'y', empty($_REQUEST['page'])? '': $_REQUEST['page']);
+		$delete = $tikilib->user_has_perm_on_object($user, $page_info['pageName'],'wiki page','tiki_p_remove');
+		$structlib->s_remove_page($_REQUEST["sremove"], $delete, empty($_REQUEST['page'])? '': $_REQUEST['page']);
   	$_REQUEST["page_ref_id"] = $page_info["parent_id"];
   } else {
     key_get($area);
@@ -107,7 +118,7 @@ if (isset($_REQUEST["sremove"])) {
 	if ($_REQUEST['watch_action'] == 'add' && !empty($_REQUEST['page'])) {
 		$tikilib->add_user_watch($user, 'structure_changed', $_REQUEST['watch_object'],'structure',$page,"tiki-index.php?page_ref_id=".$_REQUEST['watch_object']);
 	} elseif ($_REQUEST['watch_action'] == 'remove') {
-		$tikilib->remove_user_watch($user, 'structure_changed', $_REQUEST['watch_object']);
+		$tikilib->remove_user_watch($user, 'structure_changed', $_REQUEST['watch_object'], 'structure');
 	}
 }
 
@@ -133,12 +144,12 @@ if (isset($_REQUEST["create"])) {
 		if ($tikilib->page_exists($_REQUEST["name"])) {
 			$smarty->assign('alert_exists', 'y');
 		}
-		$structlib->s_create_page($_REQUEST["page_ref_id"], $after, $_REQUEST["name"], '');
+		$structlib->s_create_page($_REQUEST['page_ref_id'], $after, $_REQUEST['name'], '', $structure_info['page_ref_id']);
 		$userlib->copy_object_permissions($page_info["pageName"], $_REQUEST["name"],'wiki page');
 	} 
 	elseif(!empty($_REQUEST['name2'])) {
 		foreach ($_REQUEST['name2'] as $name) {
-			$new_page_ref_id = $structlib->s_create_page($_REQUEST["page_ref_id"], $after, $name, '');
+			$new_page_ref_id = $structlib->s_create_page($_REQUEST['page_ref_id'], $after, $name, '', $structure_info['page_ref_id']);
       $after = $new_page_ref_id;      
 		}	
 	}
@@ -236,7 +247,7 @@ if (!empty($_REQUEST['categId'])) {
 }
 	
 // Get all wiki pages for the dropdown menu
-$listpages = $tikilib->list_pages(0, 50, 'pageName_asc', $find_objects, '', true, true, false, false, $filter);
+$listpages = $tikilib->list_pages(0, -1, 'pageName_asc', $find_objects, '', true, true, false, false, $filter);
 $smarty->assign_by_ref('listpages', $listpages["data"]);
 
 $structures = $structlib->list_structures(0, -1, 'pageName_asc');
@@ -346,7 +357,7 @@ if ($prefs['feature_wiki_categorize_structure'] == 'y' && $all_editable == 'y')
 	include_once("categorize_list.php");
 } elseif ($prefs['feature_categories'] == 'y') {
 	global $categlib; include_once('lib/categories/categlib.php');
-	$categories = $categlib->get_all_categories_respect_perms($user, 'tiki_p_view_categories');
+	$categories = $categlib->get_all_categories_respect_perms($user, 'view_category');
 	$smarty->assign_by_ref('categories', $categories);
 }
 
@@ -360,5 +371,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 // Display the template
 $smarty->assign('mid', 'tiki-edit_structure.tpl');
 $smarty->display("tiki.tpl");
-
-?>
