@@ -21,8 +21,9 @@ if ($tiki_p_admin_wiki != 'y' && $tiki_p_export_wiki != 'y') {
 
 if (!isset($_REQUEST["page"])) {
 	$exportlib->MakeWikiZip();
-
-	header ("location: dump/export.tar");
+	$dump = 'dump';
+	if (!empty($tikidomain)) $dump .= "/$tikidomain";
+	header ("location: $dump/export.tar");
 } else {
 	if (isset($_REQUEST["all"]))
 		$all = 0;
@@ -35,5 +36,3 @@ if (!isset($_REQUEST["page"])) {
 	header ("Content-Disposition: inline; filename=$page");
 	echo $data;
 }
-
-?>
