@@ -23,7 +23,7 @@ if ($prefs['feature_forums'] != 'y') {
 
 if ($tiki_p_forum_read != 'y') {
 	$smarty->assign('errortype', 401);
-	$smarty->assign('msg', tra("Permission denied you cannot view this section"));
+	$smarty->assign('msg', tra("Permission denied. You cannot view this section"));
 
 	$smarty->display("error.tpl");
 	die;
@@ -57,45 +57,16 @@ $smarty->assign('find', $find);
 
 $smarty->assign_by_ref('sort_mode', $sort_mode);
 $channels = $commentslib->list_forums($offset, $maxRecords, $sort_mode, $find);
+Perms::bulk( array( 'type' => 'forum' ), 'object', $channels['data'], 'forumId' );
 
 $temp_max = count($channels["data"]);
 for ($i = 0; $i < $temp_max; $i++) {
-	if ($userlib->object_has_one_permission($channels["data"][$i]["forumId"], 'forum')) {
-		$channels["data"][$i]["individual"] = 'y';
-
-		// forums that user cannot read are not displayed at all
-		$channels["data"][$i]["individual_tiki_p_forum_read"] = 'y';
-
-		if ($userlib->object_has_permission($user, $channels["data"][$i]["forumId"], 'forum', 'tiki_p_forum_post')) {
-			$channels["data"][$i]["individual_tiki_p_forum_post"] = 'y';
-		} else {
-			$channels["data"][$i]["individual_tiki_p_forum_post"] = 'n';
-		}
-
-		if ($userlib->object_has_permission($user, $channels["data"][$i]["forumId"], 'forum', 'tiki_p_forum_vote')) {
-			$channels["data"][$i]["individual_tiki_p_forum_vote"] = 'y';
-		} else {
-			$channels["data"][$i]["individual_tiki_p_forum_vote"] = 'n';
-		}
-
-		if ($userlib->object_has_permission($user, $channels["data"][$i]["forumId"], 'forum', 'tiki_p_forum_post_topic')) {
-			$channels["data"][$i]["individual_tiki_p_forum_post_topic"] = 'y';
-		} else {
-			$channels["data"][$i]["individual_tiki_p_forum_post_topic"] = 'n';
-		}
-
-		if ($tiki_p_admin
-			== 'y' || $userlib->object_has_permission($user, $channels["data"][$i]["forumId"], 'forum', 'tiki_p_admin_forum')) {
-			$channels["data"][$i]["individual_tiki_p_forum_post_topic"] = 'y';
-
-			$channels["data"][$i]["individual_tiki_p_forum_vote"] = 'y';
-			$channels["data"][$i]["individual_tiki_p_admin_forum"] = 'y';
-			$channels["data"][$i]["individual_tiki_p_forum_post"] = 'y';
-			$channels["data"][$i]["individual_tiki_p_forum_read"] = 'y';
-		}
-	} else {
-		$channels["data"][$i]["individual"] = 'n';
-	}
+	$forumperms = Perms::get( array( 'type' => 'forum', 'object' => $channels['data'][$i]['forumId'] ) );
+	$channels["data"][$i]["individual_tiki_p_forum_read"] = $forumperms->forum_read ? 'y' : 'n';
+	$channels["data"][$i]["individual_tiki_p_forum_post"] = $forumperms->forum_post ? 'y' : 'n';
+	$channels["data"][$i]["individual_tiki_p_forum_post_topic"] = $forumperms->forum_post_topic ? 'y' : 'n';
+	$channels["data"][$i]["individual_tiki_p_forum_vote"] = $forumperms->forum_vote ? 'y' : 'n';
+	$channels["data"][$i]["individual_tiki_p_admin_forum"] = $forumperms->admin_forum ? 'y' : 'n';
 }
 
 $smarty->assign_by_ref('channels', $channels["data"]);
@@ -113,5 +84,3 @@ ask_ticket('forums');
 // Display the template
 $smarty->assign('mid', 'tiki-forums.tpl');
 $smarty->display("tiki.tpl");
-
-?>
