@@ -9,15 +9,25 @@ require_once ('tiki-setup.php');
 require_once ('lib/tikilib.php');
 require_once ('lib/rss/rsslib.php');
 
+if ($prefs['feature_forums'] != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_forums");
+	$smarty->display("error.tpl");
+	die;
+}
+
 if ($prefs['rss_forums'] != 'y') {
         $errmsg=tra("rss feed disabled");
         require_once ('tiki-rss_error.php');
 }
 
-if($tiki_p_admin_forum != 'y' && $tiki_p_forum_read != 'y') {
-	$smarty->assign('errortype', 401);
-	$errmsg=tra("Permission denied you cannot view this section");
-	require_once ('tiki-rss_error.php');
+$res=$access->authorize_rss(array('tiki_p_admin_forum','tiki_p_forum_read'));
+if($res) {
+   if($res['header'] == 'y') {
+      header('WWW-Authenticate: Basic realm="'.$tikidomain.'"');
+      header('HTTP/1.0 401 Unauthorized');
+   }
+   $errmsg=$res['msg'];
+   require_once ('tiki-rss_error.php');
 }
 
 $feed = "forums";
@@ -27,13 +37,13 @@ $output = $rsslib->get_from_cache($uniqueid);
 if ($output["data"]=="EMPTY") {
 	$title = (!empty($title_rss_forums)) ? $title_rss_forums :  tra("Tiki RSS feed for forums");
 	$desc = (!empty($desc_rss_forums)) ? $desc_rss_forums : tra("Last topics in forums.");
-	$id = "forumId";
+	$id = 'object';
 	$param = "threadId";
 	$descId = "data";
 	$dateId = "commentDate";
 	$authorId = "userName";
 	$titleId = "title";
-	$readrepl = "tiki-view_forum_thread.php?$id=%s&comments_parentId=%s";
+	$readrepl = 'tiki-view_forum_thread.php?forumId=%s&comments_parentId=%s';
 
         $tmp = $prefs['title_rss_'.$feed];
         if ($tmp<>'') $title = $tmp;
@@ -45,5 +55,3 @@ if ($output["data"]=="EMPTY") {
 }
 header("Content-type: ".$output["content-type"]);
 print $output["data"];
-
-?>
