@@ -10,8 +10,8 @@
 $section = 'galleries';
 require_once ('tiki-setup.php');
 
-include_once ("lib/imagegals/imagegallib.php");
-include_once ('lib/categories/categlib.php');
+global $imagegallib; include_once ("lib/imagegals/imagegallib.php");
+global $categlib; include_once ('lib/categories/categlib.php');
 include_once ('lib/map/usermap.php');
 
 if ($prefs['feature_galleries'] != 'y') {
@@ -49,28 +49,7 @@ if ($tiki_p_list_image_galleries != 'y') {
 // Check here for indivdual permissions the objectType is 'image galleries' and the id is galleryId
 $smarty->assign('individual', 'n');
 
-if ($userlib->object_has_one_permission($_REQUEST["galleryId"], 'image gallery')) {
-	$smarty->assign('individual', 'y');
-
-	if ($tiki_p_admin != 'y') {
-		// Now get all the permissions that are set for this type of permissions 'image gallery'
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'image galleries');
-
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-
-			if ($userlib->object_has_permission($user, $_REQUEST["galleryId"], 'image gallery', $permName)) {
-				$$permName = 'y';
-
-				$smarty->assign("$permName", 'y');
-			} else {
-				$$permName = 'n';
-
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-}
+$tikilib->get_perm_object($_REQUEST["galleryId"], 'image gallery');
 
 $foo = parse_url($_SERVER["REQUEST_URI"]);
 $foo["path"] = str_replace("tiki-galleries", "tiki-browse_gallery", $foo["path"]);
@@ -124,11 +103,12 @@ $smarty->assign('sortorder','created');
 $smarty->assign('sortdirection','desc');
 $smarty->assign('showname','y');
 $smarty->assign('showimageid','n');
+$smarty->assign('showcategories','n');
 $smarty->assign('showdescription','n');
 $smarty->assign('showcreated','n');
 $smarty->assign('showuser','n');
 $smarty->assign('showhits','y');
-$smarty->assign('showxysize','y');
+$smarty->assign('showxysize','n');
 $smarty->assign('showfilesize','n');
 $smarty->assign('showfilename','n');
 $options_galleryimage=array(tra('first uploaded image') => 'firstu',
@@ -155,7 +135,6 @@ if (isset($_REQUEST["edit_mode"]) && $_REQUEST["edit_mode"]) {
 
 	if ($_REQUEST["galleryId"] > 0) {
 		if ($info = $imagegallib->get_gallery_info($_REQUEST["galleryId"])) {
-
 		$scaleinfo = $imagegallib->get_gallery_scale_info($_REQUEST["galleryId"]);
 		$gallery_images = $imagegallib->get_images(0,-1,'name_asc',false,$_REQUEST['galleryId']);
 		foreach($gallery_images['data'] as $key => $item) {
@@ -177,6 +156,7 @@ if (isset($_REQUEST["edit_mode"]) && $_REQUEST["edit_mode"]) {
 		$smarty->assign('parentgallery',$info['parentgallery']);
 		$smarty->assign('showname',$info['showname']);
 		$smarty->assign('showimageid',$info['showimageid']);
+		$smarty->assign('showcategories',$info['showcategories']);;
 		$smarty->assign('showdescription',$info['showdescription']);
 		$smarty->assign('showcreated',$info['showcreated']);
 		$smarty->assign('showuser',$info['showuser']);
@@ -238,7 +218,7 @@ if (isset($_REQUEST["edit"]) && $prefs['feature_categories'] == 'y' && $prefs['f
 	$smarty->assign('galleryimage',$_REQUEST['galleryimage']);
 	$smarty->assign('parentgallery',$_REQUEST['parentgallery']);
 	$smarty->assign('defaultscale',$_REQUEST['defaultscale']);
-	$auxarray=array('showname','showimageid','showdescription','showcreated','showuser','showhits','showxysize','showfilesize','showfilename');
+	$auxarray=array('showname','showimageid','showdescription','showcreated','showuser','showhits','showxysize','showfilesize','showfilename','showcategories');
 	foreach($auxarray as $key => $item) {
 		if(!isset($_REQUEST[$item])) {
 			$_REQUEST[$item]='n';
@@ -268,8 +248,7 @@ if (isset($_REQUEST["edit"]) && $prefs['feature_categories'] == 'y' && $prefs['f
 		'', $_REQUEST["owner"], $_REQUEST["maxRows"], $_REQUEST["rowImages"], $_REQUEST["thumbSizeX"], $_REQUEST["thumbSizeY"], $public,
 		$visible,$_REQUEST['sortorder'],$_REQUEST['sortdirection'],$_REQUEST['galleryimage'],$_REQUEST['parentgallery'],
 		$_REQUEST['showname'],$_REQUEST['showimageid'],$_REQUEST['showdescription'],$_REQUEST['showcreated'],
-		$_REQUEST['showuser'],$_REQUEST['showhits'],$_REQUEST['showxysize'],$_REQUEST['showfilesize'],$_REQUEST['showfilename'],$_REQUEST['defaultscale'],$geographic);
-
+		$_REQUEST['showuser'],$_REQUEST['showhits'],$_REQUEST['showxysize'],$_REQUEST['showfilesize'],$_REQUEST['showfilename'],$_REQUEST['defaultscale'],$geographic,$_REQUEST['showcategories']);
 	#add scales
 	if (isset($_REQUEST["scaleSize"])) {
 		if (strstr($_REQUEST["scaleSize"],',')) {
@@ -322,7 +301,7 @@ if ($category_needed == 'y') {
 	$smarty->assign('galleryimage',$_REQUEST['galleryimage']);
 	$smarty->assign('parentgallery',$_REQUEST['parentgallery']);
 	$smarty->assign('defaultscale',$_REQUEST['defaultscale']);
-	$auxarray=array('showname','showimageid','showdescription','showcreated','showuser','showhits','showxysize','showfilesize','showfilename');
+	$auxarray=array('showname','showimageid','showdescription','showcreated','showuser','showhits','showxysize','showfilesize','showfilename','showcategories');
 	foreach($auxarray as $key => $item) {
 		if(!isset($_REQUEST[$item])) {
 			$_REQUEST[$item]='n';
@@ -405,9 +384,6 @@ if (!isset($_REQUEST["sort_mode"])) {
 
 $smarty->assign_by_ref('sort_mode', $sort_mode);
 
-// If offset is set use it if not then use offset =0
-// use the maxRecords php variable to set the limit
-// if sortMode is not set then use lastModif_desc
 if (!isset($_REQUEST["offset"])) {
 	$offset = 0;
 } else {
@@ -423,6 +399,7 @@ if (!is_object($imagegallib)) {
 }
 
 $galleries = $imagegallib->list_galleries($offset, $maxRecords, $sort_mode, 'admin', $find);
+Perms::bulk( array( 'type' => 'image gallery' ), 'object', $galleries, 'galleryId' );
 
 $smarty->assign('filter', '');
 if (!empty($_REQUEST['filter']))
@@ -431,10 +408,10 @@ if (!empty($_REQUEST['filter']))
 
 $temp_max = count($galleries["data"]);
 for ($i = 0; $i < $temp_max; $i++) {
+	$galperms = Perms::get( array( 'type' => 'image gallery', 'object' => $galleries["data"][$i]["galleryId"] ) );
 
 	// check if top gallery (has no parents)
 	$info = $imagegallib->get_gallery_info($galleries["data"][$i]["galleryId"]);
-	/*$subgals = $imagegallib->get_subgalleries($top_offset = 1, $maxImages, $sort_mode, '', $galleries["data"][$i]["galleryId"]);*/
 	if ($info['parentgallery'] == -1) {
 		$galleries["data"][$i]["topgal"] = 'y';
 	} else {
@@ -450,53 +427,9 @@ for ($i = 0; $i < $temp_max; $i++) {
 		$galleries["data"][$i]["parentgal"] = 'n';
 	}
 
-
-	if ($userlib->object_has_one_permission($galleries["data"][$i]["galleryId"], 'image gallery')) {
-		$galleries["data"][$i]["individual"] = 'y';
-
-		$galleries["data"][$i]["individual_tiki_p_view_image_gallery"] = 'y';
-
-		if ($userlib->object_has_permission($user, $galleries["data"][$i]["galleryId"], 'image gallery', 'tiki_p_upload_images')) {
-			$galleries["data"][$i]["individual_tiki_p_upload_images"] = 'y';
-		} else {
-			$galleries["data"][$i]["individual_tiki_p_upload_images"] = 'n';
-		}
-
-		if ($userlib->object_has_permission($user, $galleries["data"][$i]["galleryId"], 'image gallery', 'tiki_p_create_galleries'))
-			{
-			$galleries["data"][$i]["individual_tiki_p_create_galleries"] = 'y';
-		} else {
-			$galleries["data"][$i]["individual_tiki_p_create_galleries"] = 'n';
-		}
-
-		if ($tiki_p_admin == 'y' || $userlib->object_has_permission($user, $galleries["data"][$i]["galleryId"], 'image gallery',
-			'tiki_p_admin_galleries')) {
-			$galleries["data"][$i]["individual_tiki_p_create_galleries"] = 'y';
-
-			$galleries["data"][$i]["individual_tiki_p_upload_images"] = 'y';
-			$galleries["data"][$i]["individual_tiki_p_view_image_gallery"] = 'y';
-		}
-	} else {
-		$galleries["data"][$i]["individual"] = 'n';
-	}
-}
-
-// If there're more records then assign next_offset
-$cant_pages = ceil($galleries["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
-if ($galleries["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
-}
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
+	$galleries["data"][$i]["individual_tiki_p_view_image_gallery"] = $galperms->view_image_gallery ? 'y' : 'n';
+	$galleries["data"][$i]["individual_tiki_p_upload_images"] = $galperms->upload_images ? 'y' : 'n';
+	$galleries["data"][$i]["individual_tiki_p_create_galleries"] = $galperms->create_galleries ? 'y' : 'n';
 }
 
 $smarty->assign_by_ref('galleries', $galleries["data"]);
@@ -516,5 +449,3 @@ ask_ticket('galleries');
 // Display the template
 $smarty->assign('mid', 'tiki-galleries.tpl');
 $smarty->display("tiki.tpl");
-
-?>
