@@ -28,7 +28,7 @@ if ($prefs['feature_gal_rankings'] != 'y') {
 
 if ($tiki_p_list_image_galleries != 'y') {
 	$smarty->assign('errortype', 401);
-	$smarty->assign('msg', tra("Permission denied you cannot view this section"));
+	$smarty->assign('msg', tra("Permission denied. You cannot view this section"));
 
 	$smarty->display("error.tpl");
 	die;
@@ -90,5 +90,3 @@ ask_ticket('galleries-rankings');
 // Display the template
 $smarty->assign('mid', 'tiki-ranking.tpl');
 $smarty->display("tiki.tpl");
-
-?>
