@@ -63,7 +63,7 @@ function convert_formula( $formula )
 
 // Now check permissions to access this page
 if ($prefs['feature_sheet'] != 'y') {
-	$smarty->assign('msg', tra("This feature is disabled").": feature_sheets, feature_charts");
+	$smarty->assign('msg', tra("This feature is disabled").": feature_sheets");
 
 	$smarty->display("error.tpl");
 	die;
@@ -84,16 +84,16 @@ if( !( is_numeric( $_GET['w'] )
 switch( $_GET['t'] )
 {
 case 'png':
-	$renderer = &new GD_GRenderer( $_GET['w'], $_GET['h'] );
+	$renderer = new GD_GRenderer( $_GET['w'], $_GET['h'] );
 	break;
 case 'pdf':
-	$renderer = &new PDFLib_GRenderer( $_GET['p'], $_GET['o'] );
+	$renderer = new PDFLib_GRenderer( $_GET['p'], $_GET['o'] );
 	break;
 default:
 	die;
 }
 
-$graph = &new MultilineGraphic;
+$graph = new MultilineGraphic;
 $graph->setTitle( $_GET['title'] );
 
 $size = ($_GET['max'] - $_GET['min']) / $_GET['s'];
@@ -117,4 +117,3 @@ $graph->setData( $data );
 $graph->draw( $renderer );
 
 $renderer->httpOutput( "graph.{$_GET['t']}" );
-?>
