@@ -14,6 +14,12 @@ if ($tiki_p_admin != 'y') {
 	die;
 }
 
+if($prefs['feature_wiki'] != 'y') {
+    $smarty->assign('msg', tra('This feature is disabled').': feature_wiki');
+    $smarty->display('error.tpl');
+    die;  
+}
+
 
 function parse_st($dump) {
 	$bodysep  = '>>>>>>>>>>>>>>>>>>>>>>>>';
@@ -120,5 +126,3 @@ $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 
 $smarty->assign('mid', 'tiki-import_structuredtext.tpl');
 $smarty->display("tiki.tpl");
-
-?>
