@@ -40,21 +40,18 @@ if (!isset($_REQUEST["page"])) {
 $page = $_REQUEST['page'];
 $smarty->assign('page', $page);
 
-
-require_once ('tiki-pagesetup.php');
-
 // If the page doesn't exist then display an error
-if (!$tikilib->page_exists($page)) {
+if (!($info = $tikilib->get_page_info($page))) {
 	$smarty->assign('msg', tra("Page cannot be found"));
-
 	$smarty->display("error_raw.tpl");
 	die;
 }
 
 // Now check permissions to access this page
+$tikilib->get_perm_object( $page, 'wiki page', $info);
 if ($tiki_p_view != 'y') {
 	$smarty->assign('errortype', 401);
-	$smarty->assign('msg', tra("Permission denied you cannot view this page"));
+	$smarty->assign('msg', tra("Permission denied. You cannot view this page."));
 
 	$smarty->display("error_raw.tpl");
 	die;
@@ -153,11 +150,6 @@ if (empty($info["user"])) {
 
 $smarty->assign_by_ref('lastUser', $info["user"]);
 
-/*
-// force enable wiki comments (for development)
-$prefs['feature_wiki_comments'] = 'y';
-*/
-
 // Comments engine!
 if ($prefs['feature_wiki_comments'] == 'y') {
 	$comments_per_page = $prefs['wiki_comments_per_page'];
@@ -175,5 +167,3 @@ ask_ticket('index-raw');
 // Display the Index Template
 $smarty->assign('dblclickedit', 'y');
 $smarty->display("tiki-show_page_raw.tpl");
-
-?>
