@@ -5,17 +5,14 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   exit;
 }	
 
-if (isset($prefs['feature_jscalendar']) and $prefs['feature_jscalendar'] == 'y') {
+if ( $prefs['feature_jscalendar'] == 'y' && $prefs['javascript_enabled'] == 'y' ) {
 	$jslang['en'] = "en";
 	$jslang['fr'] = "fr-utf8";
 	$jslang['pt-br'] = "br-utf8";
 	$jslang['es'] = "es-utf8";
-  $smarty->assign('uses_jscalendar', 'y'); 
-  $smarty->assign('feature_jscalendar', 'y'); 
 	if (isset($prefs['language']) and isset($jslang[$prefs['language']])) {
 		$smarty->assign('jscalendar_langfile', $jslang[$prefs['language']]);
 	} else {
 		$smarty->assign('jscalendar_langfile', array_shift($jslang));
 	}
 }
-?>
