@@ -1,52 +1,42 @@
 <?php
-
-// $Id: /cvsroot/tikiwiki/tiki/tiki-list_articles.php,v 1.38.2.2 2008-03-21 23:06:51 sylvieg Exp $
-
-// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// (c) Copyright 2002-2009 by authors of the Tiki Wiki/CMS/Groupware Project
+// 
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
-
-// Initialization
+// $Id: /cvsroot/tikiwiki/tiki/tiki-list_articles.php,v 1.38.2.2 2008-03-21 23:06:51 sylvieg Exp $
 $section = 'cms';
 require_once ('tiki-setup.php');
-
 include_once ('lib/articles/artlib.php');
-
-$smarty->assign('headtitle',tra('List Articles'));
-
+$smarty->assign('headtitle', tra('List Articles'));
 if ($prefs['feature_articles'] != 'y') {
-	$smarty->assign('msg', tra("This feature is disabled").": feature_articles");
-
+	$smarty->assign('msg', tra("This feature is disabled") . ": feature_articles");
 	$smarty->display("error.tpl");
 	die;
 }
-
 // Now check permissions to access this page
-if($tiki_p_read_article != 'y') {
+if ($tiki_p_read_article != 'y') {
 	$smarty->assign('errortype', 401);
-	$smarty->assign('msg',tra("Permission denied you cannot view pages"));
+	$smarty->assign('msg', tra("Permission denied. You cannot view pages"));
 	$smarty->display("error.tpl");
-	die;  
+	die;
 }
-
 if (isset($_REQUEST["remove"])) {
+	$artperms = Perms::get( array( 'type' => 'article', 'object' => $_REQUEST['remove'] ) );
 
-	if ($tiki_p_remove_article != 'y') {
+	if ($artperms->remove_article != 'y') {
 		$smarty->assign('errortype', 401);
 		$smarty->assign('msg', tra("Permission denied you cannot remove articles"));
-
 		$smarty->display("error.tpl");
 		die;
 	}
-  $area = 'delarticle';
-  if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
-    key_check($area);
+	$area = 'delarticle';
+	if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		key_check($area);
 		$artlib->remove_article($_REQUEST["remove"]);
-  } else {
-    key_get($area);
-  }
+	} else {
+		key_get($area);
+	}
 }
-
 // This script can receive the thresold
 // for the information as the number of
 // days to get in the log 1,3,4,etc
@@ -56,9 +46,7 @@ if (!isset($_REQUEST["sort_mode"])) {
 } else {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
-
 $smarty->assign_by_ref('sort_mode', $sort_mode);
-
 // If offset is set use it if not then use offset =0
 // use the maxRecords php variable to set the limit
 // if sortMode is not set then use lastModif_desc
@@ -73,38 +61,32 @@ if (!empty($_REQUEST['maxRecords'])) {
 } else {
 	$maxRecords = $maxRecords;
 }
-#samrty->assign_by_ref('maxRecords', $maxRecords);
-
-if( ($tiki_p_admin == 'y') || ($tiki_p_admin_cms == 'y') ) {
-  $pdate = '';
-} elseif(isset($_SESSION["thedate"])) {
-  if($_SESSION["thedate"]<$tikilib->now) {
-    // If the session is older then set it to today
-    // so you can list articles
-    $pdate = $tikilib->now; 
-  } else {
-      $pdate = $_SESSION["thedate"]; 
-  }
+$smarty->assign_by_ref('maxRecords', $maxRecords);
+if (($tiki_p_admin == 'y') || ($tiki_p_admin_cms == 'y')) {
+	$date_max = '';
+} elseif (isset($_SESSION["thedate"])) {
+	if ($_SESSION["thedate"] < $tikilib->now) {
+		// If the session is older then set it to today
+		// so you can list articles
+		$date_max = $tikilib->now;
+	} else {
+		$date_max = $_SESSION["thedate"];
+	}
 } else {
-	$pdate = $tikilib->now;
+	$date_max = $tikilib->now;
 }
-
 if (isset($_REQUEST["find"])) {
 	$find = $_REQUEST["find"];
 } else {
 	$find = '';
 }
-
 $smarty->assign('find', $find);
-
 if (!isset($_REQUEST["type"])) {
 	$_REQUEST["type"] = '';
 }
-
 if (!isset($_REQUEST["topic"])) {
 	$_REQUEST["topic"] = '';
 }
-
 if (!isset($_REQUEST["categId"])) {
 	$_REQUEST["categId"] = '';
 }
@@ -115,28 +97,24 @@ $smarty->assign('find_topic', $_REQUEST["topic"]);
 $smarty->assign('find_type', $_REQUEST["type"]);
 $smarty->assign('find_categId', $_REQUEST["categId"]);
 $smarty->assign('find_lang', $_REQUEST['lang']);
-
-
-
-$visible_only='y';
-if( ($tiki_p_admin == 'y') || ($tiki_p_admin_cms == 'y') ) { $visible_only="n"; }
-
+$visible_only = 'y';
+if (($tiki_p_admin == 'y') || ($tiki_p_admin_cms == 'y')) {
+	$visible_only = "n";
+}
 // Get a list of last changes to the Wiki database
-$listpages = $tikilib->list_articles($offset, $maxRecords, $sort_mode, $find, $pdate, $user, $_REQUEST["type"], $_REQUEST["topic"], $visible_only, '', $_REQUEST["categId"], '', '', $_REQUEST['lang']);
+$listpages = $tikilib->list_articles($offset, $maxRecords, $sort_mode, $find, 0, $date_max, $user, $_REQUEST["type"], $_REQUEST["topic"], $visible_only, '', $_REQUEST["categId"], '', '', $_REQUEST['lang']);
 // If there're more records then assign next_offset
 $smarty->assign_by_ref('cant', $listpages['cant']);
-
 $smarty->assign_by_ref('listpages', $listpages["data"]);
 //print_r($listpages["data"]);
 $topics = $artlib->list_topics();
 $smarty->assign_by_ref('topics', $topics);
-
 $types = $artlib->list_types();
 $smarty->assign_by_ref('types', $types);
-
 if ($prefs['feature_categories'] == 'y') {
-	global $categlib; include_once ('lib/categories/categlib.php');
-	$categories = $categlib->get_all_categories_ext();
+	global $categlib;
+	include_once ('lib/categories/categlib.php');
+	$categories = $categlib->get_all_categories_respect_perms(null, 'view_category');
 	$smarty->assign_by_ref('categories', $categories);
 }
 if ($prefs['feature_multilingual'] == 'y') {
@@ -144,27 +122,20 @@ if ($prefs['feature_multilingual'] == 'y') {
 	$languages = $tikilib->list_languages(false, 'y');
 	$smarty->assign_by_ref('languages', $languages);
 }
-
 if ($tiki_p_edit_article != 'y' && $tiki_p_remove_article != 'y') { //check one editable
-	foreach ($listpages['data'] as $page) {
+	foreach($listpages['data'] as $page) {
 		if ($page['author'] == $user && $page['creator_edit'] == 'y') {
 			$smarty->assign('oneEditPage', 'y');
 			break;
 		}
 	}
 }
-
 include_once ('tiki-section_options.php');
-
-if ($prefs['feature_mobile'] =='y' && isset($_REQUEST['mode']) && $_REQUEST['mode'] == 'mobile') {
+if ($prefs['feature_mobile'] == 'y' && isset($_REQUEST['mode']) && $_REQUEST['mode'] == 'mobile') {
 	include_once ("lib/hawhaw/hawtikilib.php");
-
 	HAWTIKI_list_articles($listpages, $tiki_p_read_article, $offset, $maxRecords, $listpages["cant"]);
 }
 ask_ticket('list-articles');
-
 // Display the template
 $smarty->assign('mid', 'tiki-list_articles.tpl');
 $smarty->display("tiki.tpl");
-
-?>
