@@ -1,14 +1,10 @@
 <?php
-
-// $Header: /cvsroot/tikiwiki/tiki/tiki-mytiki_shared.php,v 1.4.2.2 2007/03/02 12:23:21 luciash Exp $
-
-// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// (c) Copyright 2002-2009 by authors of the Tiki Wiki/CMS/Groupware Project
+// 
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
-if ($feature_messages == 'y' && $tiki_p_messages == 'y') {
+// $Id: /cvsroot/tikiwiki/tiki/tiki-mytiki_shared.php,v 1.8 2007-10-12 07:55:29 nyloth Exp $
+if ($prefs['feature_messages'] == 'y' && $tiki_p_messages == 'y') {
 	$unread = $tikilib->user_unread_messages($user);
-
 	$smarty->assign('unread', $unread);
 }
-
-?>
\ No newline at end of file
