@@ -1,35 +1,26 @@
 <?php
-
-// $Id: /cvsroot/tikiwiki/tiki/tiki-old_polls.php,v 1.14.2.2 2007-12-06 14:14:11 nkoth Exp $
-
-// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// (c) Copyright 2002-2009 by authors of the Tiki Wiki/CMS/Groupware Project
+// 
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
-
-// Initialization
+// $Id: /cvsroot/tikiwiki/tiki/tiki-old_polls.php,v 1.14.2.2 2007-12-06 14:14:11 nkoth Exp $
 require_once ('tiki-setup.php');
-
 include_once ('lib/polls/polllib.php');
-
 if (!isset($polllib)) {
-	$polllib = new PollLib($dbTiki);
+	$polllib = new PollLib;
 }
-
 if ($prefs['feature_polls'] != 'y') {
-	$smarty->assign('msg', tra("This feature is disabled").": feature_polls");
-
+	$smarty->assign('msg', tra("This feature is disabled") . ": feature_polls");
 	$smarty->display("error.tpl");
 	die;
 }
-
 // Now check permissions to access this page
 if ($tiki_p_view_poll_results != 'y') {
 	$smarty->assign('errortype', 401);
-  $smarty->assign('msg',tra("Permission denied you cannot view this page"));
-  $smarty->display("error.tpl");
-  die;  
+	$smarty->assign('msg', tra("Permission denied. You cannot view this page."));
+	$smarty->display("error.tpl");
+	die;
 }
-
 // This script can receive the thresold
 // for the information as the number of
 // days to get in the log 1,3,4,etc
@@ -39,9 +30,7 @@ if (!isset($_REQUEST["sort_mode"])) {
 } else {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
-
 $smarty->assign_by_ref('sort_mode', $sort_mode);
-
 // If offset is set use it if not then use offset =0
 // use the maxRecords php variable to set the limit
 // if sortMode is not set then use lastModif_desc
@@ -50,42 +39,18 @@ if (!isset($_REQUEST["offset"])) {
 } else {
 	$offset = $_REQUEST["offset"];
 }
-
 $smarty->assign_by_ref('offset', $offset);
-
 if (isset($_REQUEST["find"])) {
 	$find = $_REQUEST["find"];
 } else {
 	$find = '';
 }
-
 $smarty->assign('find', $find);
-
 // Get a list of last changes to the Wiki database
 $listpages = $polllib->list_all_polls($offset, $maxRecords, $sort_mode, $find);
 // If there're more records then assign next_offset
-$cant_pages = ceil($listpages["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
-if ($listpages["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
-}
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
-}
-
+$smarty->assign_by_ref('cant_pages', $listpages["cant"]);
 $smarty->assign_by_ref('listpages', $listpages["data"]);
-//print_r($listpages["data"]);
-
 // Display the template
 $smarty->assign('mid', 'tiki-old_polls.tpl');
 $smarty->display("tiki.tpl");
-
-?>
