@@ -1,127 +1,84 @@
 <?php
-
-// $Id: /cvsroot/tikiwiki/tiki/tiki-survey_stats_survey.php,v 1.16 2007-10-12 07:55:32 nyloth Exp $
-
-// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// (c) Copyright 2002-2009 by authors of the Tiki Wiki/CMS/Groupware Project
+// 
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
-
-// Initialization
+// $Id: /cvsroot/tikiwiki/tiki/tiki-survey_stats_survey.php,v 1.16 2007-10-12 07:55:32 nyloth Exp $
 $section = 'surveys';
 require_once ('tiki-setup.php');
-
 include_once ('lib/surveys/surveylib.php');
-
 if ($prefs['feature_surveys'] != 'y') {
-	$smarty->assign('msg', tra("This feature is disabled").": feature_surveys");
-
+	$smarty->assign('msg', tra("This feature is disabled") . ": feature_surveys");
 	$smarty->display("error.tpl");
 	die;
 }
 
-$smarty->assign('individual', 'n');
-
-if ($userlib->object_has_one_permission($_REQUEST["surveyId"], 'survey')) {
-	$smarty->assign('individual', 'y');
-
-	if ($tiki_p_admin != 'y') {
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'surveys');
-
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-
-			if ($userlib->object_has_permission($user, $_REQUEST["surveyId"], 'survey', $permName)) {
-				$$permName = 'y';
-
-				$smarty->assign("$permName", 'y');
-			} else {
-				$$permName = 'n';
-
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-}
+$tikilib->get_perm_object($_REQUEST["surveyId"], 'survey');
 
 if ($tiki_p_view_survey_stats != 'y') {
 	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("You do not have permission to use this feature"));
-
 	$smarty->display("error.tpl");
 	die;
 }
-
 if (!isset($_REQUEST["surveyId"])) {
 	$smarty->assign('msg', tra("No survey indicated"));
-
 	$smarty->display("error.tpl");
 	die;
 }
-
 $smarty->assign('surveyId', $_REQUEST["surveyId"]);
 $survey_info = $srvlib->get_survey($_REQUEST["surveyId"]);
 $smarty->assign('survey_info', $survey_info);
-
 if (isset($_REQUEST["clear"]) && $tiki_p_admin_surveys == 'y') {
-  $area = 'delsurveystats';
-  if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
-    key_check($area);
+	$area = 'delsurveystats';
+	if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		key_check($area);
 		$srvlib->clear_survey_stats($_REQUEST["clear"]);
-  } else {
-    key_get($area);
-  }
+	} else {
+		key_get($area);
+	}
 }
-
 if (!isset($_REQUEST["sort_mode"])) {
 	$sort_mode = 'position_asc';
 } else {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
-
 if (!isset($_REQUEST["offset"])) {
 	$offset = 0;
 } else {
 	$offset = $_REQUEST["offset"];
 }
-
 $smarty->assign_by_ref('offset', $offset);
-
 if (isset($_REQUEST["find"])) {
 	$find = $_REQUEST["find"];
 } else {
 	$find = '';
 }
-
 $smarty->assign('find', $find);
-
 $smarty->assign_by_ref('sort_mode', $sort_mode);
-
 $channels = $srvlib->list_survey_questions($_REQUEST["surveyId"], 0, -1, $sort_mode, $find);
 $cant_pages = ceil($channels["cant"] / $maxRecords);
 $smarty->assign_by_ref('cant_pages', $cant_pages);
 $smarty->assign('actual_page', 1 + ($offset / $maxRecords));
-
 if ($channels["cant"] > ($offset + $maxRecords)) {
 	$smarty->assign('next_offset', $offset + $maxRecords);
 } else {
 	$smarty->assign('next_offset', -1);
 }
-
 // If offset is > 0 then prev_offset
 if ($offset > 0) {
 	$smarty->assign('prev_offset', $offset - $maxRecords);
 } else {
 	$smarty->assign('prev_offset', -1);
 }
-
 $smarty->assign_by_ref('channels', $channels["data"]);
-
 include_once ('tiki-section_options.php');
-
 ask_ticket('survey-stats-survey');
-
 // Display the template
 $smarty->assign('mid', 'tiki-survey_stats_survey.tpl');
-$smarty->display("tiki.tpl");
-
-?>
+if (isset($_REQUEST['print'])) {
+	$smarty->display('tiki-print.tpl');
+	$smarty->assign('print', 'y');
+} else {
+	$smarty->display('tiki.tpl');
+}
