@@ -7,25 +7,15 @@
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 require_once ('tiki-setup.php');
 
+if ($prefs['feature_mobile'] != 'y') {
+  $smarty->assign('msg', tra("This feature is disabled").": feature_mobile");
+ 
+  $smarty->display("error.tpl");
+  die;
+ }
+
+
 require ("lib/hawhaw/hawhaw.inc");
-/*
-$DemoPage = new HAW_deck("Tiki", HAW_ALIGN_CENTER);
-$title = new HAW_text("Tiki", HAW_TEXTFORMAT_BOLD);
-$DemoPage->add_text($title);
-//$link1 = new HAW_link("Forum","forum.php");
-$link2 = new HAW_link("Wiki","tiki-index.php?mode=wap");
-$link3 = new HAW_link("Blogs","tiki-list_blogs.php?mode=wap");
-$linkset = new HAW_linkset();
-//$linkset->add_link($link1);
-if($prefs['feature_wiki'] == 'y') {
-	$linkset->add_link($link2);
-}
-if($prefs['feature_blogs'] == 'y') {
-	$linkset->add_link($link3);
-}
-$DemoPage->add_linkset($linkset);
-$DemoPage->create_page();
-*/
 $TikiPage = new HAW_deck("Tiki", HAW_ALIGN_CENTER);
 
 $text1 = new HAW_text("Attention!", HAW_TEXTFORMAT_BOLD);
@@ -45,5 +35,3 @@ $text3 = new HAW_text(
 $TikiPage->add_text($text3);
 
 $TikiPage->create_page();
-
-?>
\ No newline at end of file
