@@ -8,6 +8,7 @@ if($prefs['feature_xmlrpc'] != 'y' || $prefs['wiki_feature_3d'] != 'y') {
 }
 
 require_once("XML/Server.php");
+include_once('lib/wiki/wikilib.php');
 
 $map = array ("getSubGraph" => array( "function" => "getSubGraph" ) );
 $server = new XML_RPC_Server( $map );
@@ -24,7 +25,7 @@ function getSubGraph($params) {
     $queue = array($nodeName);
     $i = 0;
 
-    $tikilib = new TikiLib($dbTiki);
+    $tikilib = new TikiLib;
     $existing_color = $prefs['wiki_3d_existing_page_color'];
     $missing_color = $prefs['wiki_3d_missing_page_color'];
 
@@ -67,5 +68,3 @@ function getSubGraph($params) {
     
     return new XML_RPC_Response(new XML_RPC_Value($response, "struct"));
 }
-
-?>
